Clojure only.

atlassian.bitbucket.pipelines

Bitbucket Pipelines API — CI/CD pipeline management, configuration, runners, variables, SSH keys, caches, and OIDC identity.

Bitbucket Pipelines API — CI/CD pipeline management, configuration, runners,
variables, SSH keys, caches, and OIDC identity.
raw docstring

create-deployments-config-environments-variablesclj

(create-deployments-config-environments-variables client
                                                  workspace
                                                  repo-slug
                                                  environment-uuid
                                                  body)
(create-deployments-config-environments-variables client
                                                  workspace
                                                  repo-slug
                                                  environment-uuid
                                                  body
                                                  opts)

Create a variable for an environment. POST /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables Path params: workspace, repo-slug, environment-uuid Body: deployment_variable

Create a variable for an environment.
POST /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables
Path params: workspace, repo-slug, environment-uuid
Body: deployment_variable
sourceraw docstring

create-pipelinesclj

(create-pipelines client workspace repo-slug body)
(create-pipelines client workspace repo-slug body opts)

Run a pipeline. POST /2.0/repositories/{workspace}/{repo_slug}/pipelines Path params: workspace, repo-slug Body: pipeline

Run a pipeline.
POST /2.0/repositories/{workspace}/{repo_slug}/pipelines
Path params: workspace, repo-slug
Body: pipeline
sourceraw docstring

create-pipelines-config-runners-by-workspaceclj

(create-pipelines-config-runners-by-workspace client workspace)

Create workspace runner. POST /2.0/workspaces/{workspace}/pipelines-config/runners Path params: workspace

Create workspace runner.
POST /2.0/workspaces/{workspace}/pipelines-config/runners
Path params: workspace
sourceraw docstring

create-pipelines-config-runners-by-workspace-repo-slugclj

(create-pipelines-config-runners-by-workspace-repo-slug client
                                                        workspace
                                                        repo-slug)

Create repository runner. POST /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners Path params: workspace, repo-slug

Create repository runner.
POST /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners
Path params: workspace, repo-slug
sourceraw docstring

create-pipelines-config-schedulesclj

(create-pipelines-config-schedules client workspace repo-slug body)
(create-pipelines-config-schedules client workspace repo-slug body opts)

Create a schedule. POST /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules Path params: workspace, repo-slug Body: pipeline_schedule_post_request_body

Create a schedule.
POST /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules
Path params: workspace, repo-slug
Body: pipeline_schedule_post_request_body
sourceraw docstring

create-pipelines-config-ssh-known-hostsclj

(create-pipelines-config-ssh-known-hosts client workspace repo-slug body)
(create-pipelines-config-ssh-known-hosts client workspace repo-slug body opts)

Create a known host. POST /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts Path params: workspace, repo-slug Body: pipeline_known_host

Create a known host.
POST /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts
Path params: workspace, repo-slug
Body: pipeline_known_host
sourceraw docstring

create-pipelines-config-variables-by-selected-userclj

(create-pipelines-config-variables-by-selected-user client selected-user)

Create a variable for a user (deprecated). POST /2.0/users/{selected_user}/pipelines_config/variables Path params: selected-user

Create a variable for a user (deprecated).
POST /2.0/users/{selected_user}/pipelines_config/variables
Path params: selected-user
sourceraw docstring

create-pipelines-config-variables-by-usernameclj

(create-pipelines-config-variables-by-username client username)

Create a variable for a user (deprecated). POST /2.0/teams/{username}/pipelines_config/variables Path params: username

Create a variable for a user (deprecated).
POST /2.0/teams/{username}/pipelines_config/variables
Path params: username
sourceraw docstring

create-pipelines-config-variables-by-workspaceclj

(create-pipelines-config-variables-by-workspace client workspace)

Create a variable for a workspace. POST /2.0/workspaces/{workspace}/pipelines-config/variables Path params: workspace

Create a variable for a workspace.
POST /2.0/workspaces/{workspace}/pipelines-config/variables
Path params: workspace
sourceraw docstring

create-pipelines-config-variables-by-workspace-repo-slugclj

(create-pipelines-config-variables-by-workspace-repo-slug client
                                                          workspace
                                                          repo-slug
                                                          body)
(create-pipelines-config-variables-by-workspace-repo-slug client
                                                          workspace
                                                          repo-slug
                                                          body
                                                          opts)

Create a variable for a repository. POST /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables Path params: workspace, repo-slug Body: pipeline_variable

Create a variable for a repository.
POST /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables
Path params: workspace, repo-slug
Body: pipeline_variable
sourceraw docstring

create-pipelines-stop-pipelineclj

(create-pipelines-stop-pipeline client workspace repo-slug pipeline-uuid)

Stop a pipeline. POST /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/stopPipeline Path params: workspace, repo-slug, pipeline-uuid

Stop a pipeline.
POST /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/stopPipeline
Path params: workspace, repo-slug, pipeline-uuid
sourceraw docstring

delete-deployments-config-environments-variablesclj

(delete-deployments-config-environments-variables client
                                                  workspace
                                                  repo-slug
                                                  environment-uuid
                                                  variable-uuid)

Delete a variable for an environment. DELETE /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables/{variable_uuid} Path params: workspace, repo-slug, environment-uuid, variable-uuid

Delete a variable for an environment.
DELETE /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables/{variable_uuid}
Path params: workspace, repo-slug, environment-uuid, variable-uuid
sourceraw docstring

delete-pipelines-config-caches-by-workspace-repo-slugclj

(delete-pipelines-config-caches-by-workspace-repo-slug client
                                                       workspace
                                                       repo-slug
                                                       opts)

Delete caches. DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches Path params: workspace, repo-slug Query params: name (required)

Delete caches.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches
Path params: workspace, repo-slug
Query params: name (required)
sourceraw docstring

delete-pipelines-config-caches-by-workspace-repo-slug-cache-uuidclj

(delete-pipelines-config-caches-by-workspace-repo-slug-cache-uuid client
                                                                  workspace
                                                                  repo-slug
                                                                  cache-uuid)

Delete a cache. DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches/{cache_uuid} Path params: workspace, repo-slug, cache-uuid

Delete a cache.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches/{cache_uuid}
Path params: workspace, repo-slug, cache-uuid
sourceraw docstring

delete-pipelines-config-runners-by-workspace-repo-slug-runner-uuidclj

(delete-pipelines-config-runners-by-workspace-repo-slug-runner-uuid client
                                                                    workspace
                                                                    repo-slug
                                                                    runner-uuid)

Delete repository runner. DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners/{runner_uuid} Path params: workspace, repo-slug, runner-uuid

Delete repository runner.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners/{runner_uuid}
Path params: workspace, repo-slug, runner-uuid
sourceraw docstring

delete-pipelines-config-runners-by-workspace-runner-uuidclj

(delete-pipelines-config-runners-by-workspace-runner-uuid client
                                                          workspace
                                                          runner-uuid)

Delete workspace runner. DELETE /2.0/workspaces/{workspace}/pipelines-config/runners/{runner_uuid} Path params: workspace, runner-uuid

Delete workspace runner.
DELETE /2.0/workspaces/{workspace}/pipelines-config/runners/{runner_uuid}
Path params: workspace, runner-uuid
sourceraw docstring

delete-pipelines-config-schedulesclj

(delete-pipelines-config-schedules client workspace repo-slug schedule-uuid)

Delete a schedule. DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid} Path params: workspace, repo-slug, schedule-uuid

Delete a schedule.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid}
Path params: workspace, repo-slug, schedule-uuid
sourceraw docstring

delete-pipelines-config-ssh-key-pairclj

(delete-pipelines-config-ssh-key-pair client workspace repo-slug)

Delete SSH key pair. DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/key_pair Path params: workspace, repo-slug

Delete SSH key pair.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/key_pair
Path params: workspace, repo-slug
sourceraw docstring

delete-pipelines-config-ssh-known-hostsclj

(delete-pipelines-config-ssh-known-hosts client
                                         workspace
                                         repo-slug
                                         known-host-uuid)

Delete a known host. DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts/{known_host_uuid} Path params: workspace, repo-slug, known-host-uuid

Delete a known host.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts/{known_host_uuid}
Path params: workspace, repo-slug, known-host-uuid
sourceraw docstring

delete-pipelines-config-variables-by-selected-user-variable-uuidclj

(delete-pipelines-config-variables-by-selected-user-variable-uuid client
                                                                  selected-user
                                                                  variable-uuid)

Delete a variable for a user (deprecated). DELETE /2.0/users/{selected_user}/pipelines_config/variables/{variable_uuid} Path params: selected-user, variable-uuid

Delete a variable for a user (deprecated).
DELETE /2.0/users/{selected_user}/pipelines_config/variables/{variable_uuid}
Path params: selected-user, variable-uuid
sourceraw docstring

delete-pipelines-config-variables-by-username-variable-uuidclj

(delete-pipelines-config-variables-by-username-variable-uuid client
                                                             username
                                                             variable-uuid)

Delete a variable for a team (deprecated). DELETE /2.0/teams/{username}/pipelines_config/variables/{variable_uuid} Path params: username, variable-uuid

Delete a variable for a team (deprecated).
DELETE /2.0/teams/{username}/pipelines_config/variables/{variable_uuid}
Path params: username, variable-uuid
sourceraw docstring

delete-pipelines-config-variables-by-workspace-repo-slug-variable-uuidclj

(delete-pipelines-config-variables-by-workspace-repo-slug-variable-uuid
  client
  workspace
  repo-slug
  variable-uuid)

Delete a variable for a repository. DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables/{variable_uuid} Path params: workspace, repo-slug, variable-uuid

Delete a variable for a repository.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables/{variable_uuid}
Path params: workspace, repo-slug, variable-uuid
sourceraw docstring

delete-pipelines-config-variables-by-workspace-variable-uuidclj

(delete-pipelines-config-variables-by-workspace-variable-uuid client
                                                              workspace
                                                              variable-uuid)

Delete a variable for a workspace. DELETE /2.0/workspaces/{workspace}/pipelines-config/variables/{variable_uuid} Path params: workspace, variable-uuid

Delete a variable for a workspace.
DELETE /2.0/workspaces/{workspace}/pipelines-config/variables/{variable_uuid}
Path params: workspace, variable-uuid
sourceraw docstring

get-pipelinesclj

(get-pipelines client workspace repo-slug pipeline-uuid)
(get-pipelines client workspace repo-slug pipeline-uuid opts)

Get a pipeline. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid} Path params: workspace, repo-slug, pipeline-uuid Query opts: passed through as query params (e.g. fields).

Get a pipeline.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}
Path params: workspace, repo-slug, pipeline-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-runners-by-workspace-repo-slug-runner-uuidclj

(get-pipelines-config-runners-by-workspace-repo-slug-runner-uuid client
                                                                 workspace
                                                                 repo-slug
                                                                 runner-uuid)
(get-pipelines-config-runners-by-workspace-repo-slug-runner-uuid client
                                                                 workspace
                                                                 repo-slug
                                                                 runner-uuid
                                                                 opts)

Get repository runner. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners/{runner_uuid} Path params: workspace, repo-slug, runner-uuid Query opts: passed through as query params (e.g. fields).

Get repository runner.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners/{runner_uuid}
Path params: workspace, repo-slug, runner-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-runners-by-workspace-runner-uuidclj

(get-pipelines-config-runners-by-workspace-runner-uuid client
                                                       workspace
                                                       runner-uuid)
(get-pipelines-config-runners-by-workspace-runner-uuid client
                                                       workspace
                                                       runner-uuid
                                                       opts)

Get workspace runner. GET /2.0/workspaces/{workspace}/pipelines-config/runners/{runner_uuid} Path params: workspace, runner-uuid Query opts: passed through as query params (e.g. fields).

Get workspace runner.
GET /2.0/workspaces/{workspace}/pipelines-config/runners/{runner_uuid}
Path params: workspace, runner-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-schedulesclj

(get-pipelines-config-schedules client workspace repo-slug schedule-uuid)
(get-pipelines-config-schedules client workspace repo-slug schedule-uuid opts)

Get a schedule. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid} Path params: workspace, repo-slug, schedule-uuid Query opts: passed through as query params (e.g. fields).

Get a schedule.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid}
Path params: workspace, repo-slug, schedule-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-ssh-known-hostsclj

(get-pipelines-config-ssh-known-hosts client
                                      workspace
                                      repo-slug
                                      known-host-uuid)
(get-pipelines-config-ssh-known-hosts client
                                      workspace
                                      repo-slug
                                      known-host-uuid
                                      opts)

Get a known host. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts/{known_host_uuid} Path params: workspace, repo-slug, known-host-uuid Query opts: passed through as query params (e.g. fields).

Get a known host.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts/{known_host_uuid}
Path params: workspace, repo-slug, known-host-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-variables-by-selected-user-variable-uuidclj

(get-pipelines-config-variables-by-selected-user-variable-uuid client
                                                               selected-user
                                                               variable-uuid)
(get-pipelines-config-variables-by-selected-user-variable-uuid client
                                                               selected-user
                                                               variable-uuid
                                                               opts)

Get a variable for a user (deprecated). GET /2.0/users/{selected_user}/pipelines_config/variables/{variable_uuid} Path params: selected-user, variable-uuid Query opts: passed through as query params (e.g. fields).

Get a variable for a user (deprecated).
GET /2.0/users/{selected_user}/pipelines_config/variables/{variable_uuid}
Path params: selected-user, variable-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-variables-by-username-variable-uuidclj

(get-pipelines-config-variables-by-username-variable-uuid client
                                                          username
                                                          variable-uuid)
(get-pipelines-config-variables-by-username-variable-uuid client
                                                          username
                                                          variable-uuid
                                                          opts)

Get a variable for a team (deprecated). GET /2.0/teams/{username}/pipelines_config/variables/{variable_uuid} Path params: username, variable-uuid Query opts: passed through as query params (e.g. fields).

Get a variable for a team (deprecated).
GET /2.0/teams/{username}/pipelines_config/variables/{variable_uuid}
Path params: username, variable-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-variables-by-workspace-repo-slug-variable-uuidclj

(get-pipelines-config-variables-by-workspace-repo-slug-variable-uuid
  client
  workspace
  repo-slug
  variable-uuid)
(get-pipelines-config-variables-by-workspace-repo-slug-variable-uuid
  client
  workspace
  repo-slug
  variable-uuid
  opts)

Get a variable for a repository. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables/{variable_uuid} Path params: workspace, repo-slug, variable-uuid Query opts: passed through as query params (e.g. fields).

Get a variable for a repository.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables/{variable_uuid}
Path params: workspace, repo-slug, variable-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-config-variables-by-workspace-variable-uuidclj

(get-pipelines-config-variables-by-workspace-variable-uuid client
                                                           workspace
                                                           variable-uuid)
(get-pipelines-config-variables-by-workspace-variable-uuid client
                                                           workspace
                                                           variable-uuid
                                                           opts)

Get variable for a workspace. GET /2.0/workspaces/{workspace}/pipelines-config/variables/{variable_uuid} Path params: workspace, variable-uuid Query opts: passed through as query params (e.g. fields).

Get variable for a workspace.
GET /2.0/workspaces/{workspace}/pipelines-config/variables/{variable_uuid}
Path params: workspace, variable-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-stepsclj

(get-pipelines-steps client workspace repo-slug pipeline-uuid step-uuid)
(get-pipelines-steps client workspace repo-slug pipeline-uuid step-uuid opts)

Get a step of a pipeline. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid} Path params: workspace, repo-slug, pipeline-uuid, step-uuid Query opts: passed through as query params (e.g. fields).

Get a step of a pipeline.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}
Path params: workspace, repo-slug, pipeline-uuid, step-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

get-pipelines-steps-logsclj

(get-pipelines-steps-logs client
                          workspace
                          repo-slug
                          pipeline-uuid
                          step-uuid
                          log-uuid)
(get-pipelines-steps-logs client
                          workspace
                          repo-slug
                          pipeline-uuid
                          step-uuid
                          log-uuid
                          opts)

Get the logs for the build container or a service container for a given step of a pipeline. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/logs/{log_uuid} Path params: workspace, repo-slug, pipeline-uuid, step-uuid, log-uuid Query opts: passed through as query params (e.g. fields).

Get the logs for the build container or a service container for a given step of a pipeline.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/logs/{log_uuid}
Path params: workspace, repo-slug, pipeline-uuid, step-uuid, log-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-deployments-config-environments-variablesclj

(list-deployments-config-environments-variables client
                                                workspace
                                                repo-slug
                                                environment-uuid)
(list-deployments-config-environments-variables client
                                                workspace
                                                repo-slug
                                                environment-uuid
                                                opts)

List variables for an environment. GET /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables Path params: workspace, repo-slug, environment-uuid

List variables for an environment.
GET /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables
Path params: workspace, repo-slug, environment-uuid
sourceraw docstring

list-pipelinesclj

(list-pipelines client workspace repo-slug)
(list-pipelines client workspace repo-slug opts)

List pipelines. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines Path params: workspace, repo-slug Query params: creator.uuid, target.ref_type, target.ref_name, target.branch, target.commit.hash, target.selector.pattern, target.selector.type, created_on, trigger_type, status, sort, page, pagelen

List pipelines.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines
Path params: workspace, repo-slug
Query params: creator.uuid, target.ref_type, target.ref_name, target.branch,
  target.commit.hash, target.selector.pattern, target.selector.type,
  created_on, trigger_type, status, sort, page, pagelen
sourceraw docstring

list-pipelines-configclj

(list-pipelines-config client workspace repo-slug)
(list-pipelines-config client workspace repo-slug opts)

Get configuration. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config Path params: workspace, repo-slug Query opts: passed through as query params (e.g. fields).

Get configuration.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config
Path params: workspace, repo-slug
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-config-cachesclj

(list-pipelines-config-caches client workspace repo-slug)
(list-pipelines-config-caches client workspace repo-slug opts)

List caches. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches Path params: workspace, repo-slug

List caches.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches
Path params: workspace, repo-slug
sourceraw docstring

list-pipelines-config-caches-content-uriclj

(list-pipelines-config-caches-content-uri client workspace repo-slug cache-uuid)
(list-pipelines-config-caches-content-uri client
                                          workspace
                                          repo-slug
                                          cache-uuid
                                          opts)

Get cache content URI. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches/{cache_uuid}/content-uri Path params: workspace, repo-slug, cache-uuid Query opts: passed through as query params (e.g. fields).

Get cache content URI.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/caches/{cache_uuid}/content-uri
Path params: workspace, repo-slug, cache-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-config-identity-oidc-keys-jsonclj

(list-pipelines-config-identity-oidc-keys-json client workspace)
(list-pipelines-config-identity-oidc-keys-json client workspace opts)

Get keys for OIDC in Pipelines. GET /2.0/workspaces/{workspace}/pipelines-config/identity/oidc/keys.json Path params: workspace Query opts: passed through as query params (e.g. fields).

Get keys for OIDC in Pipelines.
GET /2.0/workspaces/{workspace}/pipelines-config/identity/oidc/keys.json
Path params: workspace
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-config-identity-oidc-well-known-openid-configurationclj

(list-pipelines-config-identity-oidc-well-known-openid-configuration client
                                                                     workspace)
(list-pipelines-config-identity-oidc-well-known-openid-configuration client
                                                                     workspace
                                                                     opts)

Get OpenID configuration for OIDC in Pipelines. GET /2.0/workspaces/{workspace}/pipelines-config/identity/oidc/.well-known/openid-configuration Path params: workspace Query opts: passed through as query params (e.g. fields).

Get OpenID configuration for OIDC in Pipelines.
GET /2.0/workspaces/{workspace}/pipelines-config/identity/oidc/.well-known/openid-configuration
Path params: workspace
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-config-runners-by-workspaceclj

(list-pipelines-config-runners-by-workspace client workspace)
(list-pipelines-config-runners-by-workspace client workspace opts)

Get workspace runners. GET /2.0/workspaces/{workspace}/pipelines-config/runners Path params: workspace

Get workspace runners.
GET /2.0/workspaces/{workspace}/pipelines-config/runners
Path params: workspace
sourceraw docstring

list-pipelines-config-runners-by-workspace-repo-slugclj

(list-pipelines-config-runners-by-workspace-repo-slug client
                                                      workspace
                                                      repo-slug)
(list-pipelines-config-runners-by-workspace-repo-slug client
                                                      workspace
                                                      repo-slug
                                                      opts)

Get repository runners. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners Path params: workspace, repo-slug

Get repository runners.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners
Path params: workspace, repo-slug
sourceraw docstring

list-pipelines-config-schedulesclj

(list-pipelines-config-schedules client workspace repo-slug)
(list-pipelines-config-schedules client workspace repo-slug opts)

List schedules. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules Path params: workspace, repo-slug

List schedules.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules
Path params: workspace, repo-slug
sourceraw docstring

list-pipelines-config-schedules-executionsclj

(list-pipelines-config-schedules-executions client
                                            workspace
                                            repo-slug
                                            schedule-uuid)
(list-pipelines-config-schedules-executions client
                                            workspace
                                            repo-slug
                                            schedule-uuid
                                            opts)

List executions of a schedule. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid}/executions Path params: workspace, repo-slug, schedule-uuid

List executions of a schedule.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid}/executions
Path params: workspace, repo-slug, schedule-uuid
sourceraw docstring

list-pipelines-config-ssh-key-pairclj

(list-pipelines-config-ssh-key-pair client workspace repo-slug)
(list-pipelines-config-ssh-key-pair client workspace repo-slug opts)

Get SSH key pair. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/key_pair Path params: workspace, repo-slug Query opts: passed through as query params (e.g. fields).

Get SSH key pair.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/key_pair
Path params: workspace, repo-slug
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-config-ssh-known-hostsclj

(list-pipelines-config-ssh-known-hosts client workspace repo-slug)
(list-pipelines-config-ssh-known-hosts client workspace repo-slug opts)

List known hosts. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts Path params: workspace, repo-slug

List known hosts.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts
Path params: workspace, repo-slug
sourceraw docstring

list-pipelines-config-variables-by-selected-userclj

(list-pipelines-config-variables-by-selected-user client selected-user)
(list-pipelines-config-variables-by-selected-user client selected-user opts)

List variables for a user (deprecated). GET /2.0/users/{selected_user}/pipelines_config/variables Path params: selected-user

List variables for a user (deprecated).
GET /2.0/users/{selected_user}/pipelines_config/variables
Path params: selected-user
sourceraw docstring

list-pipelines-config-variables-by-usernameclj

(list-pipelines-config-variables-by-username client username)
(list-pipelines-config-variables-by-username client username opts)

List variables for an account (deprecated). GET /2.0/teams/{username}/pipelines_config/variables Path params: username

List variables for an account (deprecated).
GET /2.0/teams/{username}/pipelines_config/variables
Path params: username
sourceraw docstring

list-pipelines-config-variables-by-workspaceclj

(list-pipelines-config-variables-by-workspace client workspace)
(list-pipelines-config-variables-by-workspace client workspace opts)

List variables for a workspace. GET /2.0/workspaces/{workspace}/pipelines-config/variables Path params: workspace

List variables for a workspace.
GET /2.0/workspaces/{workspace}/pipelines-config/variables
Path params: workspace
sourceraw docstring

list-pipelines-config-variables-by-workspace-repo-slugclj

(list-pipelines-config-variables-by-workspace-repo-slug client
                                                        workspace
                                                        repo-slug)
(list-pipelines-config-variables-by-workspace-repo-slug client
                                                        workspace
                                                        repo-slug
                                                        opts)

List variables for a repository. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables Path params: workspace, repo-slug

List variables for a repository.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables
Path params: workspace, repo-slug
sourceraw docstring

list-pipelines-stepsclj

(list-pipelines-steps client workspace repo-slug pipeline-uuid)
(list-pipelines-steps client workspace repo-slug pipeline-uuid opts)

List steps for a pipeline. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps Path params: workspace, repo-slug, pipeline-uuid

List steps for a pipeline.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps
Path params: workspace, repo-slug, pipeline-uuid
sourceraw docstring

list-pipelines-steps-logclj

(list-pipelines-steps-log client workspace repo-slug pipeline-uuid step-uuid)
(list-pipelines-steps-log client
                          workspace
                          repo-slug
                          pipeline-uuid
                          step-uuid
                          opts)

Get log file for a step. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/log Path params: workspace, repo-slug, pipeline-uuid, step-uuid Query opts: passed through as query params (e.g. fields).

Get log file for a step.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/log
Path params: workspace, repo-slug, pipeline-uuid, step-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-steps-test-reportsclj

(list-pipelines-steps-test-reports client
                                   workspace
                                   repo-slug
                                   pipeline-uuid
                                   step-uuid)
(list-pipelines-steps-test-reports client
                                   workspace
                                   repo-slug
                                   pipeline-uuid
                                   step-uuid
                                   opts)

Get a summary of test reports for a given step of a pipeline. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/test_reports Path params: workspace, repo-slug, pipeline-uuid, step-uuid Query opts: passed through as query params (e.g. fields).

Get a summary of test reports for a given step of a pipeline.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/test_reports
Path params: workspace, repo-slug, pipeline-uuid, step-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-steps-test-reports-test-casesclj

(list-pipelines-steps-test-reports-test-cases client
                                              workspace
                                              repo-slug
                                              pipeline-uuid
                                              step-uuid)
(list-pipelines-steps-test-reports-test-cases client
                                              workspace
                                              repo-slug
                                              pipeline-uuid
                                              step-uuid
                                              opts)

Get test cases for a given step of a pipeline. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/test_reports/test_cases Path params: workspace, repo-slug, pipeline-uuid, step-uuid Query opts: passed through as query params (e.g. fields).

Get test cases for a given step of a pipeline.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/test_reports/test_cases
Path params: workspace, repo-slug, pipeline-uuid, step-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

list-pipelines-steps-test-reports-test-cases-test-case-reasonsclj

(list-pipelines-steps-test-reports-test-cases-test-case-reasons client
                                                                workspace
                                                                repo-slug
                                                                pipeline-uuid
                                                                step-uuid
                                                                test-case-uuid)
(list-pipelines-steps-test-reports-test-cases-test-case-reasons client
                                                                workspace
                                                                repo-slug
                                                                pipeline-uuid
                                                                step-uuid
                                                                test-case-uuid
                                                                opts)

Get test case reasons (output) for a given test case in a step of a pipeline. GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/test_reports/test_cases/{test_case_uuid}/test_case_reasons Path params: workspace, repo-slug, pipeline-uuid, step-uuid, test-case-uuid Query opts: passed through as query params (e.g. fields).

Get test case reasons (output) for a given test case in a step of a pipeline.
GET /2.0/repositories/{workspace}/{repo_slug}/pipelines/{pipeline_uuid}/steps/{step_uuid}/test_reports/test_cases/{test_case_uuid}/test_case_reasons
Path params: workspace, repo-slug, pipeline-uuid, step-uuid, test-case-uuid
Query opts: passed through as query params (e.g. fields).
sourceraw docstring

update-deployments-config-environments-variablesclj

(update-deployments-config-environments-variables client
                                                  workspace
                                                  repo-slug
                                                  environment-uuid
                                                  variable-uuid
                                                  body)
(update-deployments-config-environments-variables client
                                                  workspace
                                                  repo-slug
                                                  environment-uuid
                                                  variable-uuid
                                                  body
                                                  opts)

Update a variable for an environment. PUT /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables/{variable_uuid} Path params: workspace, repo-slug, environment-uuid, variable-uuid Body: deployment_variable

Update a variable for an environment.
PUT /2.0/repositories/{workspace}/{repo_slug}/deployments_config/environments/{environment_uuid}/variables/{variable_uuid}
Path params: workspace, repo-slug, environment-uuid, variable-uuid
Body: deployment_variable
sourceraw docstring

update-pipelines-configclj

(update-pipelines-config client workspace repo-slug body)
(update-pipelines-config client workspace repo-slug body opts)

Update configuration. PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config Path params: workspace, repo-slug Body: pipelines_config

Update configuration.
PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config
Path params: workspace, repo-slug
Body: pipelines_config
sourceraw docstring

update-pipelines-config-build-numberclj

(update-pipelines-config-build-number client workspace repo-slug body)
(update-pipelines-config-build-number client workspace repo-slug body opts)

Update the next build number. PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/build_number Path params: workspace, repo-slug Body: pipeline_build_number

Update the next build number.
PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/build_number
Path params: workspace, repo-slug
Body: pipeline_build_number
sourceraw docstring

update-pipelines-config-runners-by-workspace-repo-slug-runner-uuidclj

(update-pipelines-config-runners-by-workspace-repo-slug-runner-uuid client
                                                                    workspace
                                                                    repo-slug
                                                                    runner-uuid)

Update repository runner. PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners/{runner_uuid} Path params: workspace, repo-slug, runner-uuid

Update repository runner.
PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines-config/runners/{runner_uuid}
Path params: workspace, repo-slug, runner-uuid
sourceraw docstring

update-pipelines-config-runners-by-workspace-runner-uuidclj

(update-pipelines-config-runners-by-workspace-runner-uuid client
                                                          workspace
                                                          runner-uuid)

Update workspace runner. PUT /2.0/workspaces/{workspace}/pipelines-config/runners/{runner_uuid} Path params: workspace, runner-uuid

Update workspace runner.
PUT /2.0/workspaces/{workspace}/pipelines-config/runners/{runner_uuid}
Path params: workspace, runner-uuid
sourceraw docstring

update-pipelines-config-schedulesclj

(update-pipelines-config-schedules client
                                   workspace
                                   repo-slug
                                   schedule-uuid
                                   body)
(update-pipelines-config-schedules client
                                   workspace
                                   repo-slug
                                   schedule-uuid
                                   body
                                   opts)

Update a schedule. PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid} Path params: workspace, repo-slug, schedule-uuid Body: pipeline_schedule_put_request_body

Update a schedule.
PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/schedules/{schedule_uuid}
Path params: workspace, repo-slug, schedule-uuid
Body: pipeline_schedule_put_request_body
sourceraw docstring

update-pipelines-config-ssh-key-pairclj

(update-pipelines-config-ssh-key-pair client workspace repo-slug body)
(update-pipelines-config-ssh-key-pair client workspace repo-slug body opts)

Update SSH key pair. PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/key_pair Path params: workspace, repo-slug Body: pipeline_ssh_key_pair

Update SSH key pair.
PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/key_pair
Path params: workspace, repo-slug
Body: pipeline_ssh_key_pair
sourceraw docstring

update-pipelines-config-ssh-known-hostsclj

(update-pipelines-config-ssh-known-hosts client
                                         workspace
                                         repo-slug
                                         known-host-uuid
                                         body)
(update-pipelines-config-ssh-known-hosts client
                                         workspace
                                         repo-slug
                                         known-host-uuid
                                         body
                                         opts)

Update a known host. PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts/{known_host_uuid} Path params: workspace, repo-slug, known-host-uuid Body: pipeline_known_host

Update a known host.
PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/ssh/known_hosts/{known_host_uuid}
Path params: workspace, repo-slug, known-host-uuid
Body: pipeline_known_host
sourceraw docstring

update-pipelines-config-variables-by-selected-user-variable-uuidclj

(update-pipelines-config-variables-by-selected-user-variable-uuid client
                                                                  selected-user
                                                                  variable-uuid)

Update a variable for a user (deprecated). PUT /2.0/users/{selected_user}/pipelines_config/variables/{variable_uuid} Path params: selected-user, variable-uuid

Update a variable for a user (deprecated).
PUT /2.0/users/{selected_user}/pipelines_config/variables/{variable_uuid}
Path params: selected-user, variable-uuid
sourceraw docstring

update-pipelines-config-variables-by-username-variable-uuidclj

(update-pipelines-config-variables-by-username-variable-uuid client
                                                             username
                                                             variable-uuid)

Update a variable for a team (deprecated). PUT /2.0/teams/{username}/pipelines_config/variables/{variable_uuid} Path params: username, variable-uuid

Update a variable for a team (deprecated).
PUT /2.0/teams/{username}/pipelines_config/variables/{variable_uuid}
Path params: username, variable-uuid
sourceraw docstring

update-pipelines-config-variables-by-workspace-repo-slug-variable-uuidclj

(update-pipelines-config-variables-by-workspace-repo-slug-variable-uuid
  client
  workspace
  repo-slug
  variable-uuid
  body)
(update-pipelines-config-variables-by-workspace-repo-slug-variable-uuid
  client
  workspace
  repo-slug
  variable-uuid
  body
  opts)

Update a variable for a repository. PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables/{variable_uuid} Path params: workspace, repo-slug, variable-uuid Body: pipeline_variable

Update a variable for a repository.
PUT /2.0/repositories/{workspace}/{repo_slug}/pipelines_config/variables/{variable_uuid}
Path params: workspace, repo-slug, variable-uuid
Body: pipeline_variable
sourceraw docstring

update-pipelines-config-variables-by-workspace-variable-uuidclj

(update-pipelines-config-variables-by-workspace-variable-uuid client
                                                              workspace
                                                              variable-uuid)

Update variable for a workspace. PUT /2.0/workspaces/{workspace}/pipelines-config/variables/{variable_uuid} Path params: workspace, variable-uuid

Update variable for a workspace.
PUT /2.0/workspaces/{workspace}/pipelines-config/variables/{variable_uuid}
Path params: workspace, variable-uuid
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries