atlassian.bitbucket.refs

Bitbucket refs, branch-restrictions, and branching-model endpoint functions.

Covers:

  • Branch restrictions (/repositories/{workspace}/{repo_slug}/branch-restrictions)
  • Branching model (/repositories/{workspace}/{repo_slug}/branching-model)
  • Refs / branches / tags (/repositories/{workspace}/{repo_slug}/refs/...)
  • Project branching model (/workspaces/{workspace}/projects/{project_key}/branching-model)

Every fn delegates to atlassian.bitbucket.client/request. There is a single API surface — no :api key is used. Paginated list responses return {:values [...] :next "<full-url>" ...}; follow :next via atlassian.bitbucket.client/request-url.

Bitbucket refs, branch-restrictions, and branching-model endpoint functions.

Covers:
  - Branch restrictions  (/repositories/{workspace}/{repo_slug}/branch-restrictions)
  - Branching model      (/repositories/{workspace}/{repo_slug}/branching-model)
  - Refs / branches / tags (/repositories/{workspace}/{repo_slug}/refs/...)
  - Project branching model (/workspaces/{workspace}/projects/{project_key}/branching-model)

Every fn delegates to `atlassian.bitbucket.client/request`. There is a single
API surface — no :api key is used. Paginated list responses return
{:values [...] :next "<full-url>" ...}; follow :next via
`atlassian.bitbucket.client/request-url`.
raw docstring

create-branch-restrictionsclj

(create-branch-restrictions client workspace repo-slug body)
(create-branch-restrictions client workspace repo-slug body opts)

Create a branch restriction rule. POST /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions Path params: workspace, repo-slug Body: branchrestriction schema.

Create a branch restriction rule.
POST /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions
Path params: workspace, repo-slug
Body: branchrestriction schema.
sourceraw docstring

create-refs-branchesclj

(create-refs-branches client workspace repo-slug)
(create-refs-branches client workspace repo-slug opts)

Create a branch. POST /2.0/repositories/{workspace}/{repo_slug}/refs/branches Path params: workspace, repo-slug.

Create a branch.
POST /2.0/repositories/{workspace}/{repo_slug}/refs/branches
Path params: workspace, repo-slug.
sourceraw docstring

create-refs-tagsclj

(create-refs-tags client workspace repo-slug body)
(create-refs-tags client workspace repo-slug body opts)

Create a tag. POST /2.0/repositories/{workspace}/{repo_slug}/refs/tags Path params: workspace, repo-slug Body: tag schema.

Create a tag.
POST /2.0/repositories/{workspace}/{repo_slug}/refs/tags
Path params: workspace, repo-slug
Body: tag schema.
sourceraw docstring

delete-branch-restrictionsclj

(delete-branch-restrictions client workspace repo-slug id)
(delete-branch-restrictions client workspace repo-slug id opts)

Delete a branch restriction rule. DELETE /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions/{id} Path params: workspace, repo-slug, id.

Delete a branch restriction rule.
DELETE /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions/{id}
Path params: workspace, repo-slug, id.
sourceraw docstring

delete-refs-branchesclj

(delete-refs-branches client workspace repo-slug name)
(delete-refs-branches client workspace repo-slug name opts)

Delete a branch. DELETE /2.0/repositories/{workspace}/{repo_slug}/refs/branches/{name} Path params: workspace, repo-slug, name.

Delete a branch.
DELETE /2.0/repositories/{workspace}/{repo_slug}/refs/branches/{name}
Path params: workspace, repo-slug, name.
sourceraw docstring

delete-refs-tagsclj

(delete-refs-tags client workspace repo-slug name)
(delete-refs-tags client workspace repo-slug name opts)

Delete a tag. DELETE /2.0/repositories/{workspace}/{repo_slug}/refs/tags/{name} Path params: workspace, repo-slug, name.

Delete a tag.
DELETE /2.0/repositories/{workspace}/{repo_slug}/refs/tags/{name}
Path params: workspace, repo-slug, name.
sourceraw docstring

get-branch-restrictionsclj

(get-branch-restrictions client workspace repo-slug id)
(get-branch-restrictions client workspace repo-slug id opts)

Get a branch restriction rule. GET /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions/{id} Path params: workspace, repo-slug, id.

Get a branch restriction rule.
GET /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions/{id}
Path params: workspace, repo-slug, id.
sourceraw docstring

get-refs-branchesclj

(get-refs-branches client workspace repo-slug name)
(get-refs-branches client workspace repo-slug name opts)

Get a branch. GET /2.0/repositories/{workspace}/{repo_slug}/refs/branches/{name} Path params: workspace, repo-slug, name.

Get a branch.
GET /2.0/repositories/{workspace}/{repo_slug}/refs/branches/{name}
Path params: workspace, repo-slug, name.
sourceraw docstring

get-refs-tagsclj

(get-refs-tags client workspace repo-slug name)
(get-refs-tags client workspace repo-slug name opts)

Get a tag. GET /2.0/repositories/{workspace}/{repo_slug}/refs/tags/{name} Path params: workspace, repo-slug, name.

Get a tag.
GET /2.0/repositories/{workspace}/{repo_slug}/refs/tags/{name}
Path params: workspace, repo-slug, name.
sourceraw docstring

list-branch-restrictionsclj

(list-branch-restrictions client workspace repo-slug)
(list-branch-restrictions client workspace repo-slug opts)

List branch restrictions. GET /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions Path params: workspace, repo-slug Query opts: kind, pattern, page, pagelen, q, sort, fields.

List branch restrictions.
GET /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions
Path params: workspace, repo-slug
Query opts: kind, pattern, page, pagelen, q, sort, fields.
sourceraw docstring

list-branching-modelclj

(list-branching-model client workspace repo-slug)
(list-branching-model client workspace repo-slug opts)

Get the branching model for a repository. GET /2.0/repositories/{workspace}/{repo_slug}/branching-model Path params: workspace, repo-slug.

Get the branching model for a repository.
GET /2.0/repositories/{workspace}/{repo_slug}/branching-model
Path params: workspace, repo-slug.
sourceraw docstring

list-branching-model-settingsclj

(list-branching-model-settings client workspace repo-slug)
(list-branching-model-settings client workspace repo-slug opts)

Get the branching model config for a repository. GET /2.0/repositories/{workspace}/{repo_slug}/branching-model/settings Path params: workspace, repo-slug.

Get the branching model config for a repository.
GET /2.0/repositories/{workspace}/{repo_slug}/branching-model/settings
Path params: workspace, repo-slug.
sourceraw docstring

list-effective-branching-modelclj

(list-effective-branching-model client workspace repo-slug)
(list-effective-branching-model client workspace repo-slug opts)

Get the effective, or currently applied, branching model for a repository. GET /2.0/repositories/{workspace}/{repo_slug}/effective-branching-model Path params: workspace, repo-slug.

Get the effective, or currently applied, branching model for a repository.
GET /2.0/repositories/{workspace}/{repo_slug}/effective-branching-model
Path params: workspace, repo-slug.
sourceraw docstring

list-projects-branching-modelclj

(list-projects-branching-model client workspace project-key)
(list-projects-branching-model client workspace project-key opts)

Get the branching model for a project. GET /2.0/workspaces/{workspace}/projects/{project_key}/branching-model Path params: workspace, project-key.

Get the branching model for a project.
GET /2.0/workspaces/{workspace}/projects/{project_key}/branching-model
Path params: workspace, project-key.
sourceraw docstring

list-projects-branching-model-settingsclj

(list-projects-branching-model-settings client workspace project-key)
(list-projects-branching-model-settings client workspace project-key opts)

Get the branching model config for a project. GET /2.0/workspaces/{workspace}/projects/{project_key}/branching-model/settings Path params: workspace, project-key.

Get the branching model config for a project.
GET /2.0/workspaces/{workspace}/projects/{project_key}/branching-model/settings
Path params: workspace, project-key.
sourceraw docstring

list-refsclj

(list-refs client workspace repo-slug)
(list-refs client workspace repo-slug opts)

List branches and tags. GET /2.0/repositories/{workspace}/{repo_slug}/refs Path params: workspace, repo-slug Query opts: q, sort, page, pagelen, fields.

List branches and tags.
GET /2.0/repositories/{workspace}/{repo_slug}/refs
Path params: workspace, repo-slug
Query opts: q, sort, page, pagelen, fields.
sourceraw docstring

list-refs-branchesclj

(list-refs-branches client workspace repo-slug)
(list-refs-branches client workspace repo-slug opts)

List open branches. GET /2.0/repositories/{workspace}/{repo_slug}/refs/branches Path params: workspace, repo-slug Query opts: q, sort, page, pagelen, fields.

List open branches.
GET /2.0/repositories/{workspace}/{repo_slug}/refs/branches
Path params: workspace, repo-slug
Query opts: q, sort, page, pagelen, fields.
sourceraw docstring

list-refs-tagsclj

(list-refs-tags client workspace repo-slug)
(list-refs-tags client workspace repo-slug opts)

List tags. GET /2.0/repositories/{workspace}/{repo_slug}/refs/tags Path params: workspace, repo-slug Query opts: q, sort, page, pagelen, fields.

List tags.
GET /2.0/repositories/{workspace}/{repo_slug}/refs/tags
Path params: workspace, repo-slug
Query opts: q, sort, page, pagelen, fields.
sourceraw docstring

update-branch-restrictionsclj

(update-branch-restrictions client workspace repo-slug id body)
(update-branch-restrictions client workspace repo-slug id body opts)

Update a branch restriction rule. PUT /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions/{id} Path params: workspace, repo-slug, id Body: branchrestriction schema.

Update a branch restriction rule.
PUT /2.0/repositories/{workspace}/{repo_slug}/branch-restrictions/{id}
Path params: workspace, repo-slug, id
Body: branchrestriction schema.
sourceraw docstring

update-branching-model-settingsclj

(update-branching-model-settings client workspace repo-slug)
(update-branching-model-settings client workspace repo-slug opts)

Update the branching model config for a repository. PUT /2.0/repositories/{workspace}/{repo_slug}/branching-model/settings Path params: workspace, repo-slug.

Update the branching model config for a repository.
PUT /2.0/repositories/{workspace}/{repo_slug}/branching-model/settings
Path params: workspace, repo-slug.
sourceraw docstring

update-projects-branching-model-settingsclj

(update-projects-branching-model-settings client workspace project-key)
(update-projects-branching-model-settings client workspace project-key opts)

Update the branching model config for a project. PUT /2.0/workspaces/{workspace}/projects/{project_key}/branching-model/settings Path params: workspace, project-key.

Update the branching model config for a project.
PUT /2.0/workspaces/{workspace}/projects/{project_key}/branching-model/settings
Path params: workspace, project-key.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries