Confluence v1 admin endpoints: analytics, audit, long-running tasks, relations, settings (look-and-feel, themes), space labels/themes, and templates.
Confluence v1 admin endpoints: analytics, audit, long-running tasks, relations, settings (look-and-feel, themes), space labels/themes, and templates.
Confluence v1 Content API — archive, blueprint, search, macro, permissions, versions, and body conversion.
Confluence v1 Content API — archive, blueprint, search, macro, permissions, versions, and body conversion.
Confluence v1 content-children / descendants / attachment operations.
All fns delegate to atlassian.confluence.client/request with :api :v1.
Confluence v1 content-children / descendants / attachment operations. All fns delegate to `atlassian.confluence.client/request` with :api :v1.
Confluence Cloud v1 Content Restrictions API.
Manage read/update restrictions on content by operation, group, and user.
All list endpoints accept an optional expand query param.
Confluence Cloud v1 Content Restrictions API. Manage read/update restrictions on content by operation, group, and user. All list endpoints accept an optional `expand` query param.
Confluence v1 Content States API endpoint functions.
Confluence v1 Content States API endpoint functions.
Confluence v1 Content Watches API — watch status and watcher management for pages, spaces, labels, and content.
Confluence v1 Content Watches API — watch status and watcher management for pages, spaces, labels, and content.
Confluence v1 label endpoints: add/remove content labels, query label info.
Confluence v1 label endpoints: add/remove content labels, query label info.
Confluence v1 Search API — CQL-based search for content and users.
Confluence v1 Search API — CQL-based search for content and users.
Confluence v1 Spaces API — create, update, delete spaces and manage space permissions/settings.
Confluence v1 Spaces API — create, update, delete spaces and manage space permissions/settings.
Confluence v1 Users and Groups API — groups, group members, users, and user properties.
Confluence v1 Users and Groups API — groups, group members, users, and user properties.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |