atlassian.confluence.v1.admin

Confluence v1 admin endpoints: analytics, audit, long-running tasks, relations, settings (look-and-feel, themes), space labels/themes, and templates.

Confluence v1 admin endpoints: analytics, audit, long-running tasks,
relations, settings (look-and-feel, themes), space labels/themes, and templates.
raw docstring

add-labels-to-spaceclj

(add-labels-to-space client space-key body)
(add-labels-to-space client space-key body opts)

Add labels to a space. POST /wiki/rest/api/space/{spaceKey}/label Path params: spaceKey Body: array of label objects

Add labels to a space.
POST /wiki/rest/api/space/{spaceKey}/label
Path params: spaceKey
Body: array of label objects
sourceraw docstring

create-audit-recordclj

(create-audit-record client body)
(create-audit-record client body opts)

Create audit record. POST /wiki/rest/api/audit Body: AuditRecordCreate

Create audit record.
POST /wiki/rest/api/audit
Body: AuditRecordCreate
sourceraw docstring

create-content-templateclj

(create-content-template client body)
(create-content-template client body opts)

Create content template. POST /wiki/rest/api/template Body: ContentTemplateCreate

Create content template.
POST /wiki/rest/api/template
Body: ContentTemplateCreate
sourceraw docstring

create-relationshipclj

(create-relationship client
                     relation-name
                     source-type
                     source-key
                     target-type
                     target-key)
(create-relationship client
                     relation-name
                     source-type
                     source-key
                     target-type
                     target-key
                     opts)

Create a relationship between two entities. PUT /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey} Path params: relationName, sourceType, sourceKey, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion

Create a relationship between two entities.
PUT /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey}
Path params: relationName, sourceType, sourceKey, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion
sourceraw docstring

delete-label-from-spaceclj

(delete-label-from-space client space-key opts)

Remove label from a space. DELETE /wiki/rest/api/space/{spaceKey}/label Path params: spaceKey Query opts: name (required), prefix

Remove label from a space.
DELETE /wiki/rest/api/space/{spaceKey}/label
Path params: spaceKey
Query opts: name (required), prefix
sourceraw docstring

delete-page-treeclj

(delete-page-tree client id)

Delete page tree rooted at the given content id. DELETE /wiki/rest/api/content/{id}/pageTree Path params: id

Delete page tree rooted at the given content id.
DELETE /wiki/rest/api/content/{id}/pageTree
Path params: id
sourceraw docstring

delete-relationshipclj

(delete-relationship client
                     relation-name
                     source-type
                     source-key
                     target-type
                     target-key)
(delete-relationship client
                     relation-name
                     source-type
                     source-key
                     target-type
                     target-key
                     opts)

Delete a relationship. DELETE /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey} Path params: relationName, sourceType, sourceKey, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion

Delete a relationship.
DELETE /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey}
Path params: relationName, sourceType, sourceKey, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion
sourceraw docstring

export-audit-recordsclj

(export-audit-records client)
(export-audit-records client opts)

Export audit records. GET /wiki/rest/api/audit/export Query opts: startDate, endDate, searchString, format

Export audit records.
GET /wiki/rest/api/audit/export
Query opts: startDate, endDate, searchString, format
sourceraw docstring

find-sources-for-targetclj

(find-sources-for-target client
                         relation-name
                         target-type
                         target-key
                         source-type)
(find-sources-for-target client
                         relation-name
                         target-type
                         target-key
                         source-type
                         opts)

Find source entities related to a target entity. GET /wiki/rest/api/relation/{relationName}/to/{targetType}/{targetKey}/from/{sourceType} Path params: relationName, sourceType, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit

Find source entities related to a target entity.
GET /wiki/rest/api/relation/{relationName}/to/{targetType}/{targetKey}/from/{sourceType}
Path params: relationName, sourceType, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit
sourceraw docstring

find-target-from-sourceclj

(find-target-from-source client
                         relation-name
                         source-type
                         source-key
                         target-type)
(find-target-from-source client
                         relation-name
                         source-type
                         source-key
                         target-type
                         opts)

Find target entities related to a source entity. GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType} Path params: relationName, sourceType, sourceKey, targetType Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit

Find target entities related to a source entity.
GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}
Path params: relationName, sourceType, sourceKey, targetType
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit
sourceraw docstring

get-audit-recordsclj

(get-audit-records client)
(get-audit-records client opts)

Get audit records. GET /wiki/rest/api/audit Query opts: startDate, endDate, searchString, start, limit

Get audit records.
GET /wiki/rest/api/audit
Query opts: startDate, endDate, searchString, start, limit
sourceraw docstring

get-audit-records-for-time-periodclj

(get-audit-records-for-time-period client)
(get-audit-records-for-time-period client opts)

Get audit records for a time period. GET /wiki/rest/api/audit/since Query opts: number, units, searchString, start, limit

Get audit records for a time period.
GET /wiki/rest/api/audit/since
Query opts: number, units, searchString, start, limit
sourceraw docstring

get-blueprint-templatesclj

(get-blueprint-templates client)
(get-blueprint-templates client opts)

Get blueprint templates. GET /wiki/rest/api/template/blueprint Query opts: spaceKey, start, limit

Get blueprint templates.
GET /wiki/rest/api/template/blueprint
Query opts: spaceKey, start, limit
sourceraw docstring

get-content-templateclj

(get-content-template client content-template-id)

Get content template by id. GET /wiki/rest/api/template/{contentTemplateId} Path params: contentTemplateId

Get content template by id.
GET /wiki/rest/api/template/{contentTemplateId}
Path params: contentTemplateId
sourceraw docstring

get-content-templatesclj

(get-content-templates client)
(get-content-templates client opts)

Get content templates. GET /wiki/rest/api/template/page Query opts: spaceKey, start, limit

Get content templates.
GET /wiki/rest/api/template/page
Query opts: spaceKey, start, limit
sourceraw docstring

get-global-themeclj

(get-global-theme client)

Get global theme. GET /wiki/rest/api/settings/theme/selected

Get global theme.
GET /wiki/rest/api/settings/theme/selected
sourceraw docstring

get-labels-for-spaceclj

(get-labels-for-space client space-key)
(get-labels-for-space client space-key opts)

Get Space Labels. GET /wiki/rest/api/space/{spaceKey}/label Path params: spaceKey Query opts: prefix, start, limit

Get Space Labels.
GET /wiki/rest/api/space/{spaceKey}/label
Path params: spaceKey
Query opts: prefix, start, limit
sourceraw docstring

get-look-and-feel-settingsclj

(get-look-and-feel-settings client)
(get-look-and-feel-settings client opts)

Get look and feel settings. GET /wiki/rest/api/settings/lookandfeel Query opts: spaceKey

Get look and feel settings.
GET /wiki/rest/api/settings/lookandfeel
Query opts: spaceKey
sourceraw docstring

get-relationshipclj

(get-relationship client
                  relation-name
                  source-type
                  source-key
                  target-type
                  target-key)
(get-relationship client
                  relation-name
                  source-type
                  source-key
                  target-type
                  target-key
                  opts)

Find relationship from source to target. GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey} Path params: relationName, sourceType, sourceKey, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand

Find relationship from source to target.
GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey}
Path params: relationName, sourceType, sourceKey, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand
sourceraw docstring

get-retention-periodclj

(get-retention-period client)

Get retention period for audit records. GET /wiki/rest/api/audit/retention

Get retention period for audit records.
GET /wiki/rest/api/audit/retention
sourceraw docstring

get-space-themeclj

(get-space-theme client space-key)

Get space theme. GET /wiki/rest/api/space/{spaceKey}/theme Path params: spaceKey

Get space theme.
GET /wiki/rest/api/space/{spaceKey}/theme
Path params: spaceKey
sourceraw docstring

get-system-infoclj

(get-system-info client)

Get system info. GET /wiki/rest/api/settings/systemInfo

Get system info.
GET /wiki/rest/api/settings/systemInfo
sourceraw docstring

get-taskclj

(get-task client id)

Get a long-running task by id. GET /wiki/rest/api/longtask/{id} Path params: id

Get a long-running task by id.
GET /wiki/rest/api/longtask/{id}
Path params: id
sourceraw docstring

get-tasksclj

(get-tasks client)
(get-tasks client opts)

Get long-running tasks. GET /wiki/rest/api/longtask Query opts: key, start, limit

Get long-running tasks.
GET /wiki/rest/api/longtask
Query opts: key, start, limit
sourceraw docstring

get-themeclj

(get-theme client theme-key)

Get a theme by key. GET /wiki/rest/api/settings/theme/{themeKey} Path params: themeKey

Get a theme by key.
GET /wiki/rest/api/settings/theme/{themeKey}
Path params: themeKey
sourceraw docstring

get-themesclj

(get-themes client)
(get-themes client opts)

Get themes. GET /wiki/rest/api/settings/theme Query opts: start, limit

Get themes.
GET /wiki/rest/api/settings/theme
Query opts: start, limit
sourceraw docstring

get-viewersclj

(get-viewers client content-id)
(get-viewers client content-id opts)

Get viewers for a content item. GET /wiki/rest/api/analytics/content/{contentId}/viewers Path params: contentId Query opts: fromDate

Get viewers for a content item.
GET /wiki/rest/api/analytics/content/{contentId}/viewers
Path params: contentId
Query opts: fromDate
sourceraw docstring

get-viewsclj

(get-views client content-id)
(get-views client content-id opts)

Get views for a content item. GET /wiki/rest/api/analytics/content/{contentId}/views Path params: contentId Query opts: fromDate

Get views for a content item.
GET /wiki/rest/api/analytics/content/{contentId}/views
Path params: contentId
Query opts: fromDate
sourceraw docstring

remove-templateclj

(remove-template client content-template-id)

Remove template by id. DELETE /wiki/rest/api/template/{contentTemplateId} Path params: contentTemplateId

Remove template by id.
DELETE /wiki/rest/api/template/{contentTemplateId}
Path params: contentTemplateId
sourceraw docstring

reset-look-and-feel-settingsclj

(reset-look-and-feel-settings client)
(reset-look-and-feel-settings client opts)

Reset look and feel settings. DELETE /wiki/rest/api/settings/lookandfeel/custom Query opts: spaceKey

Reset look and feel settings.
DELETE /wiki/rest/api/settings/lookandfeel/custom
Query opts: spaceKey
sourceraw docstring

reset-space-themeclj

(reset-space-theme client space-key)

Reset space theme to default. DELETE /wiki/rest/api/space/{spaceKey}/theme Path params: spaceKey

Reset space theme to default.
DELETE /wiki/rest/api/space/{spaceKey}/theme
Path params: spaceKey
sourceraw docstring

set-retention-periodclj

(set-retention-period client body)
(set-retention-period client body opts)

Set retention period for audit records. PUT /wiki/rest/api/audit/retention Body: RetentionPeriod

Set retention period for audit records.
PUT /wiki/rest/api/audit/retention
Body: RetentionPeriod
sourceraw docstring

set-space-themeclj

(set-space-theme client space-key body)
(set-space-theme client space-key body opts)

Set space theme. PUT /wiki/rest/api/space/{spaceKey}/theme Path params: spaceKey Body: ThemeUpdate

Set space theme.
PUT /wiki/rest/api/space/{spaceKey}/theme
Path params: spaceKey
Body: ThemeUpdate
sourceraw docstring

update-content-templateclj

(update-content-template client body)
(update-content-template client body opts)

Update content template. PUT /wiki/rest/api/template Body: ContentTemplateUpdate

Update content template.
PUT /wiki/rest/api/template
Body: ContentTemplateUpdate
sourceraw docstring

update-look-and-feelclj

(update-look-and-feel client body)
(update-look-and-feel client body opts)

Select look and feel settings. PUT /wiki/rest/api/settings/lookandfeel Body: LookAndFeelSelection

Select look and feel settings.
PUT /wiki/rest/api/settings/lookandfeel
Body: LookAndFeelSelection
sourceraw docstring

update-look-and-feel-settingsclj

(update-look-and-feel-settings client body)
(update-look-and-feel-settings client body opts)

Update look and feel settings. POST /wiki/rest/api/settings/lookandfeel/custom Body: LookAndFeel Query opts: spaceKey

Update look and feel settings.
POST /wiki/rest/api/settings/lookandfeel/custom
Body: LookAndFeel
Query opts: spaceKey
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries