atlassian.confluence.v1.content-restrictions

Confluence Cloud v1 Content Restrictions API.

Manage read/update restrictions on content by operation, group, and user. All list endpoints accept an optional expand query param.

Confluence Cloud v1 Content Restrictions API.

Manage read/update restrictions on content by operation, group, and user.
All list endpoints accept an optional `expand` query param.
raw docstring

add-group-to-content-restriction-by-group-idclj

(add-group-to-content-restriction-by-group-id client id operation-key group-id)

Add group to content restriction. PUT /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/byGroupId/{groupId} Path params: id — content ID; operationKey — operation type; groupId — group ID.

Add group to content restriction. PUT /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/byGroupId/{groupId}
Path params: id — content ID; operationKey — operation type; groupId — group ID.
sourceraw docstring

add-restrictionsclj

(add-restrictions client id body)
(add-restrictions client id body opts)

Add restrictions. POST /wiki/rest/api/content/{id}/restriction Path params: id — content ID. Body: ContentRestrictionAddOrUpdateArray — array of restriction objects, e.g. [{:operation "read" :restrictions {:user {:results [...]} :group {:results [...]}}}]. Optional query opts: expand.

Add restrictions. POST /wiki/rest/api/content/{id}/restriction
Path params: id — content ID.
Body: ContentRestrictionAddOrUpdateArray — array of restriction objects,
  e.g. [{:operation "read" :restrictions {:user {:results [...]} :group {:results [...]}}}].
Optional query opts: expand.
sourceraw docstring

add-user-to-content-restrictionclj

(add-user-to-content-restriction client id operation-key)
(add-user-to-content-restriction client id operation-key opts)

Add user to content restriction. PUT /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/user Path params: id — content ID; operationKey — operation that the restriction applies to. Optional query opts: accountId, key, username (identify the user).

Add user to content restriction. PUT /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/user
Path params: id — content ID; operationKey — operation that the restriction applies to.
Optional query opts: accountId, key, username (identify the user).
sourceraw docstring

delete-restrictionsclj

(delete-restrictions client id)
(delete-restrictions client id opts)

Delete restrictions. DELETE /wiki/rest/api/content/{id}/restriction Path params: id — content ID. Optional query opts: expand.

Delete restrictions. DELETE /wiki/rest/api/content/{id}/restriction
Path params: id — content ID.
Optional query opts: expand.
sourceraw docstring

get-content-restriction-status-for-userclj

(get-content-restriction-status-for-user client id operation-key)
(get-content-restriction-status-for-user client id operation-key opts)

Get content restriction status for user. GET /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/user Path params: id — content ID; operationKey — operation that is restricted. Optional query opts: accountId, key, username (identify the user).

Get content restriction status for user. GET /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/user
Path params: id — content ID; operationKey — operation that is restricted.
Optional query opts: accountId, key, username (identify the user).
sourceraw docstring

get-individual-group-restriction-status-by-group-idclj

(get-individual-group-restriction-status-by-group-id client
                                                     id
                                                     operation-key
                                                     group-id)

Get content restriction status for group. GET /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/byGroupId/{groupId} Path params: id — content ID; operationKey — operation type; groupId — group ID.

Get content restriction status for group. GET /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/byGroupId/{groupId}
Path params: id — content ID; operationKey — operation type; groupId — group ID.
sourceraw docstring

get-restrictionsclj

(get-restrictions client id)
(get-restrictions client id opts)

Get restrictions. GET /wiki/rest/api/content/{id}/restriction Path params: id — content ID. Optional query opts: expand, start, limit.

Get restrictions. GET /wiki/rest/api/content/{id}/restriction
Path params: id — content ID.
Optional query opts: expand, start, limit.
sourceraw docstring

get-restrictions-by-operationclj

(get-restrictions-by-operation client id)
(get-restrictions-by-operation client id opts)

Get restrictions by operation. GET /wiki/rest/api/content/{id}/restriction/byOperation Path params: id — content ID. Optional query opts: expand.

Get restrictions by operation. GET /wiki/rest/api/content/{id}/restriction/byOperation
Path params: id — content ID.
Optional query opts: expand.
sourceraw docstring

get-restrictions-for-operationclj

(get-restrictions-for-operation client id operation-key)
(get-restrictions-for-operation client id operation-key opts)

Get restrictions for operation. GET /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey} Path params: id — content ID; operationKey — operation type (e.g. "read", "update"). Optional query opts: expand, start, limit.

Get restrictions for operation. GET /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}
Path params: id — content ID; operationKey — operation type (e.g. "read", "update").
Optional query opts: expand, start, limit.
sourceraw docstring

remove-group-from-content-restrictionclj

(remove-group-from-content-restriction client id operation-key group-id)

Remove group from content restriction. DELETE /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/byGroupId/{groupId} Path params: id — content ID; operationKey — operation type; groupId — group ID.

Remove group from content restriction. DELETE /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/byGroupId/{groupId}
Path params: id — content ID; operationKey — operation type; groupId — group ID.
sourceraw docstring

remove-user-from-content-restrictionclj

(remove-user-from-content-restriction client id operation-key)
(remove-user-from-content-restriction client id operation-key opts)

Remove user from content restriction. DELETE /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/user Path params: id — content ID; operationKey — operation type. Optional query opts: accountId, key, username (identify the user).

Remove user from content restriction. DELETE /wiki/rest/api/content/{id}/restriction/byOperation/{operationKey}/user
Path params: id — content ID; operationKey — operation type.
Optional query opts: accountId, key, username (identify the user).
sourceraw docstring

update-restrictionsclj

(update-restrictions client id body)
(update-restrictions client id body opts)

Update restrictions. PUT /wiki/rest/api/content/{id}/restriction Path params: id — content ID. Body: ContentRestrictionAddOrUpdateArray — array of restriction objects, e.g. [{:operation "read" :restrictions {:user {:results [...]} :group {:results [...]}}}]. Optional query opts: expand.

Update restrictions. PUT /wiki/rest/api/content/{id}/restriction
Path params: id — content ID.
Body: ContentRestrictionAddOrUpdateArray — array of restriction objects,
  e.g. [{:operation "read" :restrictions {:user {:results [...]} :group {:results [...]}}}].
Optional query opts: expand.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries