atlassian.confluence.v1.content-states

Confluence v1 Content States API endpoint functions.

Confluence v1 Content States API endpoint functions.
raw docstring

get-available-content-statesclj

(get-available-content-states client id)

Gets available content states for content. GET /wiki/rest/api/content/{id}/state/available Path params: id — id of content to get available states for.

Gets available content states for content.
GET /wiki/rest/api/content/{id}/state/available
Path params: id — id of content to get available states for.
sourceraw docstring

get-content-stateclj

(get-content-state client id)
(get-content-state client id opts)

Get content state. GET /wiki/rest/api/content/{id}/state Path params: id — the id of the content whose content state is of interest. Opts: :status — one of [current, draft, archived] (default: current).

Get content state.
GET /wiki/rest/api/content/{id}/state
Path params: id — the id of the content whose content state is of interest.
Opts: :status — one of [current, draft, archived] (default: current).
sourceraw docstring

get-content-state-settingsclj

(get-content-state-settings client space-key)

Get content state settings for space. GET /wiki/rest/api/space/{spaceKey}/state/settings Path params: spaceKey — the key of the space to be queried for its content state settings.

Get content state settings for space.
GET /wiki/rest/api/space/{spaceKey}/state/settings
Path params: spaceKey — the key of the space to be queried for its content state settings.
sourceraw docstring

get-contents-with-stateclj

(get-contents-with-state client space-key opts)

Get content in space with given content state. GET /wiki/rest/api/space/{spaceKey}/state/content Path params: spaceKey — the key of the space to be queried. Opts: :state-id (required) — id of the content state to filter by; :expand, :limit, :start.

Get content in space with given content state.
GET /wiki/rest/api/space/{spaceKey}/state/content
Path params: spaceKey — the key of the space to be queried.
Opts: :state-id (required) — id of the content state to filter by; :expand, :limit, :start.
sourceraw docstring

get-custom-content-statesclj

(get-custom-content-states client)

Get Custom Content States. GET /wiki/rest/api/content-states

Get Custom Content States.
GET /wiki/rest/api/content-states
sourceraw docstring

get-space-content-statesclj

(get-space-content-states client space-key)

Get space suggested content states. GET /wiki/rest/api/space/{spaceKey}/state Path params: spaceKey — the key of the space to be queried for its content state settings.

Get space suggested content states.
GET /wiki/rest/api/space/{spaceKey}/state
Path params: spaceKey — the key of the space to be queried for its content state settings.
sourceraw docstring

remove-content-stateclj

(remove-content-state client id)
(remove-content-state client id opts)

Removes the content state of a content and publishes a new version. DELETE /wiki/rest/api/content/{id}/state Path params: id — the Id of the content whose content state is to be set. Opts: :status — status of content state from which to delete state (draft or archived).

Removes the content state of a content and publishes a new version.
DELETE /wiki/rest/api/content/{id}/state
Path params: id — the Id of the content whose content state is to be set.
Opts: :status — status of content state from which to delete state (draft or archived).
sourceraw docstring

set-content-stateclj

(set-content-state client id body)
(set-content-state client id body opts)

Set the content state of a content and publishes a new version of the content. PUT /wiki/rest/api/content/{id}/state Path params: id — the Id of the content whose content state is to be set. Body: ContentStateRestInput — {:name string :color "#RRGGBB" :id int64} Opts: :status (required) — current or draft.

Set the content state of a content and publishes a new version of the content.
PUT /wiki/rest/api/content/{id}/state
Path params: id — the Id of the content whose content state is to be set.
Body: ContentStateRestInput — {:name string :color "#RRGGBB" :id int64}
Opts: :status (required) — current or draft.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries