Confluence v1 Content Watches API — watch status and watcher management for pages, spaces, labels, and content.
Confluence v1 Content Watches API — watch status and watcher management for pages, spaces, labels, and content.
(add-content-watcher client content-id)Add content watcher. POST /wiki/rest/api/user/watch/content/{contentId} Required path params: content-id (string). Note: requires X-Atlassian-Token header (XSRF protection).
Add content watcher. POST /wiki/rest/api/user/watch/content/{contentId}
Required path params: content-id (string).
Note: requires X-Atlassian-Token header (XSRF protection).(add-label-watcher client label-name)Add label watcher. POST /wiki/rest/api/user/watch/label/{labelName} Required path params: label-name (string). Note: requires X-Atlassian-Token header (XSRF protection).
Add label watcher. POST /wiki/rest/api/user/watch/label/{labelName}
Required path params: label-name (string).
Note: requires X-Atlassian-Token header (XSRF protection).(add-space-watcher client space-key)Add space watcher. POST /wiki/rest/api/user/watch/space/{spaceKey} Required path params: space-key (string). Note: requires X-Atlassian-Token header (XSRF protection).
Add space watcher. POST /wiki/rest/api/user/watch/space/{spaceKey}
Required path params: space-key (string).
Note: requires X-Atlassian-Token header (XSRF protection).(get-content-watch-status client content-id)Get content watch status. GET /wiki/rest/api/user/watch/content/{contentId} Required path params: content-id (string).
Get content watch status. GET /wiki/rest/api/user/watch/content/{contentId}
Required path params: content-id (string).(get-watchers-for-space client space-key)(get-watchers-for-space client space-key opts)Get space watchers. GET /wiki/rest/api/space/{spaceKey}/watch Required path params: spaceKey (string). Optional query params: start, limit.
Get space watchers. GET /wiki/rest/api/space/{spaceKey}/watch
Required path params: spaceKey (string).
Optional query params: start, limit.(get-watches-for-page client id)(get-watches-for-page client id opts)Get watches for page. GET /wiki/rest/api/content/{id}/notification/child-created Required path params: id (string). Optional query params: start, limit.
Get watches for page. GET /wiki/rest/api/content/{id}/notification/child-created
Required path params: id (string).
Optional query params: start, limit.(get-watches-for-space client id)(get-watches-for-space client id opts)Get watches for space. GET /wiki/rest/api/content/{id}/notification/created Required path params: id (string). Optional query params: start, limit.
Get watches for space. GET /wiki/rest/api/content/{id}/notification/created
Required path params: id (string).
Optional query params: start, limit.(is-watching-label client label-name)Get label watch status. GET /wiki/rest/api/user/watch/label/{labelName} Required path params: label-name (string).
Get label watch status. GET /wiki/rest/api/user/watch/label/{labelName}
Required path params: label-name (string).(is-watching-space client space-key)Get space watch status. GET /wiki/rest/api/user/watch/space/{spaceKey} Required path params: space-key (string).
Get space watch status. GET /wiki/rest/api/user/watch/space/{spaceKey}
Required path params: space-key (string).(remove-content-watcher client content-id)Remove content watcher. DELETE /wiki/rest/api/user/watch/content/{contentId} Required path params: content-id (string). Note: requires X-Atlassian-Token header (XSRF protection).
Remove content watcher. DELETE /wiki/rest/api/user/watch/content/{contentId}
Required path params: content-id (string).
Note: requires X-Atlassian-Token header (XSRF protection).(remove-label-watcher client label-name)Remove label watcher. DELETE /wiki/rest/api/user/watch/label/{labelName} Required path params: label-name (string).
Remove label watcher. DELETE /wiki/rest/api/user/watch/label/{labelName}
Required path params: label-name (string).(remove-space-watch client space-key)Remove space watch. DELETE /wiki/rest/api/user/watch/space/{spaceKey} Required path params: space-key (string).
Remove space watch. DELETE /wiki/rest/api/user/watch/space/{spaceKey}
Required path params: space-key (string).cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |