atlassian.confluence.v2.content-properties

Confluence Cloud v2 Content Properties API. Cursor-paginated list responses include :results and :_links {:next ...}; page with the cursor query param.

Confluence Cloud v2 Content Properties API.
Cursor-paginated list responses include :results and :_links {:next ...};
page with the `cursor` query param.
raw docstring

create-attachment-propertyclj

(create-attachment-property client attachment-id body)
(create-attachment-property client attachment-id body opts)

Create content property for attachment. POST /wiki/api/v2/attachments/{attachment-id}/properties Path params: attachment-id Body: ContentPropertyCreateRequest

Create content property for attachment.
POST /wiki/api/v2/attachments/{attachment-id}/properties
Path params: attachment-id
Body: ContentPropertyCreateRequest
sourceraw docstring

create-blogpost-propertyclj

(create-blogpost-property client blogpost-id body)
(create-blogpost-property client blogpost-id body opts)

Create content property for blog post. POST /wiki/api/v2/blogposts/{blogpost-id}/properties Path params: blogpost-id Body: ContentPropertyCreateRequest

Create content property for blog post.
POST /wiki/api/v2/blogposts/{blogpost-id}/properties
Path params: blogpost-id
Body: ContentPropertyCreateRequest
sourceraw docstring

create-comment-propertyclj

(create-comment-property client comment-id body)
(create-comment-property client comment-id body opts)

Create content property for comment. POST /wiki/api/v2/comments/{comment-id}/properties Path params: comment-id Body: ContentPropertyCreateRequest

Create content property for comment.
POST /wiki/api/v2/comments/{comment-id}/properties
Path params: comment-id
Body: ContentPropertyCreateRequest
sourceraw docstring

create-custom-content-propertyclj

(create-custom-content-property client custom-content-id body)
(create-custom-content-property client custom-content-id body opts)

Create content property for custom content. POST /wiki/api/v2/custom-content/{custom-content-id}/properties Path params: custom-content-id Body: ContentPropertyCreateRequest

Create content property for custom content.
POST /wiki/api/v2/custom-content/{custom-content-id}/properties
Path params: custom-content-id
Body: ContentPropertyCreateRequest
sourceraw docstring

create-database-propertyclj

(create-database-property client id body)
(create-database-property client id body opts)

Create content property for database. POST /wiki/api/v2/databases/{id}/properties Path params: id Body: ContentPropertyCreateRequest

Create content property for database.
POST /wiki/api/v2/databases/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest
sourceraw docstring

create-folder-propertyclj

(create-folder-property client id body)
(create-folder-property client id body opts)

Create content property for folder. POST /wiki/api/v2/folders/{id}/properties Path params: id Body: ContentPropertyCreateRequest

Create content property for folder.
POST /wiki/api/v2/folders/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest
sourceraw docstring

create-page-propertyclj

(create-page-property client page-id body)
(create-page-property client page-id body opts)

Create content property for page. POST /wiki/api/v2/pages/{page-id}/properties Path params: page-id Body: ContentPropertyCreateRequest

Create content property for page.
POST /wiki/api/v2/pages/{page-id}/properties
Path params: page-id
Body: ContentPropertyCreateRequest
sourceraw docstring

(create-smart-link-property client id body)
(create-smart-link-property client id body opts)

Create content property for Smart Link in the content tree. POST /wiki/api/v2/embeds/{id}/properties Path params: id Body: ContentPropertyCreateRequest

Create content property for Smart Link in the content tree.
POST /wiki/api/v2/embeds/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest
sourceraw docstring

create-whiteboard-propertyclj

(create-whiteboard-property client id body)
(create-whiteboard-property client id body opts)

Create content property for whiteboard. POST /wiki/api/v2/whiteboards/{id}/properties Path params: id Body: ContentPropertyCreateRequest

Create content property for whiteboard.
POST /wiki/api/v2/whiteboards/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest
sourceraw docstring

delete-attachment-property-by-idclj

(delete-attachment-property-by-id client attachment-id property-id)

Delete content property for attachment by id. DELETE /wiki/api/v2/attachments/{attachment-id}/properties/{property-id} Path params: attachment-id, property-id

Delete content property for attachment by id.
DELETE /wiki/api/v2/attachments/{attachment-id}/properties/{property-id}
Path params: attachment-id, property-id
sourceraw docstring

delete-blogpost-property-by-idclj

(delete-blogpost-property-by-id client blogpost-id property-id)

Delete content property for blogpost by id. DELETE /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id} Path params: blogpost-id, property-id

Delete content property for blogpost by id.
DELETE /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id}
Path params: blogpost-id, property-id
sourceraw docstring

delete-comment-property-by-idclj

(delete-comment-property-by-id client comment-id property-id)

Delete content property for comment by id. DELETE /wiki/api/v2/comments/{comment-id}/properties/{property-id} Path params: comment-id, property-id

Delete content property for comment by id.
DELETE /wiki/api/v2/comments/{comment-id}/properties/{property-id}
Path params: comment-id, property-id
sourceraw docstring

delete-custom-content-property-by-idclj

(delete-custom-content-property-by-id client custom-content-id property-id)

Delete content property for custom content by id. DELETE /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id} Path params: custom-content-id, property-id

Delete content property for custom content by id.
DELETE /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id}
Path params: custom-content-id, property-id
sourceraw docstring

delete-database-property-by-idclj

(delete-database-property-by-id client database-id property-id)

Delete content property for database by id. DELETE /wiki/api/v2/databases/{database-id}/properties/{property-id} Path params: database-id, property-id

Delete content property for database by id.
DELETE /wiki/api/v2/databases/{database-id}/properties/{property-id}
Path params: database-id, property-id
sourceraw docstring

delete-folder-property-by-idclj

(delete-folder-property-by-id client folder-id property-id)

Delete content property for folder by id. DELETE /wiki/api/v2/folders/{folder-id}/properties/{property-id} Path params: folder-id, property-id

Delete content property for folder by id.
DELETE /wiki/api/v2/folders/{folder-id}/properties/{property-id}
Path params: folder-id, property-id
sourceraw docstring

delete-page-property-by-idclj

(delete-page-property-by-id client page-id property-id)

Delete content property for page by id. DELETE /wiki/api/v2/pages/{page-id}/properties/{property-id} Path params: page-id, property-id

Delete content property for page by id.
DELETE /wiki/api/v2/pages/{page-id}/properties/{property-id}
Path params: page-id, property-id
sourceraw docstring

(delete-smart-link-property-by-id client embed-id property-id)

Delete content property for Smart Link in the content tree by id. DELETE /wiki/api/v2/embeds/{embed-id}/properties/{property-id} Path params: embed-id, property-id

Delete content property for Smart Link in the content tree by id.
DELETE /wiki/api/v2/embeds/{embed-id}/properties/{property-id}
Path params: embed-id, property-id
sourceraw docstring

delete-whiteboard-property-by-idclj

(delete-whiteboard-property-by-id client whiteboard-id property-id)

Delete content property for whiteboard by id. DELETE /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id} Path params: whiteboard-id, property-id

Delete content property for whiteboard by id.
DELETE /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id}
Path params: whiteboard-id, property-id
sourceraw docstring

get-attachment-content-propertiesclj

(get-attachment-content-properties client attachment-id)
(get-attachment-content-properties client attachment-id opts)

Get content properties for attachment. GET /wiki/api/v2/attachments/{attachment-id}/properties Path params: attachment-id Query opts: key, sort, cursor, limit

Get content properties for attachment.
GET /wiki/api/v2/attachments/{attachment-id}/properties
Path params: attachment-id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-attachment-content-properties-by-idclj

(get-attachment-content-properties-by-id client attachment-id property-id)

Get content property for attachment by id. GET /wiki/api/v2/attachments/{attachment-id}/properties/{property-id} Path params: attachment-id, property-id

Get content property for attachment by id.
GET /wiki/api/v2/attachments/{attachment-id}/properties/{property-id}
Path params: attachment-id, property-id
sourceraw docstring

get-blogpost-content-propertiesclj

(get-blogpost-content-properties client blogpost-id)
(get-blogpost-content-properties client blogpost-id opts)

Get content properties for blog post. GET /wiki/api/v2/blogposts/{blogpost-id}/properties Path params: blogpost-id Query opts: key, sort, cursor, limit

Get content properties for blog post.
GET /wiki/api/v2/blogposts/{blogpost-id}/properties
Path params: blogpost-id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-blogpost-content-properties-by-idclj

(get-blogpost-content-properties-by-id client blogpost-id property-id)

Get content property for blog post by id. GET /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id} Path params: blogpost-id, property-id

Get content property for blog post by id.
GET /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id}
Path params: blogpost-id, property-id
sourceraw docstring

get-comment-content-propertiesclj

(get-comment-content-properties client comment-id)
(get-comment-content-properties client comment-id opts)

Get content properties for comment. GET /wiki/api/v2/comments/{comment-id}/properties Path params: comment-id Query opts: key, sort, cursor, limit

Get content properties for comment.
GET /wiki/api/v2/comments/{comment-id}/properties
Path params: comment-id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-comment-content-properties-by-idclj

(get-comment-content-properties-by-id client comment-id property-id)

Get content property for comment by id. GET /wiki/api/v2/comments/{comment-id}/properties/{property-id} Path params: comment-id, property-id

Get content property for comment by id.
GET /wiki/api/v2/comments/{comment-id}/properties/{property-id}
Path params: comment-id, property-id
sourceraw docstring

get-custom-content-content-propertiesclj

(get-custom-content-content-properties client custom-content-id)
(get-custom-content-content-properties client custom-content-id opts)

Get content properties for custom content. GET /wiki/api/v2/custom-content/{custom-content-id}/properties Path params: custom-content-id Query opts: key, sort, cursor, limit

Get content properties for custom content.
GET /wiki/api/v2/custom-content/{custom-content-id}/properties
Path params: custom-content-id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-custom-content-content-properties-by-idclj

(get-custom-content-content-properties-by-id client
                                             custom-content-id
                                             property-id)

Get content property for custom content by id. GET /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id} Path params: custom-content-id, property-id

Get content property for custom content by id.
GET /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id}
Path params: custom-content-id, property-id
sourceraw docstring

get-database-content-propertiesclj

(get-database-content-properties client id)
(get-database-content-properties client id opts)

Get content properties for database. GET /wiki/api/v2/databases/{id}/properties Path params: id Query opts: key, sort, cursor, limit

Get content properties for database.
GET /wiki/api/v2/databases/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-database-content-properties-by-idclj

(get-database-content-properties-by-id client database-id property-id)

Get content property for database by id. GET /wiki/api/v2/databases/{database-id}/properties/{property-id} Path params: database-id, property-id

Get content property for database by id.
GET /wiki/api/v2/databases/{database-id}/properties/{property-id}
Path params: database-id, property-id
sourceraw docstring

get-folder-content-propertiesclj

(get-folder-content-properties client id)
(get-folder-content-properties client id opts)

Get content properties for folder. GET /wiki/api/v2/folders/{id}/properties Path params: id Query opts: key, sort, cursor, limit

Get content properties for folder.
GET /wiki/api/v2/folders/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-folder-content-properties-by-idclj

(get-folder-content-properties-by-id client folder-id property-id)

Get content property for folder by id. GET /wiki/api/v2/folders/{folder-id}/properties/{property-id} Path params: folder-id, property-id

Get content property for folder by id.
GET /wiki/api/v2/folders/{folder-id}/properties/{property-id}
Path params: folder-id, property-id
sourceraw docstring

get-page-content-propertiesclj

(get-page-content-properties client page-id)
(get-page-content-properties client page-id opts)

Get content properties for page. GET /wiki/api/v2/pages/{page-id}/properties Path params: page-id Query opts: key, sort, cursor, limit

Get content properties for page.
GET /wiki/api/v2/pages/{page-id}/properties
Path params: page-id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-page-content-properties-by-idclj

(get-page-content-properties-by-id client page-id property-id)

Get content property for page by id. GET /wiki/api/v2/pages/{page-id}/properties/{property-id} Path params: page-id, property-id

Get content property for page by id.
GET /wiki/api/v2/pages/{page-id}/properties/{property-id}
Path params: page-id, property-id
sourceraw docstring

(get-smart-link-content-properties client id)
(get-smart-link-content-properties client id opts)

Get content properties for Smart Link in the content tree. GET /wiki/api/v2/embeds/{id}/properties Path params: id Query opts: key, sort, cursor, limit

Get content properties for Smart Link in the content tree.
GET /wiki/api/v2/embeds/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit
sourceraw docstring

(get-smart-link-content-properties-by-id client embed-id property-id)

Get content property for Smart Link in the content tree by id. GET /wiki/api/v2/embeds/{embed-id}/properties/{property-id} Path params: embed-id, property-id

Get content property for Smart Link in the content tree by id.
GET /wiki/api/v2/embeds/{embed-id}/properties/{property-id}
Path params: embed-id, property-id
sourceraw docstring

get-whiteboard-content-propertiesclj

(get-whiteboard-content-properties client id)
(get-whiteboard-content-properties client id opts)

Get content properties for whiteboard. GET /wiki/api/v2/whiteboards/{id}/properties Path params: id Query opts: key, sort, cursor, limit

Get content properties for whiteboard.
GET /wiki/api/v2/whiteboards/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit
sourceraw docstring

get-whiteboard-content-properties-by-idclj

(get-whiteboard-content-properties-by-id client whiteboard-id property-id)

Get content property for whiteboard by id. GET /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id} Path params: whiteboard-id, property-id

Get content property for whiteboard by id.
GET /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id}
Path params: whiteboard-id, property-id
sourceraw docstring

update-attachment-property-by-idclj

(update-attachment-property-by-id client attachment-id property-id body)
(update-attachment-property-by-id client attachment-id property-id body opts)

Update content property for attachment by id. PUT /wiki/api/v2/attachments/{attachment-id}/properties/{property-id} Path params: attachment-id, property-id Body: ContentPropertyUpdateRequest

Update content property for attachment by id.
PUT /wiki/api/v2/attachments/{attachment-id}/properties/{property-id}
Path params: attachment-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

update-blogpost-property-by-idclj

(update-blogpost-property-by-id client blogpost-id property-id body)
(update-blogpost-property-by-id client blogpost-id property-id body opts)

Update content property for blog post by id. PUT /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id} Path params: blogpost-id, property-id Body: ContentPropertyUpdateRequest

Update content property for blog post by id.
PUT /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id}
Path params: blogpost-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

update-comment-property-by-idclj

(update-comment-property-by-id client comment-id property-id body)
(update-comment-property-by-id client comment-id property-id body opts)

Update content property for comment by id. PUT /wiki/api/v2/comments/{comment-id}/properties/{property-id} Path params: comment-id, property-id Body: ContentPropertyUpdateRequest

Update content property for comment by id.
PUT /wiki/api/v2/comments/{comment-id}/properties/{property-id}
Path params: comment-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

update-custom-content-property-by-idclj

(update-custom-content-property-by-id client custom-content-id property-id body)
(update-custom-content-property-by-id client
                                      custom-content-id
                                      property-id
                                      body
                                      opts)

Update content property for custom content by id. PUT /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id} Path params: custom-content-id, property-id Body: ContentPropertyUpdateRequest

Update content property for custom content by id.
PUT /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id}
Path params: custom-content-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

update-database-property-by-idclj

(update-database-property-by-id client database-id property-id body)
(update-database-property-by-id client database-id property-id body opts)

Update content property for database by id. PUT /wiki/api/v2/databases/{database-id}/properties/{property-id} Path params: database-id, property-id Body: ContentPropertyUpdateRequest

Update content property for database by id.
PUT /wiki/api/v2/databases/{database-id}/properties/{property-id}
Path params: database-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

update-folder-property-by-idclj

(update-folder-property-by-id client folder-id property-id body)
(update-folder-property-by-id client folder-id property-id body opts)

Update content property for folder by id. PUT /wiki/api/v2/folders/{folder-id}/properties/{property-id} Path params: folder-id, property-id Body: ContentPropertyUpdateRequest

Update content property for folder by id.
PUT /wiki/api/v2/folders/{folder-id}/properties/{property-id}
Path params: folder-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

update-page-property-by-idclj

(update-page-property-by-id client page-id property-id body)
(update-page-property-by-id client page-id property-id body opts)

Update content property for page by id. PUT /wiki/api/v2/pages/{page-id}/properties/{property-id} Path params: page-id, property-id Body: ContentPropertyUpdateRequest

Update content property for page by id.
PUT /wiki/api/v2/pages/{page-id}/properties/{property-id}
Path params: page-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

(update-smart-link-property-by-id client embed-id property-id body)
(update-smart-link-property-by-id client embed-id property-id body opts)

Update content property for Smart Link in the content tree by id. PUT /wiki/api/v2/embeds/{embed-id}/properties/{property-id} Path params: embed-id, property-id Body: ContentPropertyUpdateRequest

Update content property for Smart Link in the content tree by id.
PUT /wiki/api/v2/embeds/{embed-id}/properties/{property-id}
Path params: embed-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

update-whiteboard-property-by-idclj

(update-whiteboard-property-by-id client whiteboard-id property-id body)
(update-whiteboard-property-by-id client whiteboard-id property-id body opts)

Update content property for whiteboard by id. PUT /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id} Path params: whiteboard-id, property-id Body: ContentPropertyUpdateRequest

Update content property for whiteboard by id.
PUT /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id}
Path params: whiteboard-id, property-id
Body: ContentPropertyUpdateRequest
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries