atlassian.confluence.v2.custom-content

Confluence v2 Custom Content endpoint fns — one per operationId in v2-custom-content.edn.

Confluence v2 Custom Content endpoint fns — one per operationId in v2-custom-content.edn.
raw docstring

create-custom-contentclj

(create-custom-content client body)
(create-custom-content client body opts)

Create custom content. POST /wiki/api/v2/custom-content Body: custom content create request. Body :representation field: "storage" | "atlas_doc_format" | "wiki"

Create custom content.
POST /wiki/api/v2/custom-content
Body: custom content create request.
Body :representation field: "storage" | "atlas_doc_format" | "wiki"
sourceraw docstring

create-databaseclj

(create-database client body)
(create-database client body opts)

Create database. POST /wiki/api/v2/databases Body: database create request. Query opts: :private

Create database.
POST /wiki/api/v2/databases
Body: database create request.
Query opts: :private
sourceraw docstring

create-folderclj

(create-folder client body)
(create-folder client body opts)

Create folder. POST /wiki/api/v2/folders Body: folder create request.

Create folder.
POST /wiki/api/v2/folders
Body: folder create request.
sourceraw docstring

(create-smart-link client body)
(create-smart-link client body opts)

Create Smart Link in the content tree. POST /wiki/api/v2/embeds Body: smart link create request.

Create Smart Link in the content tree.
POST /wiki/api/v2/embeds
Body: smart link create request.
sourceraw docstring

create-whiteboardclj

(create-whiteboard client body)
(create-whiteboard client body opts)

Create whiteboard. POST /wiki/api/v2/whiteboards Body: whiteboard create request. Query opts: :private

Create whiteboard.
POST /wiki/api/v2/whiteboards
Body: whiteboard create request.
Query opts: :private
sourceraw docstring

delete-custom-contentclj

(delete-custom-content client id)
(delete-custom-content client id opts)

Delete custom content. DELETE /wiki/api/v2/custom-content/{id} Path params: id — The ID of the custom content to be deleted. Query opts: :purge

Delete custom content.
DELETE /wiki/api/v2/custom-content/{id}
Path params: id — The ID of the custom content to be deleted.
Query opts: :purge
sourceraw docstring

delete-databaseclj

(delete-database client id)

Delete database. DELETE /wiki/api/v2/databases/{id} Path params: id — The ID of the database to be deleted.

Delete database.
DELETE /wiki/api/v2/databases/{id}
Path params: id — The ID of the database to be deleted.
sourceraw docstring

delete-folderclj

(delete-folder client id)

Delete folder. DELETE /wiki/api/v2/folders/{id} Path params: id — The ID of the folder to be deleted.

Delete folder.
DELETE /wiki/api/v2/folders/{id}
Path params: id — The ID of the folder to be deleted.
sourceraw docstring

(delete-smart-link client id)

Delete Smart Link in the content tree. DELETE /wiki/api/v2/embeds/{id} Path params: id — The ID of the Smart Link to be deleted.

Delete Smart Link in the content tree.
DELETE /wiki/api/v2/embeds/{id}
Path params: id — The ID of the Smart Link to be deleted.
sourceraw docstring

delete-whiteboardclj

(delete-whiteboard client id)

Delete whiteboard. DELETE /wiki/api/v2/whiteboards/{id} Path params: id — The ID of the whiteboard to be deleted.

Delete whiteboard.
DELETE /wiki/api/v2/whiteboards/{id}
Path params: id — The ID of the whiteboard to be deleted.
sourceraw docstring

get-custom-content-by-idclj

(get-custom-content-by-id client id)
(get-custom-content-by-id client id opts)

Get custom content by id. GET /wiki/api/v2/custom-content/{id} Path params: id — The ID of the custom content. Query opts: :body-format :version :include-labels :include-properties :include-operations :include-versions :include-version :include-collaborators

Get custom content by id.
GET /wiki/api/v2/custom-content/{id}
Path params: id — The ID of the custom content.
Query opts: :body-format :version :include-labels :include-properties :include-operations :include-versions :include-version :include-collaborators
sourceraw docstring

get-custom-content-by-typeclj

(get-custom-content-by-type client)
(get-custom-content-by-type client opts)

Get custom content by type. GET /wiki/api/v2/custom-content Query opts: :type (required) :id :space-id :sort :cursor :limit :body-format

Get custom content by type.
GET /wiki/api/v2/custom-content
Query opts: :type (required) :id :space-id :sort :cursor :limit :body-format
sourceraw docstring

get-custom-content-by-type-in-blog-postclj

(get-custom-content-by-type-in-blog-post client id opts)

Get custom content by type in blog post. GET /wiki/api/v2/blogposts/{id}/custom-content Path params: id — The ID of the blog post. Query opts: :type (required) :sort :cursor :limit :body-format

Get custom content by type in blog post.
GET /wiki/api/v2/blogposts/{id}/custom-content
Path params: id — The ID of the blog post.
Query opts: :type (required) :sort :cursor :limit :body-format
sourceraw docstring

get-custom-content-by-type-in-pageclj

(get-custom-content-by-type-in-page client id opts)

Get custom content by type in page. GET /wiki/api/v2/pages/{id}/custom-content Path params: id — The ID of the page. Query opts: :type (required) :sort :cursor :limit :body-format

Get custom content by type in page.
GET /wiki/api/v2/pages/{id}/custom-content
Path params: id — The ID of the page.
Query opts: :type (required) :sort :cursor :limit :body-format
sourceraw docstring

get-custom-content-by-type-in-spaceclj

(get-custom-content-by-type-in-space client id opts)

Get custom content by type in space. GET /wiki/api/v2/spaces/{id}/custom-content Path params: id — The ID of the space. Query opts: :type (required) :cursor :limit :body-format

Get custom content by type in space.
GET /wiki/api/v2/spaces/{id}/custom-content
Path params: id — The ID of the space.
Query opts: :type (required) :cursor :limit :body-format
sourceraw docstring

get-database-by-idclj

(get-database-by-id client id)
(get-database-by-id client id opts)

Get database by id. GET /wiki/api/v2/databases/{id} Path params: id — The ID of the database. Query opts: :include-collaborators :include-direct-children :include-operations :include-properties

Get database by id.
GET /wiki/api/v2/databases/{id}
Path params: id — The ID of the database.
Query opts: :include-collaborators :include-direct-children :include-operations :include-properties
sourceraw docstring

get-folder-by-idclj

(get-folder-by-id client id)
(get-folder-by-id client id opts)

Get folder by id. GET /wiki/api/v2/folders/{id} Path params: id — The ID of the folder. Query opts: :include-collaborators :include-direct-children :include-operations :include-properties

Get folder by id.
GET /wiki/api/v2/folders/{id}
Path params: id — The ID of the folder.
Query opts: :include-collaborators :include-direct-children :include-operations :include-properties
sourceraw docstring

(get-smart-link-by-id client id)
(get-smart-link-by-id client id opts)

Get Smart Link in the content tree by id. GET /wiki/api/v2/embeds/{id} Path params: id — The ID of the Smart Link. Query opts: :include-collaborators :include-direct-children :include-operations :include-properties

Get Smart Link in the content tree by id.
GET /wiki/api/v2/embeds/{id}
Path params: id — The ID of the Smart Link.
Query opts: :include-collaborators :include-direct-children :include-operations :include-properties
sourceraw docstring

get-whiteboard-by-idclj

(get-whiteboard-by-id client id)
(get-whiteboard-by-id client id opts)

Get whiteboard by id. GET /wiki/api/v2/whiteboards/{id} Path params: id — The ID of the whiteboard. Query opts: :include-collaborators :include-direct-children :include-operations :include-properties

Get whiteboard by id.
GET /wiki/api/v2/whiteboards/{id}
Path params: id — The ID of the whiteboard.
Query opts: :include-collaborators :include-direct-children :include-operations :include-properties
sourceraw docstring

update-custom-contentclj

(update-custom-content client id body)
(update-custom-content client id body opts)

Update custom content. PUT /wiki/api/v2/custom-content/{id} Path params: id — The ID of the custom content to be updated. Body: custom content update request. Body :representation field: "storage" | "atlas_doc_format" | "wiki"

Update custom content.
PUT /wiki/api/v2/custom-content/{id}
Path params: id — The ID of the custom content to be updated.
Body: custom content update request.
Body :representation field: "storage" | "atlas_doc_format" | "wiki"
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries