atlassian.confluence.v2.hierarchy

Confluence v2 hierarchy endpoints: ancestors, descendants, children, and direct-children for pages, databases, folders, whiteboards, smart links, and custom content.

All list responses are cursor-paginated: {:results [...] :_links {:next ...}}. Page with the cursor query param; use atlassian.confluence.client/next-cursor to extract it from a response.

Confluence v2 hierarchy endpoints: ancestors, descendants, children, and
direct-children for pages, databases, folders, whiteboards, smart links,
and custom content.

All list responses are cursor-paginated: {:results [...] :_links {:next ...}}.
Page with the `cursor` query param; use `atlassian.confluence.client/next-cursor`
to extract it from a response.
raw docstring

get-child-custom-contentclj

(get-child-custom-content client id)
(get-child-custom-content client id opts)

Get child custom content. GET /wiki/api/v2/custom-content/{id}/children Path params: id (integer) — parent custom content ID. Accepts opts: cursor, limit, sort.

Get child custom content.
GET /wiki/api/v2/custom-content/{id}/children
Path params: id (integer) — parent custom content ID.
Accepts opts: cursor, limit, sort.
sourceraw docstring

get-child-pagesclj

(get-child-pages client id)
(get-child-pages client id opts)

Get child pages. DEPRECATED. GET /wiki/api/v2/pages/{id}/children Path params: id (integer) — parent page ID. Accepts opts: cursor, limit, sort.

Get child pages. DEPRECATED.
GET /wiki/api/v2/pages/{id}/children
Path params: id (integer) — parent page ID.
Accepts opts: cursor, limit, sort.
sourceraw docstring

get-database-ancestorsclj

(get-database-ancestors client id)
(get-database-ancestors client id opts)

Get all ancestors of database. GET /wiki/api/v2/databases/{id}/ancestors Path params: id (integer) — database ID. Accepts opts: limit.

Get all ancestors of database.
GET /wiki/api/v2/databases/{id}/ancestors
Path params: id (integer) — database ID.
Accepts opts: limit.
sourceraw docstring

get-database-descendantsclj

(get-database-descendants client id)
(get-database-descendants client id opts)

Get descendants of a database. GET /wiki/api/v2/databases/{id}/descendants Path params: id (integer) — database ID. Accepts opts: limit, depth, cursor.

Get descendants of a database.
GET /wiki/api/v2/databases/{id}/descendants
Path params: id (integer) — database ID.
Accepts opts: limit, depth, cursor.
sourceraw docstring

get-database-direct-childrenclj

(get-database-direct-children client id)
(get-database-direct-children client id opts)

Get direct children of a database. GET /wiki/api/v2/databases/{id}/direct-children Path params: id (integer) — parent database ID. Accepts opts: cursor, limit, sort.

Get direct children of a database.
GET /wiki/api/v2/databases/{id}/direct-children
Path params: id (integer) — parent database ID.
Accepts opts: cursor, limit, sort.
sourceraw docstring

get-folder-ancestorsclj

(get-folder-ancestors client id)
(get-folder-ancestors client id opts)

Get all ancestors of folder. GET /wiki/api/v2/folders/{id}/ancestors Path params: id (integer) — folder ID. Accepts opts: limit.

Get all ancestors of folder.
GET /wiki/api/v2/folders/{id}/ancestors
Path params: id (integer) — folder ID.
Accepts opts: limit.
sourceraw docstring

get-folder-descendantsclj

(get-folder-descendants client id)
(get-folder-descendants client id opts)

Get descendants of folder. GET /wiki/api/v2/folders/{id}/descendants Path params: id (integer) — folder ID. Accepts opts: limit, depth, cursor.

Get descendants of folder.
GET /wiki/api/v2/folders/{id}/descendants
Path params: id (integer) — folder ID.
Accepts opts: limit, depth, cursor.
sourceraw docstring

get-folder-direct-childrenclj

(get-folder-direct-children client id)
(get-folder-direct-children client id opts)

Get direct children of a folder. GET /wiki/api/v2/folders/{id}/direct-children Path params: id (integer) — parent folder ID. Accepts opts: cursor, limit, sort.

Get direct children of a folder.
GET /wiki/api/v2/folders/{id}/direct-children
Path params: id (integer) — parent folder ID.
Accepts opts: cursor, limit, sort.
sourceraw docstring

get-page-ancestorsclj

(get-page-ancestors client id)
(get-page-ancestors client id opts)

Get all ancestors of page. GET /wiki/api/v2/pages/{id}/ancestors Path params: id (integer) — page ID. Accepts opts: limit.

Get all ancestors of page.
GET /wiki/api/v2/pages/{id}/ancestors
Path params: id (integer) — page ID.
Accepts opts: limit.
sourceraw docstring

get-page-descendantsclj

(get-page-descendants client id)
(get-page-descendants client id opts)

Get descendants of page. GET /wiki/api/v2/pages/{id}/descendants Path params: id (integer) — page ID. Accepts opts: limit, depth, cursor.

Get descendants of page.
GET /wiki/api/v2/pages/{id}/descendants
Path params: id (integer) — page ID.
Accepts opts: limit, depth, cursor.
sourceraw docstring

get-page-direct-childrenclj

(get-page-direct-children client id)
(get-page-direct-children client id opts)

Get direct children of a page. GET /wiki/api/v2/pages/{id}/direct-children Path params: id (integer) — parent page ID. Accepts opts: cursor, limit, sort.

Get direct children of a page.
GET /wiki/api/v2/pages/{id}/direct-children
Path params: id (integer) — parent page ID.
Accepts opts: cursor, limit, sort.
sourceraw docstring

(get-smart-link-ancestors client id)
(get-smart-link-ancestors client id opts)

Get all ancestors of Smart Link in content tree. GET /wiki/api/v2/embeds/{id}/ancestors Path params: id (integer) — smart link ID. Accepts opts: limit.

Get all ancestors of Smart Link in content tree.
GET /wiki/api/v2/embeds/{id}/ancestors
Path params: id (integer) — smart link ID.
Accepts opts: limit.
sourceraw docstring

(get-smart-link-descendants client id)
(get-smart-link-descendants client id opts)

Get descendants of a smart link. GET /wiki/api/v2/embeds/{id}/descendants Path params: id (integer) — smart link ID. Accepts opts: limit, depth, cursor.

Get descendants of a smart link.
GET /wiki/api/v2/embeds/{id}/descendants
Path params: id (integer) — smart link ID.
Accepts opts: limit, depth, cursor.
sourceraw docstring

(get-smart-link-direct-children client id)
(get-smart-link-direct-children client id opts)

Get direct children of a Smart Link. GET /wiki/api/v2/embeds/{id}/direct-children Path params: id (integer) — parent smart link ID. Accepts opts: cursor, limit, sort.

Get direct children of a Smart Link.
GET /wiki/api/v2/embeds/{id}/direct-children
Path params: id (integer) — parent smart link ID.
Accepts opts: cursor, limit, sort.
sourceraw docstring

get-whiteboard-ancestorsclj

(get-whiteboard-ancestors client id)
(get-whiteboard-ancestors client id opts)

Get all ancestors of whiteboard. GET /wiki/api/v2/whiteboards/{id}/ancestors Path params: id (integer) — whiteboard ID. Accepts opts: limit.

Get all ancestors of whiteboard.
GET /wiki/api/v2/whiteboards/{id}/ancestors
Path params: id (integer) — whiteboard ID.
Accepts opts: limit.
sourceraw docstring

get-whiteboard-descendantsclj

(get-whiteboard-descendants client id)
(get-whiteboard-descendants client id opts)

Get descendants of a whiteboard. GET /wiki/api/v2/whiteboards/{id}/descendants Path params: id (integer) — whiteboard ID. Accepts opts: limit, depth, cursor.

Get descendants of a whiteboard.
GET /wiki/api/v2/whiteboards/{id}/descendants
Path params: id (integer) — whiteboard ID.
Accepts opts: limit, depth, cursor.
sourceraw docstring

get-whiteboard-direct-childrenclj

(get-whiteboard-direct-children client id)
(get-whiteboard-direct-children client id opts)

Get direct children of a whiteboard. GET /wiki/api/v2/whiteboards/{id}/direct-children Path params: id (integer) — parent whiteboard ID. Accepts opts: cursor, limit, sort.

Get direct children of a whiteboard.
GET /wiki/api/v2/whiteboards/{id}/direct-children
Path params: id (integer) — parent whiteboard ID.
Accepts opts: cursor, limit, sort.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries