Confluence v2 Space endpoint fns — one per operationId in v2-spaces.edn.
Confluence v2 Space endpoint fns — one per operationId in v2-spaces.edn.
(create-space client body)(create-space client body opts)Create space. POST /wiki/api/v2/spaces Body: space definition object
Create space. POST /wiki/api/v2/spaces Body: space definition object
(create-space-property client space-id body)(create-space-property client space-id body opts)Create space property in space. POST /wiki/api/v2/spaces/{space-id}/properties Path params: space-id — The ID of the space for which space properties should be returned. Body: SpacePropertyCreateRequest {:key string :value any}
Create space property in space.
POST /wiki/api/v2/spaces/{space-id}/properties
Path params: space-id — The ID of the space for which space properties should be returned.
Body: SpacePropertyCreateRequest {:key string :value any}(create-space-role client body)(create-space-role client body opts)Create a space role. POST /wiki/api/v2/space-roles Body: object (space role definition)
Create a space role. POST /wiki/api/v2/space-roles Body: object (space role definition)
(delete-space-property-by-id client space-id property-id)Delete space property by id. DELETE /wiki/api/v2/spaces/{space-id}/properties/{property-id} Path params: space-id — The ID of the space the property belongs to. property-id — The ID of the property to be deleted.
Delete space property by id.
DELETE /wiki/api/v2/spaces/{space-id}/properties/{property-id}
Path params: space-id — The ID of the space the property belongs to.
property-id — The ID of the property to be deleted.(delete-space-role client id)Delete a space role. DELETE /wiki/api/v2/space-roles/{id} Path params: id — Id of the space role
Delete a space role.
DELETE /wiki/api/v2/space-roles/{id}
Path params: id — Id of the space role(get-available-space-permissions client)(get-available-space-permissions client opts)Get available space permissions. GET /wiki/api/v2/space-permissions Query opts: :cursor :limit
Get available space permissions. GET /wiki/api/v2/space-permissions Query opts: :cursor :limit
(get-available-space-roles client)(get-available-space-roles client opts)Get available space roles. GET /wiki/api/v2/space-roles Query opts: :space-id :role-type :principal-id :principal-type :cursor :limit
Get available space roles. GET /wiki/api/v2/space-roles Query opts: :space-id :role-type :principal-id :principal-type :cursor :limit
(get-space-by-id client id)(get-space-by-id client id opts)Get space by id. GET /wiki/api/v2/spaces/{id} Path params: id — The ID of the space to be returned. Query opts: :description-format :include-icon :include-operations :include-properties :include-permissions :include-role-assignments :include-labels
Get space by id.
GET /wiki/api/v2/spaces/{id}
Path params: id — The ID of the space to be returned.
Query opts: :description-format :include-icon :include-operations
:include-properties :include-permissions :include-role-assignments
:include-labels(get-space-permissions-assignments client id)(get-space-permissions-assignments client id opts)Get space permissions assignments. GET /wiki/api/v2/spaces/{id}/permissions Path params: id — The ID of the space to be returned. Query opts: :cursor :limit
Get space permissions assignments.
GET /wiki/api/v2/spaces/{id}/permissions
Path params: id — The ID of the space to be returned.
Query opts: :cursor :limit(get-space-properties client space-id)(get-space-properties client space-id opts)Get space properties in space. GET /wiki/api/v2/spaces/{space-id}/properties Path params: space-id — The ID of the space for which space properties should be returned. Query opts: :key :cursor :limit
Get space properties in space.
GET /wiki/api/v2/spaces/{space-id}/properties
Path params: space-id — The ID of the space for which space properties should be returned.
Query opts: :key :cursor :limit(get-space-property-by-id client space-id property-id)Get space property by id. GET /wiki/api/v2/spaces/{space-id}/properties/{property-id} Path params: space-id — The ID of the space the property belongs to. property-id — The ID of the property to be retrieved.
Get space property by id.
GET /wiki/api/v2/spaces/{space-id}/properties/{property-id}
Path params: space-id — The ID of the space the property belongs to.
property-id — The ID of the property to be retrieved.(get-space-role-assignments client id)(get-space-role-assignments client id opts)Get space role assignments. GET /wiki/api/v2/spaces/{id}/role-assignments Path params: id — The ID of the space for which to retrieve assignments. Query opts: :role-id :role-type :principal-id :principal-type :cursor :limit
Get space role assignments.
GET /wiki/api/v2/spaces/{id}/role-assignments
Path params: id — The ID of the space for which to retrieve assignments.
Query opts: :role-id :role-type :principal-id :principal-type :cursor :limit(get-space-role-mode client)Get space role mode. GET /wiki/api/v2/space-role-mode
Get space role mode. GET /wiki/api/v2/space-role-mode
(get-space-roles-by-id client id)Get space role by ID. GET /wiki/api/v2/space-roles/{id} Path params: id — The ID of the space role to retrieve.
Get space role by ID.
GET /wiki/api/v2/space-roles/{id}
Path params: id — The ID of the space role to retrieve.(get-spaces client)(get-spaces client opts)Get spaces. GET /wiki/api/v2/spaces Query opts: :ids :keys :type :status :labels :favorited-by :not-favorited-by :sort :description-format :include-icon :cursor :limit Cursor-paginated: response has :results and :_links {:next ...}.
Get spaces.
GET /wiki/api/v2/spaces
Query opts: :ids :keys :type :status :labels :favorited-by :not-favorited-by
:sort :description-format :include-icon :cursor :limit
Cursor-paginated: response has :results and :_links {:next ...}.(set-space-role-assignments client id body)(set-space-role-assignments client id body opts)Set space role assignments. POST /wiki/api/v2/spaces/{id}/role-assignments Path params: id — The ID of the space for which to retrieve assignments. Body: role assignments object
Set space role assignments.
POST /wiki/api/v2/spaces/{id}/role-assignments
Path params: id — The ID of the space for which to retrieve assignments.
Body: role assignments object(update-space-property-by-id client space-id property-id body)(update-space-property-by-id client space-id property-id body opts)Update space property by id. PUT /wiki/api/v2/spaces/{space-id}/properties/{property-id} Path params: space-id — The ID of the space the property belongs to. property-id — The ID of the property to be updated. Body: SpacePropertyUpdateRequest {:key string :value any :version {:number int :message string}}
Update space property by id.
PUT /wiki/api/v2/spaces/{space-id}/properties/{property-id}
Path params: space-id — The ID of the space the property belongs to.
property-id — The ID of the property to be updated.
Body: SpacePropertyUpdateRequest {:key string :value any :version {:number int :message string}}(update-space-role client id body)(update-space-role client id body opts)Update a space role. PUT /wiki/api/v2/space-roles/{id} Path params: id — Id of the space role Body: object (space role update)
Update a space role.
PUT /wiki/api/v2/space-roles/{id}
Path params: id — Id of the space role
Body: object (space role update)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |