atlassian.jira.fields

Jira Cloud REST API — Issue fields, custom field contexts, and custom field options endpoint functions.

Every function delegates to atlassian.jira.client/request. Build a client with (atlassian.jira.client/client) and pass it as the first argument.

Jira Cloud REST API — Issue fields, custom field contexts, and custom field
options endpoint functions.

Every function delegates to `atlassian.jira.client/request`. Build a client
with `(atlassian.jira.client/client)` and pass it as the first argument.
raw docstring

add-issue-types-to-contextclj

(add-issue-types-to-context client field-id context-id body)
(add-issue-types-to-context client field-id context-id body opts)

Add issue types to context. Adds issue types to a custom field context. PUT /rest/api/3/field/{fieldId}/context/{contextId}/issuetype Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: IssueTypeIds — {:issueTypeIds ["10000" ...]}

Add issue types to context. Adds issue types to a custom field context.
PUT /rest/api/3/field/{fieldId}/context/{contextId}/issuetype
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: IssueTypeIds — {:issueTypeIds ["10000" ...]}
sourceraw docstring

assign-projects-to-custom-field-contextclj

(assign-projects-to-custom-field-context client field-id context-id body)
(assign-projects-to-custom-field-context client field-id context-id body opts)

Assign custom field context to projects. Assigns a custom field context to projects. PUT /rest/api/3/field/{fieldId}/context/{contextId}/project Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: ProjectIds — {:projectIds ["10000" ...]}

Assign custom field context to projects. Assigns a custom field context to projects.
PUT /rest/api/3/field/{fieldId}/context/{contextId}/project
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: ProjectIds — {:projectIds ["10000" ...]}
sourceraw docstring

create-custom-fieldclj

(create-custom-field client body)
(create-custom-field client body opts)

Create custom field. Creates a custom field. POST /rest/api/3/field Body: CustomFieldDefinitionJsonBean — {:name, :description, :type, :searcherKey}

Create custom field. Creates a custom field.
POST /rest/api/3/field
Body: CustomFieldDefinitionJsonBean — {:name, :description, :type, :searcherKey}
sourceraw docstring

create-custom-field-contextclj

(create-custom-field-context client field-id body)
(create-custom-field-context client field-id body opts)

Create custom field context. Creates a custom field context. POST /rest/api/3/field/{fieldId}/context Path params: fieldId — The ID of the custom field. Body: CreateCustomFieldContext — {:name, :description, :projectIds, :issueTypeIds}

Create custom field context. Creates a custom field context.
POST /rest/api/3/field/{fieldId}/context
Path params: fieldId — The ID of the custom field.
Body: CreateCustomFieldContext — {:name, :description, :projectIds, :issueTypeIds}
sourceraw docstring

create-custom-field-optionclj

(create-custom-field-option client field-id context-id body)
(create-custom-field-option client field-id context-id body opts)

Create custom field options (context). Creates options and, where the custom select field is of the group picker type, groups for a custom field. POST /rest/api/3/field/{fieldId}/context/{contextId}/option Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: BulkCustomFieldOptionCreateRequest — {:options [{:value, :disabled}]}

Create custom field options (context). Creates options and, where the custom select field is of the group picker type, groups for a custom field.
POST /rest/api/3/field/{fieldId}/context/{contextId}/option
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: BulkCustomFieldOptionCreateRequest — {:options [{:value, :disabled}]}
sourceraw docstring

delete-custom-fieldclj

(delete-custom-field client id)

Delete custom field. Deletes a custom field. The field is placed in the trash. DELETE /rest/api/3/field/{id} Path params: id — The ID of a custom field.

Delete custom field. Deletes a custom field. The field is placed in the trash.
DELETE /rest/api/3/field/{id}
Path params: id — The ID of a custom field.
sourceraw docstring

delete-custom-field-contextclj

(delete-custom-field-context client field-id context-id)

Delete custom field context. Deletes a custom field context. DELETE /rest/api/3/field/{fieldId}/context/{contextId} Path params: fieldId — The ID of the custom field. contextId — The ID of the context.

Delete custom field context. Deletes a custom field context.
DELETE /rest/api/3/field/{fieldId}/context/{contextId}
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
sourceraw docstring

delete-custom-field-optionclj

(delete-custom-field-option client field-id context-id option-id)

Delete custom field options (context). Deletes a custom field option. DELETE /rest/api/3/field/{fieldId}/context/{contextId}/option/{optionId} Path params: fieldId — The ID of the custom field. contextId — The ID of the context. optionId — The ID of the option.

Delete custom field options (context). Deletes a custom field option.
DELETE /rest/api/3/field/{fieldId}/context/{contextId}/option/{optionId}
Path params: fieldId — The ID of the custom field. contextId — The ID of the context. optionId — The ID of the option.
sourceraw docstring

get-contexts-for-fieldclj

(get-contexts-for-field client field-id)
(get-contexts-for-field client field-id opts)

Get custom field contexts. Returns a paginated list of contexts for a custom field. GET /rest/api/3/field/{fieldId}/context Path params: fieldId — The ID of the custom field. opts: isAnyIssueType, isGlobalContext, contextId, startAt, maxResults

Get custom field contexts. Returns a paginated list of contexts for a custom field.
GET /rest/api/3/field/{fieldId}/context
Path params: fieldId — The ID of the custom field.
opts: isAnyIssueType, isGlobalContext, contextId, startAt, maxResults
sourceraw docstring

get-contexts-for-field-deprecatedclj

(get-contexts-for-field-deprecated client field-id)
(get-contexts-for-field-deprecated client field-id opts)

Get contexts for a field. DEPRECATED: Returns a paginated list of contexts for a field. GET /rest/api/3/field/{fieldId}/contexts Path params: fieldId — The ID of the field to return contexts for. opts: startAt, maxResults

Get contexts for a field. DEPRECATED: Returns a paginated list of contexts for a field.
GET /rest/api/3/field/{fieldId}/contexts
Path params: fieldId — The ID of the field to return contexts for.
opts: startAt, maxResults
sourceraw docstring

get-custom-field-contexts-for-projects-and-issue-typesclj

(get-custom-field-contexts-for-projects-and-issue-types client field-id body)
(get-custom-field-contexts-for-projects-and-issue-types client
                                                        field-id
                                                        body
                                                        opts)

Get custom field contexts for projects and issue types. POST /rest/api/3/field/{fieldId}/context/mapping Path params: fieldId — The ID of the custom field. Body: ProjectIssueTypeMappings — {:mappings [{:projectId, :issueTypeIds}]} opts: startAt, maxResults

Get custom field contexts for projects and issue types.
POST /rest/api/3/field/{fieldId}/context/mapping
Path params: fieldId — The ID of the custom field.
Body: ProjectIssueTypeMappings — {:mappings [{:projectId, :issueTypeIds}]}
opts: startAt, maxResults
sourceraw docstring

get-custom-field-optionclj

(get-custom-field-option client id)

Get custom field option. GET /rest/api/3/customFieldOption/{id} Path params: id — The ID of the custom field option.

Get custom field option.
GET /rest/api/3/customFieldOption/{id}
Path params: id — The ID of the custom field option.
sourceraw docstring

get-default-valuesclj

(get-default-values client field-id)
(get-default-values client field-id opts)

Get custom field contexts default values. DEPRECATED: Returns default values for a custom field. GET /rest/api/3/field/{fieldId}/context/defaultValue Path params: fieldId — The ID of the custom field. opts: contextId, startAt, maxResults

Get custom field contexts default values. DEPRECATED: Returns default values for a custom field.
GET /rest/api/3/field/{fieldId}/context/defaultValue
Path params: fieldId — The ID of the custom field.
opts: contextId, startAt, maxResults
sourceraw docstring

get-field-project-associationsclj

(get-field-project-associations client field-id)
(get-field-project-associations client field-id opts)

Get field project associations. Returns the projects associated with a field. GET /rest/api/3/field/{fieldId}/association/project Path params: fieldId — The ID of the field. opts: startAt, maxResults

Get field project associations. Returns the projects associated with a field.
GET /rest/api/3/field/{fieldId}/association/project
Path params: fieldId — The ID of the field.
opts: startAt, maxResults
sourceraw docstring

get-fieldsclj

(get-fields client)

Get fields. Returns system and custom issue fields. GET /rest/api/3/field

Get fields. Returns system and custom issue fields.
GET /rest/api/3/field
sourceraw docstring

get-fields-paginatedclj

(get-fields-paginated client)
(get-fields-paginated client opts)

Get fields paginated. Returns a paginated list of fields for Classic Jira projects. GET /rest/api/3/field/search opts: startAt, maxResults, type, id, query, orderBy, expand, projectIds

Get fields paginated. Returns a paginated list of fields for Classic Jira projects.
GET /rest/api/3/field/search
opts: startAt, maxResults, type, id, query, orderBy, expand, projectIds
sourceraw docstring

get-issue-type-mappings-for-contextsclj

(get-issue-type-mappings-for-contexts client field-id)
(get-issue-type-mappings-for-contexts client field-id opts)

Get issue types for custom field context. Returns a paginated list of context-to-issue-type mappings. GET /rest/api/3/field/{fieldId}/context/issuetypemapping Path params: fieldId — The ID of the custom field. opts: contextId, startAt, maxResults

Get issue types for custom field context. Returns a paginated list of context-to-issue-type mappings.
GET /rest/api/3/field/{fieldId}/context/issuetypemapping
Path params: fieldId — The ID of the custom field.
opts: contextId, startAt, maxResults
sourceraw docstring

get-options-for-contextclj

(get-options-for-context client field-id context-id)
(get-options-for-context client field-id context-id opts)

Get custom field options (context). Returns a paginated list of all custom field option for a context. GET /rest/api/3/field/{fieldId}/context/{contextId}/option Path params: fieldId — The ID of the custom field. contextId — The ID of the context. opts: optionId, onlyOptions, startAt, maxResults

Get custom field options (context). Returns a paginated list of all custom field option for a context.
GET /rest/api/3/field/{fieldId}/context/{contextId}/option
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
opts: optionId, onlyOptions, startAt, maxResults
sourceraw docstring

get-project-context-mappingclj

(get-project-context-mapping client field-id)
(get-project-context-mapping client field-id opts)

Get project mappings for custom field context. Returns a paginated list of context-to-project mappings. GET /rest/api/3/field/{fieldId}/context/projectmapping Path params: fieldId — The ID of the custom field. opts: contextId, startAt, maxResults

Get project mappings for custom field context. Returns a paginated list of context-to-project mappings.
GET /rest/api/3/field/{fieldId}/context/projectmapping
Path params: fieldId — The ID of the custom field.
opts: contextId, startAt, maxResults
sourceraw docstring

get-project-fieldsclj

(get-project-fields client opts)

Get fields for projects. Returns fields and their configuration for projects. GET /rest/api/3/projects/fields opts: startAt, maxResults, projectId (required), workTypeId (required), fieldId

Get fields for projects. Returns fields and their configuration for projects.
GET /rest/api/3/projects/fields
opts: startAt, maxResults, projectId (required), workTypeId (required), fieldId
sourceraw docstring

get-trashed-fields-paginatedclj

(get-trashed-fields-paginated client)
(get-trashed-fields-paginated client opts)

Get fields in trash paginated. Returns a paginated list of fields in the trash. GET /rest/api/3/field/search/trashed opts: startAt, maxResults, id, query, expand, orderBy

Get fields in trash paginated. Returns a paginated list of fields in the trash.
GET /rest/api/3/field/search/trashed
opts: startAt, maxResults, id, query, expand, orderBy
sourceraw docstring

remove-custom-field-context-from-projectsclj

(remove-custom-field-context-from-projects client field-id context-id body)
(remove-custom-field-context-from-projects client field-id context-id body opts)

Remove custom field context from projects. Removes a custom field context from projects. POST /rest/api/3/field/{fieldId}/context/{contextId}/project/remove Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: ProjectIds — {:projectIds ["10000" ...]}

Remove custom field context from projects. Removes a custom field context from projects.
POST /rest/api/3/field/{fieldId}/context/{contextId}/project/remove
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: ProjectIds — {:projectIds ["10000" ...]}
sourceraw docstring

remove-issue-types-from-contextclj

(remove-issue-types-from-context client field-id context-id body)
(remove-issue-types-from-context client field-id context-id body opts)

Remove issue types from context. Removes issue types from a custom field context. POST /rest/api/3/field/{fieldId}/context/{contextId}/issuetype/remove Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: IssueTypeIds — {:issueTypeIds ["10000" ...]}

Remove issue types from context. Removes issue types from a custom field context.
POST /rest/api/3/field/{fieldId}/context/{contextId}/issuetype/remove
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: IssueTypeIds — {:issueTypeIds ["10000" ...]}
sourceraw docstring

reorder-custom-field-optionsclj

(reorder-custom-field-options client field-id context-id body)
(reorder-custom-field-options client field-id context-id body opts)

Reorder custom field options (context). Changes the order of custom field options or cascading options. PUT /rest/api/3/field/{fieldId}/context/{contextId}/option/move Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: OrderOfCustomFieldOptions — {:customFieldOptionIds [...], :position, :after}

Reorder custom field options (context). Changes the order of custom field options or cascading options.
PUT /rest/api/3/field/{fieldId}/context/{contextId}/option/move
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: OrderOfCustomFieldOptions — {:customFieldOptionIds [...], :position, :after}
sourceraw docstring

replace-custom-field-optionclj

(replace-custom-field-option client field-id context-id option-id)
(replace-custom-field-option client field-id context-id option-id opts)

Replace custom field options. Deselects a custom field option from all issues where it is selected. DELETE /rest/api/3/field/{fieldId}/context/{contextId}/option/{optionId}/issue Path params: fieldId — The ID of the custom field. contextId — The ID of the context. optionId — The ID of the option. opts: replaceWith, jql

Replace custom field options. Deselects a custom field option from all issues where it is selected.
DELETE /rest/api/3/field/{fieldId}/context/{contextId}/option/{optionId}/issue
Path params: fieldId — The ID of the custom field. contextId — The ID of the context. optionId — The ID of the option.
opts: replaceWith, jql
sourceraw docstring

restore-custom-fieldclj

(restore-custom-field client id)

Restore custom field from trash. Restores a custom field from trash. POST /rest/api/3/field/{id}/restore Path params: id — The ID of a custom field.

Restore custom field from trash. Restores a custom field from trash.
POST /rest/api/3/field/{id}/restore
Path params: id — The ID of a custom field.
sourceraw docstring

set-default-valuesclj

(set-default-values client field-id body)
(set-default-values client field-id body opts)

Set custom field contexts default values. DEPRECATED: Sets default values for a custom field. PUT /rest/api/3/field/{fieldId}/context/defaultValue Path params: fieldId — The ID of the custom field. Body: CustomFieldContextDefaultValueUpdate — {:defaultValues [...]}

Set custom field contexts default values. DEPRECATED: Sets default values for a custom field.
PUT /rest/api/3/field/{fieldId}/context/defaultValue
Path params: fieldId — The ID of the custom field.
Body: CustomFieldContextDefaultValueUpdate — {:defaultValues [...]}
sourceraw docstring

trash-custom-fieldclj

(trash-custom-field client id)

Move custom field to trash. Moves a custom field to trash. POST /rest/api/3/field/{id}/trash Path params: id — The ID of a custom field.

Move custom field to trash. Moves a custom field to trash.
POST /rest/api/3/field/{id}/trash
Path params: id — The ID of a custom field.
sourceraw docstring

update-custom-fieldclj

(update-custom-field client field-id body)
(update-custom-field client field-id body opts)

Update custom field. Updates a custom field. PUT /rest/api/3/field/{fieldId} Path params: fieldId — The ID of the custom field. Body: UpdateCustomFieldDetails — {:name, :description, :searcherKey}

Update custom field. Updates a custom field.
PUT /rest/api/3/field/{fieldId}
Path params: fieldId — The ID of the custom field.
Body: UpdateCustomFieldDetails — {:name, :description, :searcherKey}
sourceraw docstring

update-custom-field-contextclj

(update-custom-field-context client field-id context-id body)
(update-custom-field-context client field-id context-id body opts)

Update custom field context. Updates a custom field context. PUT /rest/api/3/field/{fieldId}/context/{contextId} Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: CustomFieldContextUpdateDetails — {:name, :description}

Update custom field context. Updates a custom field context.
PUT /rest/api/3/field/{fieldId}/context/{contextId}
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: CustomFieldContextUpdateDetails — {:name, :description}
sourceraw docstring

update-custom-field-optionclj

(update-custom-field-option client field-id context-id body)
(update-custom-field-option client field-id context-id body opts)

Update custom field options (context). Updates the options of a custom field. PUT /rest/api/3/field/{fieldId}/context/{contextId}/option Path params: fieldId — The ID of the custom field. contextId — The ID of the context. Body: BulkCustomFieldOptionUpdateRequest — {:options [{:id, :value, :disabled}]}

Update custom field options (context). Updates the options of a custom field.
PUT /rest/api/3/field/{fieldId}/context/{contextId}/option
Path params: fieldId — The ID of the custom field. contextId — The ID of the context.
Body: BulkCustomFieldOptionUpdateRequest — {:options [{:id, :value, :disabled}]}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries