atlassian.jira.filters

Jira Cloud Filters + Filter Sharing API.

One public function per operation in /rest/api/3/filter. Build a client with atlassian.jira.client/client, then call any function here with it as the first argument.

Jira Cloud Filters + Filter Sharing API.

One public function per operation in /rest/api/3/filter. Build a client with
`atlassian.jira.client/client`, then call any function here with it as the
first argument.
raw docstring

add-share-permissionclj

(add-share-permission client id body)

Add share permission. POST /rest/api/3/filter/{id}/permission

Path params: id — the ID of the filter. Body: SharePermissionInputBean — required keys: :type. Optional: :accountId :groupId :groupname :projectId :projectRoleId :rights.

Add share permission.
POST /rest/api/3/filter/{id}/permission

Path params: id — the ID of the filter.
Body: SharePermissionInputBean — required keys: :type. Optional:
:accountId :groupId :groupname :projectId :projectRoleId :rights.
sourceraw docstring

change-filter-ownerclj

(change-filter-owner client id body)

Change filter owner. PUT /rest/api/3/filter/{id}/owner

Path params: id — the ID of the filter to update. Body: ChangeFilterOwner — required keys: :accountId.

Change filter owner.
PUT /rest/api/3/filter/{id}/owner

Path params: id — the ID of the filter to update.
Body: ChangeFilterOwner — required keys: :accountId.
sourceraw docstring

create-filterclj

(create-filter client body)
(create-filter client body opts)

Create filter. POST /rest/api/3/filter

Body: Filter — required keys: :name. Optional: :description, :jql, :sharePermissions, :editPermissions, :favourite.

Create filter.
POST /rest/api/3/filter

Body: Filter — required keys: :name. Optional: :description, :jql,
:sharePermissions, :editPermissions, :favourite.
sourceraw docstring

delete-favourite-for-filterclj

(delete-favourite-for-filter client id)
(delete-favourite-for-filter client id opts)

Remove filter as favorite. DELETE /rest/api/3/filter/{id}/favourite

Path params: id — the ID of the filter. opts: :expand.

Remove filter as favorite.
DELETE /rest/api/3/filter/{id}/favourite

Path params: id — the ID of the filter.
opts: :expand.
sourceraw docstring

delete-filterclj

(delete-filter client id)

Delete filter. DELETE /rest/api/3/filter/{id}

Path params: id — the ID of the filter to delete.

Delete filter.
DELETE /rest/api/3/filter/{id}

Path params: id — the ID of the filter to delete.
sourceraw docstring

delete-share-permissionclj

(delete-share-permission client id permission-id)

Delete share permission. DELETE /rest/api/3/filter/{id}/permission/{permissionId}

Path params: id — the ID of the filter; permissionId — the ID of the share permission.

Delete share permission.
DELETE /rest/api/3/filter/{id}/permission/{permissionId}

Path params: id — the ID of the filter; permissionId — the ID of the
share permission.
sourceraw docstring

get-columnsclj

(get-columns client id)

Get columns. GET /rest/api/3/filter/{id}/columns

Returns the columns for a filter. Path params: id.

Get columns.
GET /rest/api/3/filter/{id}/columns

Returns the columns for a filter. Path params: id.
sourceraw docstring

get-default-share-scopeclj

(get-default-share-scope client)

Get default share scope. GET /rest/api/3/filter/defaultShareScope

Get default share scope.
GET /rest/api/3/filter/defaultShareScope
sourceraw docstring

get-favourite-filtersclj

(get-favourite-filters client)
(get-favourite-filters client opts)

Get favorite filters. GET /rest/api/3/filter/favourite

opts: :expand (comma-separated string).

Get favorite filters.
GET /rest/api/3/filter/favourite

opts: :expand (comma-separated string).
sourceraw docstring

get-filterclj

(get-filter client id)
(get-filter client id opts)

Get filter. GET /rest/api/3/filter/{id}

Path params: id — the ID of the filter to return. opts: :expand :overrideSharePermissions.

Get filter.
GET /rest/api/3/filter/{id}

Path params: id — the ID of the filter to return.
opts: :expand :overrideSharePermissions.
sourceraw docstring

get-filters-paginatedclj

(get-filters-paginated client)
(get-filters-paginated client opts)

Search for filters. GET /rest/api/3/filter/search

opts: :filterName :accountId :owner :groupname :groupId :projectId :id :orderBy :startAt :maxResults :expand :overrideSharePermissions :isSubstringMatch.

Search for filters.
GET /rest/api/3/filter/search

opts: :filterName :accountId :owner :groupname :groupId :projectId :id
      :orderBy :startAt :maxResults :expand :overrideSharePermissions
      :isSubstringMatch.
sourceraw docstring

get-my-filtersclj

(get-my-filters client)
(get-my-filters client opts)

Get my filters. GET /rest/api/3/filter/my

opts: :expand (comma-separated string), :includeFavourites (boolean).

Get my filters.
GET /rest/api/3/filter/my

opts: :expand (comma-separated string), :includeFavourites (boolean).
sourceraw docstring

get-share-permissionclj

(get-share-permission client id permission-id)

Get share permission. GET /rest/api/3/filter/{id}/permission/{permissionId}

Path params: id — the ID of the filter; permissionId — the ID of the share permission.

Get share permission.
GET /rest/api/3/filter/{id}/permission/{permissionId}

Path params: id — the ID of the filter; permissionId — the ID of the
share permission.
sourceraw docstring

get-share-permissionsclj

(get-share-permissions client id)

Get share permissions. GET /rest/api/3/filter/{id}/permission

Path params: id — the ID of the filter.

Get share permissions.
GET /rest/api/3/filter/{id}/permission

Path params: id — the ID of the filter.
sourceraw docstring

reset-columnsclj

(reset-columns client id)

Reset columns. DELETE /rest/api/3/filter/{id}/columns

Resets the columns for the filter to the default. Path params: id.

Reset columns.
DELETE /rest/api/3/filter/{id}/columns

Resets the columns for the filter to the default. Path params: id.
sourceraw docstring

set-columnsclj

(set-columns client id body)

Set columns. PUT /rest/api/3/filter/{id}/columns

Path params: id — the ID of the filter. Body: ColumnRequestBody — keys: :columns (array of column objects).

Set columns.
PUT /rest/api/3/filter/{id}/columns

Path params: id — the ID of the filter.
Body: ColumnRequestBody — keys: :columns (array of column objects).
sourceraw docstring

set-default-share-scopeclj

(set-default-share-scope client body)

Set default share scope. PUT /rest/api/3/filter/defaultShareScope

Body: DefaultShareScope — required keys: :scope.

Set default share scope.
PUT /rest/api/3/filter/defaultShareScope

Body: DefaultShareScope — required keys: :scope.
sourceraw docstring

set-favourite-for-filterclj

(set-favourite-for-filter client id)
(set-favourite-for-filter client id opts)

Add filter as favorite. PUT /rest/api/3/filter/{id}/favourite

Path params: id — the ID of the filter. opts: :expand.

Add filter as favorite.
PUT /rest/api/3/filter/{id}/favourite

Path params: id — the ID of the filter.
opts: :expand.
sourceraw docstring

update-filterclj

(update-filter client id body)
(update-filter client id body opts)

Update filter. PUT /rest/api/3/filter/{id}

Path params: id — the ID of the filter to update. Body: Filter — required keys: :name. Optional: :description, :jql, :sharePermissions, :editPermissions, :favourite. opts: :expand :overrideSharePermissions.

Update filter.
PUT /rest/api/3/filter/{id}

Path params: id — the ID of the filter to update.
Body: Filter — required keys: :name. Optional: :description, :jql,
:sharePermissions, :editPermissions, :favourite.
opts: :expand :overrideSharePermissions.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries