atlassian.jira.issues

Jira Issues API — one public fn per operation in the Issues group.

All fns take a client (built via atlassian.jira.client/client) as the first arg, then required path params, then an optional opts map for query params and/or a body map for write operations.

Description/comment fields that accept rich text expect ADF documents. Use atlassian.jira.adf/text->adf to build one from a plain string.

Jira Issues API — one public fn per operation in the Issues group.

All fns take a `client` (built via `atlassian.jira.client/client`) as the
first arg, then required path params, then an optional `opts` map for query
params and/or a `body` map for write operations.

Description/comment fields that accept rich text expect ADF documents.
Use `atlassian.jira.adf/text->adf` to build one from a plain string.
raw docstring

archive-issuesclj

(archive-issues client body)
(archive-issues client body opts)

Archive issue(s) by issue ID/key (sync). PUT /rest/api/3/issue/archive Body: IssueArchivalSyncRequest — {:issueIdsOrKeys ["PROJ-1" "PROJ-2"]}

Archive issue(s) by issue ID/key (sync).
PUT /rest/api/3/issue/archive
Body: IssueArchivalSyncRequest — {:issueIdsOrKeys ["PROJ-1" "PROJ-2"]}
sourceraw docstring

archive-issues-asyncclj

(archive-issues-async client body)
(archive-issues-async client body opts)

Archive issue(s) by JQL (async). POST /rest/api/3/issue/archive Body: ArchiveIssueAsyncRequest — {:jql "project = PROJ AND status = Done"}

Archive issue(s) by JQL (async).
POST /rest/api/3/issue/archive
Body: ArchiveIssueAsyncRequest — {:jql "project = PROJ AND status = Done"}
sourceraw docstring

assign-issueclj

(assign-issue client issue-id-or-key body)
(assign-issue client issue-id-or-key body opts)

Assign issue to a user. Pass {:accountId nil} to unassign. PUT /rest/api/3/issue/{issueIdOrKey}/assignee Path: issueIdOrKey — the ID or key of the issue. Body: User — {:accountId "5b10a..."}

Assign issue to a user. Pass `{:accountId nil}` to unassign.
PUT /rest/api/3/issue/{issueIdOrKey}/assignee
Path: issueIdOrKey — the ID or key of the issue.
Body: User — {:accountId "5b10a..."}
sourceraw docstring

bulk-fetch-issuesclj

(bulk-fetch-issues client body)
(bulk-fetch-issues client body opts)

Bulk fetch issues by ID or key. POST /rest/api/3/issue/bulkfetch Body: BulkFetchIssueRequestBean — {:issueIdsOrKeys [...] :fields [...] :expand "..."}

Bulk fetch issues by ID or key.
POST /rest/api/3/issue/bulkfetch
Body: BulkFetchIssueRequestBean — {:issueIdsOrKeys [...] :fields [...] :expand "..."}
sourceraw docstring

create-issueclj

(create-issue client body)
(create-issue client body opts)

Create issue. POST /rest/api/3/issue Body: IssueUpdateDetails — {:fields {:project {:key "PROJ"} :summary "..." :issuetype {:name "Bug"} :description <ADF>}} The description field is ADF; use atlassian.jira.adf/text->adf for plain text. opts: {:updateHistory bool}

Create issue.
POST /rest/api/3/issue
Body: IssueUpdateDetails — {:fields {:project {:key "PROJ"} :summary "..." :issuetype {:name "Bug"} :description <ADF>}}
The `description` field is ADF; use `atlassian.jira.adf/text->adf` for plain text.
opts: {:updateHistory bool}
sourceraw docstring

create-issuesclj

(create-issues client body)
(create-issues client body opts)

Bulk create issues. POST /rest/api/3/issue/bulk Body: IssuesUpdateBean — {:issueUpdates [{:fields {...}} ...]}

Bulk create issues.
POST /rest/api/3/issue/bulk
Body: IssuesUpdateBean — {:issueUpdates [{:fields {...}} ...]}
sourceraw docstring

delete-issueclj

(delete-issue client issue-id-or-key)
(delete-issue client issue-id-or-key opts)

Delete issue. DELETE /rest/api/3/issue/{issueIdOrKey} Path: issueIdOrKey — the ID or key of the issue. opts: {:deleteSubtasks "true"|"false"}

Delete issue.
DELETE /rest/api/3/issue/{issueIdOrKey}
Path: issueIdOrKey — the ID or key of the issue.
opts: {:deleteSubtasks "true"|"false"}
sourceraw docstring

do-transitionclj

(do-transition client issue-id-or-key body)
(do-transition client issue-id-or-key body opts)

Transition issue to a new status. POST /rest/api/3/issue/{issueIdOrKey}/transitions Path: issueIdOrKey — the ID or key of the issue. Body: IssueUpdateDetails — {:transition {:id "21"} :fields {...} :update {...}}

Transition issue to a new status.
POST /rest/api/3/issue/{issueIdOrKey}/transitions
Path: issueIdOrKey — the ID or key of the issue.
Body: IssueUpdateDetails — {:transition {:id "21"} :fields {...} :update {...}}
sourceraw docstring

edit-issueclj

(edit-issue client issue-id-or-key body)
(edit-issue client issue-id-or-key body opts)

Edit issue. PUT /rest/api/3/issue/{issueIdOrKey} Path: issueIdOrKey — the ID or key of the issue. Body: IssueUpdateDetails — {:fields {:summary "New summary" :description <ADF>} :update {...}} The description field is ADF; use atlassian.jira.adf/text->adf for plain text. opts: {:notifyUsers bool :overrideScreenSecurity bool :overrideEditableFlag bool :returnIssue bool :expand "..."}

Edit issue.
PUT /rest/api/3/issue/{issueIdOrKey}
Path: issueIdOrKey — the ID or key of the issue.
Body: IssueUpdateDetails — {:fields {:summary "New summary" :description <ADF>} :update {...}}
The `description` field is ADF; use `atlassian.jira.adf/text->adf` for plain text.
opts: {:notifyUsers bool :overrideScreenSecurity bool :overrideEditableFlag bool :returnIssue bool :expand "..."}
sourceraw docstring

export-archived-issuesclj

(export-archived-issues client body)
(export-archived-issues client body opts)

Export archived issue(s). PUT /rest/api/3/issues/archive/export Body: ArchivedIssuesFilterRequest — {:archivedBy [...] :archivedDateRange {:dateAfter "..." :dateBefore "..."} :issueTypes [...] :projects [...] :reporters [...]}

Export archived issue(s).
PUT /rest/api/3/issues/archive/export
Body: ArchivedIssuesFilterRequest — {:archivedBy [...] :archivedDateRange {:dateAfter "..." :dateBefore "..."} :issueTypes [...] :projects [...] :reporters [...]}
sourceraw docstring

get-bulk-changelogsclj

(get-bulk-changelogs client body)
(get-bulk-changelogs client body opts)

Bulk fetch changelogs for a list of issues. POST /rest/api/3/changelog/bulkfetch Body: BulkChangelogRequestBean — {:issueIds [...] :fieldIds [...]}

Bulk fetch changelogs for a list of issues.
POST /rest/api/3/changelog/bulkfetch
Body: BulkChangelogRequestBean — {:issueIds [...] :fieldIds [...]}
sourceraw docstring

get-changelogsclj

(get-changelogs client issue-id-or-key)
(get-changelogs client issue-id-or-key opts)

Get changelogs for an issue. GET /rest/api/3/issue/{issueIdOrKey}/changelog Path: issueIdOrKey — the ID or key of the issue. opts: {:startAt int :maxResults int}

Get changelogs for an issue.
GET /rest/api/3/issue/{issueIdOrKey}/changelog
Path: issueIdOrKey — the ID or key of the issue.
opts: {:startAt int :maxResults int}
sourceraw docstring

get-changelogs-by-idsclj

(get-changelogs-by-ids client issue-id-or-key body)
(get-changelogs-by-ids client issue-id-or-key body opts)

Get changelogs by IDs for an issue. POST /rest/api/3/issue/{issueIdOrKey}/changelog/list Path: issueIdOrKey — the ID or key of the issue. Body: IssueChangelogIds — {:changelogIds [1 2 3]}

Get changelogs by IDs for an issue.
POST /rest/api/3/issue/{issueIdOrKey}/changelog/list
Path: issueIdOrKey — the ID or key of the issue.
Body: IssueChangelogIds — {:changelogIds [1 2 3]}
sourceraw docstring

get-create-issue-metaclj

(get-create-issue-meta client)
(get-create-issue-meta client opts)

DEPRECATED. Get create issue metadata. GET /rest/api/3/issue/createmeta opts: {:projectIds [...] :projectKeys [...] :issuetypeIds [...] :issuetypeNames [...] :expand "..."}

DEPRECATED. Get create issue metadata.
GET /rest/api/3/issue/createmeta
opts: {:projectIds [...] :projectKeys [...] :issuetypeIds [...] :issuetypeNames [...] :expand "..."}
sourceraw docstring

get-create-issue-meta-issue-type-idclj

(get-create-issue-meta-issue-type-id client project-id-or-key issue-type-id)
(get-create-issue-meta-issue-type-id client
                                     project-id-or-key
                                     issue-type-id
                                     opts)

Get create field metadata for a project and issue type id. GET /rest/api/3/issue/createmeta/{projectIdOrKey}/issuetypes/{issueTypeId} Path: projectIdOrKey — the ID or key of the project; issueTypeId — the issue type ID. opts: {:startAt int :maxResults int}

Get create field metadata for a project and issue type id.
GET /rest/api/3/issue/createmeta/{projectIdOrKey}/issuetypes/{issueTypeId}
Path: projectIdOrKey — the ID or key of the project; issueTypeId — the issue type ID.
opts: {:startAt int :maxResults int}
sourceraw docstring

get-create-issue-meta-issue-typesclj

(get-create-issue-meta-issue-types client project-id-or-key)
(get-create-issue-meta-issue-types client project-id-or-key opts)

Get create metadata issue types for a project. GET /rest/api/3/issue/createmeta/{projectIdOrKey}/issuetypes Path: projectIdOrKey — the ID or key of the project. opts: {:startAt int :maxResults int}

Get create metadata issue types for a project.
GET /rest/api/3/issue/createmeta/{projectIdOrKey}/issuetypes
Path: projectIdOrKey — the ID or key of the project.
opts: {:startAt int :maxResults int}
sourceraw docstring

get-edit-issue-metaclj

(get-edit-issue-meta client issue-id-or-key)
(get-edit-issue-meta client issue-id-or-key opts)

Get edit issue metadata. GET /rest/api/3/issue/{issueIdOrKey}/editmeta Path: issueIdOrKey — the ID or key of the issue. opts: {:overrideScreenSecurity bool :overrideEditableFlag bool}

Get edit issue metadata.
GET /rest/api/3/issue/{issueIdOrKey}/editmeta
Path: issueIdOrKey — the ID or key of the issue.
opts: {:overrideScreenSecurity bool :overrideEditableFlag bool}
sourceraw docstring

get-eventsclj

(get-events client)

Get events — returns all Jira issue event types. GET /rest/api/3/events

Get events — returns all Jira issue event types.
GET /rest/api/3/events
sourceraw docstring

get-issueclj

(get-issue client issue-id-or-key)
(get-issue client issue-id-or-key opts)

Get issue. GET /rest/api/3/issue/{issueIdOrKey} Path: issueIdOrKey — the ID or key of the issue. opts: {:fields [...] :fieldsByKeys bool :expand "..." :properties [...] :updateHistory bool :failFast bool}

Get issue.
GET /rest/api/3/issue/{issueIdOrKey}
Path: issueIdOrKey — the ID or key of the issue.
opts: {:fields [...] :fieldsByKeys bool :expand "..." :properties [...] :updateHistory bool :failFast bool}
sourceraw docstring

get-issue-limit-reportclj

(get-issue-limit-report client)
(get-issue-limit-report client opts)

Get issue limit report. GET /rest/api/3/issue/limit/report opts: {:isReturningKeys bool}

Get issue limit report.
GET /rest/api/3/issue/limit/report
opts: {:isReturningKeys bool}
sourceraw docstring

get-transitionsclj

(get-transitions client issue-id-or-key)
(get-transitions client issue-id-or-key opts)

Get transitions available for an issue. GET /rest/api/3/issue/{issueIdOrKey}/transitions Path: issueIdOrKey — the ID or key of the issue. opts: {:expand "..." :transitionId "..." :skipRemoteOnlyCondition bool :includeUnavailableTransitions bool :sortByOpsBarAndStatus bool}

Get transitions available for an issue.
GET /rest/api/3/issue/{issueIdOrKey}/transitions
Path: issueIdOrKey — the ID or key of the issue.
opts: {:expand "..." :transitionId "..." :skipRemoteOnlyCondition bool
       :includeUnavailableTransitions bool :sortByOpsBarAndStatus bool}
sourceraw docstring

notifyclj

(notify client issue-id-or-key body)
(notify client issue-id-or-key body opts)

Send notification for issue. POST /rest/api/3/issue/{issueIdOrKey}/notify Path: issueIdOrKey — ID or key of the issue that the notification is sent for. Body: Notification — {:subject "..." :textBody "..." :to {:voters bool :watchers bool :groups [...] :users [...]}}

Send notification for issue.
POST /rest/api/3/issue/{issueIdOrKey}/notify
Path: issueIdOrKey — ID or key of the issue that the notification is sent for.
Body: Notification — {:subject "..." :textBody "..." :to {:voters bool :watchers bool :groups [...] :users [...]}}
sourceraw docstring

unarchive-issuesclj

(unarchive-issues client body)
(unarchive-issues client body opts)

Unarchive issue(s) by issue keys/ID. PUT /rest/api/3/issue/unarchive Body: IssueArchivalSyncRequest — {:issueIdsOrKeys ["PROJ-1" "PROJ-2"]}

Unarchive issue(s) by issue keys/ID.
PUT /rest/api/3/issue/unarchive
Body: IssueArchivalSyncRequest — {:issueIdsOrKeys ["PROJ-1" "PROJ-2"]}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries