atlassian.jira.misc

Miscellaneous Jira Cloud REST API endpoints.

Covers: announcement banners, application properties, application roles, audit records, avatars, global configuration, Jira expressions, license metrics, labels, preferences, redaction, server info, tasks, and webhooks.

Miscellaneous Jira Cloud REST API endpoints.

Covers: announcement banners, application properties, application roles,
audit records, avatars, global configuration, Jira expressions, license
metrics, labels, preferences, redaction, server info, tasks, and webhooks.
raw docstring

analyse-expressionclj

(analyse-expression client body)
(analyse-expression client body opts)

Analyse Jira expression. POST /rest/api/3/expression/analyse Body: JiraExpressionForAnalysis — map with :expressions (list of strings) and optional :contextVariables. opts: :check (syntax | type | complexity)

Analyse Jira expression.
POST /rest/api/3/expression/analyse
Body: JiraExpressionForAnalysis — map with :expressions (list of strings) and optional :contextVariables.
opts: :check (syntax | type | complexity)
sourceraw docstring

cancel-taskclj

(cancel-task client task-id)

Cancel task. POST /rest/api/3/task/{taskId}/cancel Path params: taskId — the ID of the task.

Cancel task.
POST /rest/api/3/task/{taskId}/cancel
Path params: taskId — the ID of the task.
sourceraw docstring

delete-avatarclj

(delete-avatar client type owning-object-id id)

Delete avatar. DELETE /rest/api/3/universal_avatar/type/{type}/owner/{owningObjectId}/avatar/{id} Path params: type — avatar type; owningObjectId — entity ID; id — avatar ID.

Delete avatar.
DELETE /rest/api/3/universal_avatar/type/{type}/owner/{owningObjectId}/avatar/{id}
Path params: type — avatar type; owningObjectId — entity ID; id — avatar ID.
sourceraw docstring

delete-webhook-by-idclj

(delete-webhook-by-id client body)

Delete webhooks by ID. DELETE /rest/api/3/webhook Body: ContainerForWebhookIDs — map with :webhookIds (list of longs).

Delete webhooks by ID.
DELETE /rest/api/3/webhook
Body: ContainerForWebhookIDs — map with :webhookIds (list of longs).
sourceraw docstring

evaluate-jira-expressionclj

(evaluate-jira-expression client body)
(evaluate-jira-expression client body opts)

DEPRECATED. Currently being removed. Evaluate Jira expression. POST /rest/api/3/expression/eval Body: JiraExpressionEvalRequestBean — map with :expression and optional :context. opts: :expand

DEPRECATED. Currently being removed. Evaluate Jira expression.
POST /rest/api/3/expression/eval
Body: JiraExpressionEvalRequestBean — map with :expression and optional :context.
opts: :expand
sourceraw docstring

evaluate-jsis-jira-expressionclj

(evaluate-jsis-jira-expression client body)
(evaluate-jsis-jira-expression client body opts)

Evaluate Jira expression using enhanced search API. POST /rest/api/3/expression/evaluate Body: JiraExpressionEvaluateRequestBean — map with :expression and optional :context. opts: :expand

Evaluate Jira expression using enhanced search API.
POST /rest/api/3/expression/evaluate
Body: JiraExpressionEvaluateRequestBean — map with :expression and optional :context.
opts: :expand
sourceraw docstring

get-advanced-settingsclj

(get-advanced-settings client)

Get advanced settings. GET /rest/api/3/application-properties/advanced-settings

Get advanced settings.
GET /rest/api/3/application-properties/advanced-settings
sourceraw docstring

get-all-application-rolesclj

(get-all-application-roles client)

Get all application roles. GET /rest/api/3/applicationrole

Get all application roles.
GET /rest/api/3/applicationrole
sourceraw docstring

get-all-labelsclj

(get-all-labels client)
(get-all-labels client opts)

Get all labels. GET /rest/api/3/label opts: :startAt, :maxResults

Get all labels.
GET /rest/api/3/label
opts: :startAt, :maxResults
sourceraw docstring

get-all-system-avatarsclj

(get-all-system-avatars client type)

Get system avatars by type. GET /rest/api/3/avatar/{type}/system Path params: type — the avatar type.

Get system avatars by type.
GET /rest/api/3/avatar/{type}/system
Path params: type — the avatar type.
sourceraw docstring

get-application-propertyclj

(get-application-property client)
(get-application-property client opts)

Get application property. GET /rest/api/3/application-properties opts: :key, :permissionLevel, :keyFilter

Get application property.
GET /rest/api/3/application-properties
opts: :key, :permissionLevel, :keyFilter
sourceraw docstring

get-application-roleclj

(get-application-role client key)

Get application role. GET /rest/api/3/applicationrole/{key} Path params: key — the key of the application role.

Get application role.
GET /rest/api/3/applicationrole/{key}
Path params: key — the key of the application role.
sourceraw docstring

get-approximate-application-license-countclj

(get-approximate-application-license-count client application-key)

Get approximate application license count. GET /rest/api/3/license/approximateLicenseCount/product/{applicationKey} Path params: applicationKey — ID of the application (specific Jira version).

Get approximate application license count.
GET /rest/api/3/license/approximateLicenseCount/product/{applicationKey}
Path params: applicationKey — ID of the application (specific Jira version).
sourceraw docstring

get-approximate-license-countclj

(get-approximate-license-count client)

Get approximate license count. GET /rest/api/3/license/approximateLicenseCount

Get approximate license count.
GET /rest/api/3/license/approximateLicenseCount
sourceraw docstring

get-audit-recordsclj

(get-audit-records client)
(get-audit-records client opts)

Get audit records. GET /rest/api/3/auditing/record opts: :offset, :limit, :filter, :from, :to

Get audit records.
GET /rest/api/3/auditing/record
opts: :offset, :limit, :filter, :from, :to
sourceraw docstring

get-avatar-image-by-idclj

(get-avatar-image-by-id client type id)
(get-avatar-image-by-id client type id opts)

Get avatar image by ID. GET /rest/api/3/universal_avatar/view/type/{type}/avatar/{id} Path params: type — icon type of the avatar; id — avatar ID. opts: :size, :format

Get avatar image by ID.
GET /rest/api/3/universal_avatar/view/type/{type}/avatar/{id}
Path params: type — icon type of the avatar; id — avatar ID.
opts: :size, :format
sourceraw docstring

get-avatar-image-by-ownerclj

(get-avatar-image-by-owner client type entity-id)
(get-avatar-image-by-owner client type entity-id opts)

Get avatar image by owner. GET /rest/api/3/universal_avatar/view/type/{type}/owner/{entityId} Path params: type — icon type of the avatar; entityId — project or issue type ID. opts: :size, :format

Get avatar image by owner.
GET /rest/api/3/universal_avatar/view/type/{type}/owner/{entityId}
Path params: type — icon type of the avatar; entityId — project or issue type ID.
opts: :size, :format
sourceraw docstring

get-avatar-image-by-typeclj

(get-avatar-image-by-type client type)
(get-avatar-image-by-type client type opts)

Get avatar image by type. GET /rest/api/3/universal_avatar/view/type/{type} Path params: type — icon type of the avatar. opts: :size, :format

Get avatar image by type.
GET /rest/api/3/universal_avatar/view/type/{type}
Path params: type — icon type of the avatar.
opts: :size, :format
sourceraw docstring

get-avatarsclj

(get-avatars client type entity-id)
(get-avatars client type entity-id opts)

Get avatars for an entity. GET /rest/api/3/universal_avatar/type/{type}/owner/{entityId} Path params: type — avatar type; entityId — ID of the associated item.

Get avatars for an entity.
GET /rest/api/3/universal_avatar/type/{type}/owner/{entityId}
Path params: type — avatar type; entityId — ID of the associated item.
sourceraw docstring

get-bannerclj

(get-banner client)

Get announcement banner configuration. GET /rest/api/3/announcementBanner

Get announcement banner configuration.
GET /rest/api/3/announcementBanner
sourceraw docstring

get-configurationclj

(get-configuration client)

Get global settings. GET /rest/api/3/configuration

Get global settings.
GET /rest/api/3/configuration
sourceraw docstring

get-current-userclj

(get-current-user client)
(get-current-user client opts)

Get current user. GET /rest/api/3/myself opts: :expand

Get current user.
GET /rest/api/3/myself
opts: :expand
sourceraw docstring

get-dynamic-webhooks-for-appclj

(get-dynamic-webhooks-for-app client)
(get-dynamic-webhooks-for-app client opts)

Get dynamic webhooks for app. GET /rest/api/3/webhook opts: :startAt, :maxResults

Get dynamic webhooks for app.
GET /rest/api/3/webhook
opts: :startAt, :maxResults
sourceraw docstring

get-failed-webhooksclj

(get-failed-webhooks client)
(get-failed-webhooks client opts)

Get failed webhooks. GET /rest/api/3/webhook/failed opts: :maxResults, :after

Get failed webhooks.
GET /rest/api/3/webhook/failed
opts: :maxResults, :after
sourceraw docstring

get-licenseclj

(get-license client)

Get license. GET /rest/api/3/instance/license

Get license.
GET /rest/api/3/instance/license
sourceraw docstring

get-localeclj

(get-locale client)

Get locale. GET /rest/api/3/mypreferences/locale

Get locale.
GET /rest/api/3/mypreferences/locale
sourceraw docstring

get-preferenceclj

(get-preference client opts)

Get preference. GET /rest/api/3/mypreferences opts: :key (required) — the key of the preference.

Get preference.
GET /rest/api/3/mypreferences
opts: :key (required) — the key of the preference.
sourceraw docstring

get-redaction-statusclj

(get-redaction-status client job-id)

Get redaction status. GET /rest/api/3/redact/status/{jobId} Path params: jobId — redaction job ID.

Get redaction status.
GET /rest/api/3/redact/status/{jobId}
Path params: jobId — redaction job ID.
sourceraw docstring

get-server-infoclj

(get-server-info client)

Get Jira instance info. GET /rest/api/3/serverInfo

Get Jira instance info.
GET /rest/api/3/serverInfo
sourceraw docstring

get-taskclj

(get-task client task-id)

Get task. GET /rest/api/3/task/{taskId} Path params: taskId — the ID of the task.

Get task.
GET /rest/api/3/task/{taskId}
Path params: taskId — the ID of the task.
sourceraw docstring

redactclj

(redact client body)

Redact issues. POST /rest/api/3/redact Body: BulkRedactionRequest — map with :issueIds and :fields to redact.

Redact issues.
POST /rest/api/3/redact
Body: BulkRedactionRequest — map with :issueIds and :fields to redact.
sourceraw docstring

refresh-webhooksclj

(refresh-webhooks client body)

Extend webhook life. PUT /rest/api/3/webhook/refresh Body: ContainerForWebhookIDs — map with :webhookIds (list of longs).

Extend webhook life.
PUT /rest/api/3/webhook/refresh
Body: ContainerForWebhookIDs — map with :webhookIds (list of longs).
sourceraw docstring

register-dynamic-webhooksclj

(register-dynamic-webhooks client body)

Register dynamic webhooks. POST /rest/api/3/webhook Body: WebhookRegistrationDetails — map with :webhooks (list of webhook configs) and :url.

Register dynamic webhooks.
POST /rest/api/3/webhook
Body: WebhookRegistrationDetails — map with :webhooks (list of webhook configs) and :url.
sourceraw docstring

remove-preferenceclj

(remove-preference client opts)

Delete preference. DELETE /rest/api/3/mypreferences opts: :key (required) — the key of the preference.

Delete preference.
DELETE /rest/api/3/mypreferences
opts: :key (required) — the key of the preference.
sourceraw docstring

set-application-propertyclj

(set-application-property client id body)

Set application property. PUT /rest/api/3/application-properties/{id} Path params: id — the key of the application property to update. Body: SimpleApplicationPropertyBean

Set application property.
PUT /rest/api/3/application-properties/{id}
Path params: id — the key of the application property to update.
Body: SimpleApplicationPropertyBean
sourceraw docstring

set-bannerclj

(set-banner client body)

Update announcement banner configuration. PUT /rest/api/3/announcementBanner Body: AnnouncementBannerConfigurationUpdate

Update announcement banner configuration.
PUT /rest/api/3/announcementBanner
Body: AnnouncementBannerConfigurationUpdate
sourceraw docstring

set-localeclj

(set-locale client body)

DEPRECATED. Set locale. PUT /rest/api/3/mypreferences/locale Body: Locale — map with :locale string.

DEPRECATED. Set locale.
PUT /rest/api/3/mypreferences/locale
Body: Locale — map with :locale string.
sourceraw docstring

set-preferenceclj

(set-preference client body opts)

Set preference. PUT /rest/api/3/mypreferences Body: string value for the preference. opts: :key (required) — the key of the preference (max 255 chars).

Set preference.
PUT /rest/api/3/mypreferences
Body: string value for the preference.
opts: :key (required) — the key of the preference (max 255 chars).
sourceraw docstring

store-avatarclj

(store-avatar client type entity-id body)
(store-avatar client type entity-id body opts)

Load avatar for an entity. POST /rest/api/3/universal_avatar/type/{type}/owner/{entityId} Path params: type — avatar type; entityId — ID of the associated item. opts: :x, :y, :size (required) Body: raw avatar image bytes (caller-supplied).

Load avatar for an entity.
POST /rest/api/3/universal_avatar/type/{type}/owner/{entityId}
Path params: type — avatar type; entityId — ID of the associated item.
opts: :x, :y, :size (required)
Body: raw avatar image bytes (caller-supplied).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries