atlassian.jira.notifications

Jira notification scheme endpoints.

Covers the /rest/api/3/notificationscheme surface: listing, creating, updating, and deleting notification schemes, and managing individual notifications within a scheme.

Jira notification scheme endpoints.

Covers the /rest/api/3/notificationscheme surface: listing, creating,
updating, and deleting notification schemes, and managing individual
notifications within a scheme.
raw docstring

add-notificationsclj

(add-notifications client id body)
(add-notifications client id body opts)

Add notifications to notification scheme. PUT /rest/api/3/notificationscheme/{id}/notification

Path params: id - The ID of the notification scheme.

Body: AddNotificationsDetails {:notificationSchemeEvents [{:event {:id "string"} :notifications [{:notificationType "string" ...}]}]}

Add notifications to notification scheme.
PUT /rest/api/3/notificationscheme/{id}/notification

Path params:
  id - The ID of the notification scheme.

Body: AddNotificationsDetails
  {:notificationSchemeEvents [{:event {:id "string"} :notifications [{:notificationType "string" ...}]}]}
sourceraw docstring

create-notification-schemeclj

(create-notification-scheme client body)
(create-notification-scheme client body opts)

Create notification scheme. POST /rest/api/3/notificationscheme

Body: CreateNotificationSchemeDetails {:name "string (required, max 255)" :description "string (optional, max 4000)" :notificationSchemeEvents [{:event {...} :notifications [...]}]}

Create notification scheme.
POST /rest/api/3/notificationscheme

Body: CreateNotificationSchemeDetails
  {:name                    "string (required, max 255)"
   :description             "string (optional, max 4000)"
   :notificationSchemeEvents [{:event {...} :notifications [...]}]}
sourceraw docstring

delete-notification-schemeclj

(delete-notification-scheme client notification-scheme-id)

Delete notification scheme. DELETE /rest/api/3/notificationscheme/{notificationSchemeId}

Path params: notification-scheme-id - The ID of the notification scheme.

Delete notification scheme.
DELETE /rest/api/3/notificationscheme/{notificationSchemeId}

Path params:
  notification-scheme-id - The ID of the notification scheme.
sourceraw docstring

get-notification-schemeclj

(get-notification-scheme client id)
(get-notification-scheme client id opts)

Get notification scheme. GET /rest/api/3/notificationscheme/{id}

Path params: id - The ID of the notification scheme.

opts (optional): :expand - comma-separated expansion options (all, field, group, notificationSchemeEvents, projectRole, user)

Get notification scheme.
GET /rest/api/3/notificationscheme/{id}

Path params:
  id - The ID of the notification scheme.

opts (optional):
  :expand - comma-separated expansion options (all, field, group, notificationSchemeEvents, projectRole, user)
sourceraw docstring

get-notification-scheme-to-project-mappingsclj

(get-notification-scheme-to-project-mappings client)
(get-notification-scheme-to-project-mappings client opts)

Get projects using notification schemes paginated. GET /rest/api/3/notificationscheme/project

opts (all optional): :startAt - page offset :maxResults - max items per page :notificationSchemeId - filter by notification scheme IDs (array) :projectId - filter by project IDs (array)

Get projects using notification schemes paginated.
GET /rest/api/3/notificationscheme/project

opts (all optional):
  :startAt                - page offset
  :maxResults             - max items per page
  :notificationSchemeId   - filter by notification scheme IDs (array)
  :projectId              - filter by project IDs (array)
sourceraw docstring

get-notification-schemesclj

(get-notification-schemes client)
(get-notification-schemes client opts)

Get notification schemes paginated. GET /rest/api/3/notificationscheme

opts (all optional): :startAt - page offset :maxResults - max items per page :id - filter by notification scheme IDs (array) :projectId - filter by project IDs (array) :onlyDefault - when true, returns only the default notification scheme :expand - comma-separated list of expansion options (all, field, group, notificationSchemeEvents, projectRole, user)

Get notification schemes paginated.
GET /rest/api/3/notificationscheme

opts (all optional):
  :startAt      - page offset
  :maxResults   - max items per page
  :id           - filter by notification scheme IDs (array)
  :projectId    - filter by project IDs (array)
  :onlyDefault  - when true, returns only the default notification scheme
  :expand       - comma-separated list of expansion options (all, field, group, notificationSchemeEvents, projectRole, user)
sourceraw docstring

remove-notification-from-notification-schemeclj

(remove-notification-from-notification-scheme client
                                              notification-scheme-id
                                              notification-id)

Remove notification from notification scheme. DELETE /rest/api/3/notificationscheme/{notificationSchemeId}/notification/{notificationId}

Path params: notification-scheme-id - The ID of the notification scheme. notification-id - The ID of the notification.

Remove notification from notification scheme.
DELETE /rest/api/3/notificationscheme/{notificationSchemeId}/notification/{notificationId}

Path params:
  notification-scheme-id - The ID of the notification scheme.
  notification-id        - The ID of the notification.
sourceraw docstring

update-notification-schemeclj

(update-notification-scheme client id body)
(update-notification-scheme client id body opts)

Update notification scheme. PUT /rest/api/3/notificationscheme/{id}

Path params: id - The ID of the notification scheme.

Body: UpdateNotificationSchemeDetails {:name "string (max 255)" :description "string (max 4000)"}

Update notification scheme.
PUT /rest/api/3/notificationscheme/{id}

Path params:
  id - The ID of the notification scheme.

Body: UpdateNotificationSchemeDetails
  {:name        "string (max 255)"
   :description "string (max 4000)"}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries