atlassian.jira.priorities-statuses

Jira Cloud endpoints for issue priorities, priority schemes, issue resolutions, and statuses.

All functions delegate to atlassian.jira.client/request and take a client handle as their first argument (build one with atlassian.jira.client/client).

Jira Cloud endpoints for issue priorities, priority schemes, issue
resolutions, and statuses.

All functions delegate to `atlassian.jira.client/request` and take a client
handle as their first argument (build one with `atlassian.jira.client/client`).
raw docstring

create-priorityclj

(create-priority client body)
(create-priority client body opts)

DEPRECATED. Create an issue priority. POST /rest/api/3/priority Body: CreatePriorityDetails — {:name string, :description string, :iconUrl string, :statusColor string}

DEPRECATED. Create an issue priority.
POST /rest/api/3/priority
Body: CreatePriorityDetails — {:name string, :description string, :iconUrl string, :statusColor string}
sourceraw docstring

create-priority-schemeclj

(create-priority-scheme client body)
(create-priority-scheme client body opts)

Create a priority scheme. POST /rest/api/3/priorityscheme Body: CreatePrioritySchemeDetails — {:name string, :description string, :defaultPriorityId string, :priorityIds [string]}

Create a priority scheme.
POST /rest/api/3/priorityscheme
Body: CreatePrioritySchemeDetails — {:name string, :description string, :defaultPriorityId string, :priorityIds [string]}
sourceraw docstring

create-resolutionclj

(create-resolution client body)
(create-resolution client body opts)

Create an issue resolution. POST /rest/api/3/resolution Body: CreateResolutionDetails — {:name string, :description string}

Create an issue resolution.
POST /rest/api/3/resolution
Body: CreateResolutionDetails — {:name string, :description string}
sourceraw docstring

create-statusesclj

(create-statuses client body)
(create-statuses client body opts)

Bulk create statuses. POST /rest/api/3/statuses Body: StatusCreateRequest — {:statuses [{:name string, :statusCategory string, :description string}]}

Bulk create statuses.
POST /rest/api/3/statuses
Body: StatusCreateRequest — {:statuses [{:name string, :statusCategory string, :description string}]}
sourceraw docstring

delete-priorityclj

(delete-priority client id)

Delete an issue priority. GET /rest/api/3/priority/{id} Path params: id — The ID of the issue priority.

Delete an issue priority.
GET /rest/api/3/priority/{id}
Path params: id — The ID of the issue priority.
sourceraw docstring

delete-priority-schemeclj

(delete-priority-scheme client scheme-id)

Delete a priority scheme. DELETE /rest/api/3/priorityscheme/{schemeId} Path params: schemeId — The priority scheme ID.

Delete a priority scheme.
DELETE /rest/api/3/priorityscheme/{schemeId}
Path params: schemeId — The priority scheme ID.
sourceraw docstring

delete-resolutionclj

(delete-resolution client id opts)

Delete an issue resolution. Requires :replaceWith query param (required). DELETE /rest/api/3/resolution/{id} Path params: id — The ID of the issue resolution. opts: :replaceWith (required) — ID of the resolution to replace the deleted one.

Delete an issue resolution. Requires :replaceWith query param (required).
DELETE /rest/api/3/resolution/{id}
Path params: id — The ID of the issue resolution.
opts: :replaceWith (required) — ID of the resolution to replace the deleted one.
sourceraw docstring

delete-statuses-by-idclj

(delete-statuses-by-id client opts)

Bulk delete statuses by ID. DELETE /rest/api/3/statuses opts: :id (required array) — list of status IDs to delete (1-50).

Bulk delete statuses by ID.
DELETE /rest/api/3/statuses
opts: :id (required array) — list of status IDs to delete (1-50).
sourceraw docstring

get-available-priorities-by-priority-schemeclj

(get-available-priorities-by-priority-scheme client opts)

Get available priorities for a priority scheme (excludes already-assigned ones). GET /rest/api/3/priorityscheme/priorities/available opts: :startAt, :maxResults, :query, :schemeId (required), :exclude (array)

Get available priorities for a priority scheme (excludes already-assigned ones).
GET /rest/api/3/priorityscheme/priorities/available
opts: :startAt, :maxResults, :query, :schemeId (required), :exclude (array)
sourceraw docstring

get-prioritiesclj

(get-priorities client)

DEPRECATED. Get all issue priorities. GET /rest/api/3/priority

DEPRECATED. Get all issue priorities.
GET /rest/api/3/priority
sourceraw docstring

get-priorities-by-priority-schemeclj

(get-priorities-by-priority-scheme client scheme-id)
(get-priorities-by-priority-scheme client scheme-id opts)

Get priorities associated with a priority scheme, paginated. GET /rest/api/3/priorityscheme/{schemeId}/priorities Path params: schemeId — The priority scheme ID. opts: :startAt, :maxResults

Get priorities associated with a priority scheme, paginated.
GET /rest/api/3/priorityscheme/{schemeId}/priorities
Path params: schemeId — The priority scheme ID.
opts: :startAt, :maxResults
sourceraw docstring

get-priorityclj

(get-priority client id)

Get an issue priority. GET /rest/api/3/priority/{id} Path params: id — The ID of the issue priority.

Get an issue priority.
GET /rest/api/3/priority/{id}
Path params: id — The ID of the issue priority.
sourceraw docstring

get-priority-schemesclj

(get-priority-schemes client)
(get-priority-schemes client opts)

Get a paginated list of priority schemes. GET /rest/api/3/priorityscheme opts: :startAt, :maxResults, :priorityId (array), :schemeId (array), :schemeName, :onlyDefault, :orderBy, :expand

Get a paginated list of priority schemes.
GET /rest/api/3/priorityscheme
opts: :startAt, :maxResults, :priorityId (array), :schemeId (array), :schemeName, :onlyDefault, :orderBy, :expand
sourceraw docstring

get-project-issue-type-usages-for-statusclj

(get-project-issue-type-usages-for-status client status-id project-id)
(get-project-issue-type-usages-for-status client status-id project-id opts)

Get issue type usages for a status within a project, paginated. GET /rest/api/3/statuses/{statusId}/project/{projectId}/issueTypeUsages Path params: statusId, projectId. opts: :nextPageToken, :maxResults

Get issue type usages for a status within a project, paginated.
GET /rest/api/3/statuses/{statusId}/project/{projectId}/issueTypeUsages
Path params: statusId, projectId.
opts: :nextPageToken, :maxResults
sourceraw docstring

get-project-usages-for-statusclj

(get-project-usages-for-status client status-id)
(get-project-usages-for-status client status-id opts)

Get project usages for a status, paginated. GET /rest/api/3/statuses/{statusId}/projectUsages Path params: statusId. opts: :nextPageToken, :maxResults

Get project usages for a status, paginated.
GET /rest/api/3/statuses/{statusId}/projectUsages
Path params: statusId.
opts: :nextPageToken, :maxResults
sourceraw docstring

get-projects-by-priority-schemeclj

(get-projects-by-priority-scheme client scheme-id)
(get-projects-by-priority-scheme client scheme-id opts)

Get projects associated with a priority scheme, paginated. GET /rest/api/3/priorityscheme/{schemeId}/projects Path params: schemeId — The priority scheme ID. opts: :startAt, :maxResults, :projectId (array), :query

Get projects associated with a priority scheme, paginated.
GET /rest/api/3/priorityscheme/{schemeId}/projects
Path params: schemeId — The priority scheme ID.
opts: :startAt, :maxResults, :projectId (array), :query
sourceraw docstring

get-resolutionclj

(get-resolution client id)

Get an issue resolution value. GET /rest/api/3/resolution/{id} Path params: id — The ID of the issue resolution value.

Get an issue resolution value.
GET /rest/api/3/resolution/{id}
Path params: id — The ID of the issue resolution value.
sourceraw docstring

get-resolutionsclj

(get-resolutions client)

DEPRECATED. Get all issue resolutions. GET /rest/api/3/resolution

DEPRECATED. Get all issue resolutions.
GET /rest/api/3/resolution
sourceraw docstring

get-statuses-by-idclj

(get-statuses-by-id client opts)

Bulk get statuses by ID. GET /rest/api/3/statuses opts: :id (required array) — list of status IDs (1-50).

Bulk get statuses by ID.
GET /rest/api/3/statuses
opts: :id (required array) — list of status IDs (1-50).
sourceraw docstring

get-statuses-by-nameclj

(get-statuses-by-name client opts)

Bulk get statuses by name. GET /rest/api/3/statuses/byNames opts: :name (required array) — list of status names (1-50); :projectId (optional).

Bulk get statuses by name.
GET /rest/api/3/statuses/byNames
opts: :name (required array) — list of status names (1-50); :projectId (optional).
sourceraw docstring

get-workflow-usages-for-statusclj

(get-workflow-usages-for-status client status-id)
(get-workflow-usages-for-status client status-id opts)

Get workflow usages for a status, paginated. GET /rest/api/3/statuses/{statusId}/workflowUsages Path params: statusId. opts: :nextPageToken, :maxResults

Get workflow usages for a status, paginated.
GET /rest/api/3/statuses/{statusId}/workflowUsages
Path params: statusId.
opts: :nextPageToken, :maxResults
sourceraw docstring

move-prioritiesclj

(move-priorities client body)
(move-priorities client body opts)

Change the order of issue priorities. PUT /rest/api/3/priority/move Body: ReorderIssuePriorities — {:ids [string], :after string} or {:ids [string], :position string}

Change the order of issue priorities.
PUT /rest/api/3/priority/move
Body: ReorderIssuePriorities — {:ids [string], :after string} or {:ids [string], :position string}
sourceraw docstring

move-resolutionsclj

(move-resolutions client body)
(move-resolutions client body opts)

Change the order of issue resolutions. PUT /rest/api/3/resolution/move Body: ReorderIssueResolutionsRequest — {:ids [string], :after string} or {:ids [string], :position string}

Change the order of issue resolutions.
PUT /rest/api/3/resolution/move
Body: ReorderIssueResolutionsRequest — {:ids [string], :after string} or {:ids [string], :position string}
sourceraw docstring

search-prioritiesclj

(search-priorities client)
(search-priorities client opts)

DEPRECATED. Search for issue priorities using pagination. GET /rest/api/3/priority/search opts: :startAt, :maxResults, :id (array), :projectId (array), :priorityName, :onlyDefault, :expand

DEPRECATED. Search for issue priorities using pagination.
GET /rest/api/3/priority/search
opts: :startAt, :maxResults, :id (array), :projectId (array), :priorityName, :onlyDefault, :expand
sourceraw docstring

search-resolutionsclj

(search-resolutions client)
(search-resolutions client opts)

Search for issue resolutions using pagination. GET /rest/api/3/resolution/search opts: :startAt, :maxResults, :id (array), :onlyDefault

Search for issue resolutions using pagination.
GET /rest/api/3/resolution/search
opts: :startAt, :maxResults, :id (array), :onlyDefault
sourceraw docstring

search-statusesclj

(search-statuses client)
(search-statuses client opts)

Search statuses, paginated. GET /rest/api/3/statuses/search opts: :projectId, :startAt, :maxResults, :searchString, :statusCategory

Search statuses, paginated.
GET /rest/api/3/statuses/search
opts: :projectId, :startAt, :maxResults, :searchString, :statusCategory
sourceraw docstring

set-default-priorityclj

(set-default-priority client body)
(set-default-priority client body opts)

Set the default issue priority. PUT /rest/api/3/priority/default Body: SetDefaultPriorityRequest — {:id string}

Set the default issue priority.
PUT /rest/api/3/priority/default
Body: SetDefaultPriorityRequest — {:id string}
sourceraw docstring

set-default-resolutionclj

(set-default-resolution client body)
(set-default-resolution client body opts)

Set the default issue resolution. PUT /rest/api/3/resolution/default Body: SetDefaultResolutionRequest — {:id string}

Set the default issue resolution.
PUT /rest/api/3/resolution/default
Body: SetDefaultResolutionRequest — {:id string}
sourceraw docstring

suggested-priorities-for-mappingsclj

(suggested-priorities-for-mappings client body)
(suggested-priorities-for-mappings client body opts)

Get suggested priorities when migrating issues to a priority scheme. POST /rest/api/3/priorityscheme/mappings Body: SuggestedMappingsRequestBean — {:schemeId string, :priorities [{:issueIds [string], :priorityId string}]}

Get suggested priorities when migrating issues to a priority scheme.
POST /rest/api/3/priorityscheme/mappings
Body: SuggestedMappingsRequestBean — {:schemeId string, :priorities [{:issueIds [string], :priorityId string}]}
sourceraw docstring

update-priorityclj

(update-priority client id body)
(update-priority client id body opts)

DEPRECATED. Update an issue priority. PUT /rest/api/3/priority/{id} Path params: id — The ID of the issue priority. Body: UpdatePriorityDetails — {:name string, :description string, :iconUrl string, :statusColor string}

DEPRECATED. Update an issue priority.
PUT /rest/api/3/priority/{id}
Path params: id — The ID of the issue priority.
Body: UpdatePriorityDetails — {:name string, :description string, :iconUrl string, :statusColor string}
sourceraw docstring

update-priority-schemeclj

(update-priority-scheme client scheme-id body)
(update-priority-scheme client scheme-id body opts)

Update a priority scheme. PUT /rest/api/3/priorityscheme/{schemeId} Path params: schemeId — The ID of the priority scheme. Body: UpdatePrioritySchemeRequestBean — {:name string, :description string, :defaultPriorityId string, :priorityIds [string]}

Update a priority scheme.
PUT /rest/api/3/priorityscheme/{schemeId}
Path params: schemeId — The ID of the priority scheme.
Body: UpdatePrioritySchemeRequestBean — {:name string, :description string, :defaultPriorityId string, :priorityIds [string]}
sourceraw docstring

update-resolutionclj

(update-resolution client id body)
(update-resolution client id body opts)

Update an issue resolution. PUT /rest/api/3/resolution/{id} Path params: id — The ID of the issue resolution. Body: UpdateResolutionDetails — {:name string, :description string}

Update an issue resolution.
PUT /rest/api/3/resolution/{id}
Path params: id — The ID of the issue resolution.
Body: UpdateResolutionDetails — {:name string, :description string}
sourceraw docstring

update-statusesclj

(update-statuses client body)
(update-statuses client body opts)

Bulk update statuses. PUT /rest/api/3/statuses Body: StatusUpdateRequest — {:statuses [{:id string, :name string, :statusCategory string, :description string}]}

Bulk update statuses.
PUT /rest/api/3/statuses
Body: StatusUpdateRequest — {:statuses [{:id string, :name string, :statusCategory string, :description string}]}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries