atlassian.jira.project-roles

Jira Cloud Project Roles and Project Role Actors endpoints.

Covers the /rest/api/3/project/{projectIdOrKey}/role* and /rest/api/3/role* surfaces for managing project roles, their members (actors), and global default actors.

Jira Cloud Project Roles and Project Role Actors endpoints.

Covers the /rest/api/3/project/{projectIdOrKey}/role* and /rest/api/3/role*
surfaces for managing project roles, their members (actors), and global
default actors.
raw docstring

add-actor-usersclj

(add-actor-users client project-id-or-key id body)
(add-actor-users client project-id-or-key id body opts)

Add actors to project role. POST /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params: projectIdOrKey - The project ID or project key (case sensitive). id - The ID of the project role.

Body: ActorsMap {:user ["account-id"] ; user account IDs to add :group ["group-name"] ; group names to add (prefer groupId) :groupId ["group-id"]} ; group IDs to add

Add actors to project role.
POST /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params:
  projectIdOrKey - The project ID or project key (case sensitive).
  id             - The ID of the project role.

Body: ActorsMap
  {:user    ["account-id"]    ; user account IDs to add
   :group   ["group-name"]   ; group names to add (prefer groupId)
   :groupId ["group-id"]}    ; group IDs to add
sourceraw docstring

add-project-role-actors-to-roleclj

(add-project-role-actors-to-role client id body)
(add-project-role-actors-to-role client id body opts)

Add default actors to project role. POST /rest/api/3/role/{id}/actors

Path params: id - The ID of the project role.

Body: ActorInputBean {:user ["account-id"] ; user account IDs to add as default actors :group ["group-name"] ; group names (prefer groupId) :groupId ["group-id"]} ; group IDs to add as default actors

Add default actors to project role.
POST /rest/api/3/role/{id}/actors

Path params:
  id - The ID of the project role.

Body: ActorInputBean
  {:user    ["account-id"]   ; user account IDs to add as default actors
   :group   ["group-name"]  ; group names (prefer groupId)
   :groupId ["group-id"]}   ; group IDs to add as default actors
sourceraw docstring

create-project-roleclj

(create-project-role client body)
(create-project-role client body opts)

Create project role. POST /rest/api/3/role

Body: CreateUpdateRoleRequestBean {:name "Role name" ; required, max 255 chars, must be unique :description "Role description"}

Create project role.
POST /rest/api/3/role

Body: CreateUpdateRoleRequestBean
  {:name        "Role name"       ; required, max 255 chars, must be unique
   :description "Role description"}
sourceraw docstring

delete-actorclj

(delete-actor client project-id-or-key id)
(delete-actor client project-id-or-key id opts)

Delete actors from project role. DELETE /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params: projectIdOrKey - The project ID or project key (case sensitive). id - The ID of the project role.

Optional opts keys: :user - account ID of user to remove :group - group name to remove (prefer groupId) :groupId - group ID to remove

Delete actors from project role.
DELETE /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params:
  projectIdOrKey - The project ID or project key (case sensitive).
  id             - The ID of the project role.

Optional opts keys:
  :user    - account ID of user to remove
  :group   - group name to remove (prefer groupId)
  :groupId - group ID to remove
sourceraw docstring

delete-project-roleclj

(delete-project-role client id)
(delete-project-role client id opts)

Delete project role. DELETE /rest/api/3/role/{id}

Path params: id - The ID of the project role to delete.

Optional opts keys: :swap - ID of the project role to replace the deleted one in schemes.

Delete project role.
DELETE /rest/api/3/role/{id}

Path params:
  id - The ID of the project role to delete.

Optional opts keys:
  :swap - ID of the project role to replace the deleted one in schemes.
sourceraw docstring

delete-project-role-actors-from-roleclj

(delete-project-role-actors-from-role client id)
(delete-project-role-actors-from-role client id opts)

Delete default actors from project role. DELETE /rest/api/3/role/{id}/actors

Path params: id - The ID of the project role.

Optional opts keys: :user - account ID of user to remove as default actor :group - group name to remove (prefer groupId) :groupId - group ID to remove as default actor

Delete default actors from project role.
DELETE /rest/api/3/role/{id}/actors

Path params:
  id - The ID of the project role.

Optional opts keys:
  :user    - account ID of user to remove as default actor
  :group   - group name to remove (prefer groupId)
  :groupId - group ID to remove as default actor
sourceraw docstring

fully-update-project-roleclj

(fully-update-project-role client id body)
(fully-update-project-role client id body opts)

Fully update project role. PUT /rest/api/3/role/{id}

Path params: id - The ID of the project role.

Body: CreateUpdateRoleRequestBean {:name "Role name" ; required :description "Role description"} ; required

Fully update project role.
PUT /rest/api/3/role/{id}

Path params:
  id - The ID of the project role.

Body: CreateUpdateRoleRequestBean
  {:name        "Role name"        ; required
   :description "Role description"} ; required
sourceraw docstring

get-all-project-rolesclj

(get-all-project-roles client)

Get all project roles. GET /rest/api/3/role

Get all project roles.
GET /rest/api/3/role
sourceraw docstring

get-project-roleclj

(get-project-role client project-id-or-key id)
(get-project-role client project-id-or-key id opts)

Get project role for project. GET /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params: projectIdOrKey - The project ID or project key (case sensitive). id - The ID of the project role.

Optional opts keys: :excludeInactiveUsers - boolean; exclude inactive users.

Get project role for project.
GET /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params:
  projectIdOrKey - The project ID or project key (case sensitive).
  id             - The ID of the project role.

Optional opts keys:
  :excludeInactiveUsers - boolean; exclude inactive users.
sourceraw docstring

get-project-role-actors-for-roleclj

(get-project-role-actors-for-role client id)

Get default actors for project role. GET /rest/api/3/role/{id}/actors

Path params: id - The ID of the project role.

Get default actors for project role.
GET /rest/api/3/role/{id}/actors

Path params:
  id - The ID of the project role.
sourceraw docstring

get-project-role-by-idclj

(get-project-role-by-id client id)

Get project role by ID. GET /rest/api/3/role/{id}

Path params: id - The ID of the project role.

Get project role by ID.
GET /rest/api/3/role/{id}

Path params:
  id - The ID of the project role.
sourceraw docstring

get-project-role-detailsclj

(get-project-role-details client project-id-or-key)
(get-project-role-details client project-id-or-key opts)

Get project role details. GET /rest/api/3/project/{projectIdOrKey}/roledetails

Path params: projectIdOrKey - The project ID or project key (case sensitive).

Optional opts keys: :currentMember - boolean; filter to roles the caller belongs to :excludeConnectAddons - boolean :excludeOtherServiceRoles - boolean; exclude default JSM/CSM roles

Get project role details.
GET /rest/api/3/project/{projectIdOrKey}/roledetails

Path params:
  projectIdOrKey - The project ID or project key (case sensitive).

Optional opts keys:
  :currentMember          - boolean; filter to roles the caller belongs to
  :excludeConnectAddons   - boolean
  :excludeOtherServiceRoles - boolean; exclude default JSM/CSM roles
sourceraw docstring

get-project-rolesclj

(get-project-roles client project-id-or-key)

Get project roles for project. GET /rest/api/3/project/{projectIdOrKey}/role

Path params: projectIdOrKey - The project ID or project key (case sensitive).

Get project roles for project.
GET /rest/api/3/project/{projectIdOrKey}/role

Path params:
  projectIdOrKey - The project ID or project key (case sensitive).
sourceraw docstring

partial-update-project-roleclj

(partial-update-project-role client id body)
(partial-update-project-role client id body opts)

Partial update project role. POST /rest/api/3/role/{id}

Path params: id - The ID of the project role.

Body: CreateUpdateRoleRequestBean {:name "New name" ; optional :description "New description"} ; optional

Partial update project role.
POST /rest/api/3/role/{id}

Path params:
  id - The ID of the project role.

Body: CreateUpdateRoleRequestBean
  {:name        "New name"        ; optional
   :description "New description"} ; optional
sourceraw docstring

set-actorsclj

(set-actors client project-id-or-key id body)
(set-actors client project-id-or-key id body opts)

Set actors for project role (replaces all existing actors). PUT /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params: projectIdOrKey - The project ID or project key (case sensitive). id - The ID of the project role.

Body: ProjectRoleActorsUpdateBean {:categorisedActors {"atlassian-user-role-actor" ["account-id"] "atlassian-group-role-actor-id" ["group-id"]}}

Set actors for project role (replaces all existing actors).
PUT /rest/api/3/project/{projectIdOrKey}/role/{id}

Path params:
  projectIdOrKey - The project ID or project key (case sensitive).
  id             - The ID of the project role.

Body: ProjectRoleActorsUpdateBean
  {:categorisedActors
   {"atlassian-user-role-actor"       ["account-id"]
    "atlassian-group-role-actor-id"   ["group-id"]}}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries