atlassian.jira.projects

Jira Cloud project, component, version, category, and project-template endpoints.

One public fn per operation defined in resources/openapi/groups/projects.edn. All functions delegate to atlassian.jira.client/request.

Jira Cloud project, component, version, category, and project-template endpoints.

One public fn per operation defined in resources/openapi/groups/projects.edn.
All functions delegate to `atlassian.jira.client/request`.
raw docstring

archive-projectclj

(archive-project client project-id-or-key)

Archive project. POST /rest/api/3/project/{projectIdOrKey}/archive Path params: projectIdOrKey — The project ID or key (case sensitive).

Archive project.
POST /rest/api/3/project/{projectIdOrKey}/archive
Path params: projectIdOrKey — The project ID or key (case sensitive).
sourceraw docstring

create-componentclj

(create-component client body)
(create-component client body opts)

Create component. POST /rest/api/3/component Body: ProjectComponent schema.

Create component.
POST /rest/api/3/component
Body: ProjectComponent schema.
sourceraw docstring

create-projectclj

(create-project client body)
(create-project client body opts)

Create project. POST /rest/api/3/project Body: CreateProjectDetails schema.

Create project.
POST /rest/api/3/project
Body: CreateProjectDetails schema.
sourceraw docstring

create-project-avatarclj

(create-project-avatar client project-id-or-key body)
(create-project-avatar client project-id-or-key body opts)

Load project avatar. POST /rest/api/3/project/{projectIdOrKey}/avatar2 Path params: projectIdOrKey — The ID or key of the project. Query opts: x, y, size.

Load project avatar.
POST /rest/api/3/project/{projectIdOrKey}/avatar2
Path params: projectIdOrKey — The ID or key of the project.
Query opts: x, y, size.
sourceraw docstring

create-project-categoryclj

(create-project-category client body)
(create-project-category client body opts)

Create project category. POST /rest/api/3/projectCategory Body: ProjectCategory schema.

Create project category.
POST /rest/api/3/projectCategory
Body: ProjectCategory schema.
sourceraw docstring

create-project-with-custom-templateclj

(create-project-with-custom-template client body)
(create-project-with-custom-template client body opts)

Create custom project. POST /rest/api/3/project-template Body: ProjectCustomTemplateCreateRequestDTO schema.

Create custom project.
POST /rest/api/3/project-template
Body: ProjectCustomTemplateCreateRequestDTO schema.
sourceraw docstring

(create-related-work client id body)
(create-related-work client id body opts)

Create related work. POST /rest/api/3/version/{id}/relatedwork Path params: id — The ID of the version. Body: VersionRelatedWork schema.

Create related work.
POST /rest/api/3/version/{id}/relatedwork
Path params: id — The ID of the version.
Body: VersionRelatedWork schema.
sourceraw docstring

create-versionclj

(create-version client body)
(create-version client body opts)

Create version. POST /rest/api/3/version Body: Version schema.

Create version.
POST /rest/api/3/version
Body: Version schema.
sourceraw docstring

delete-and-replace-versionclj

(delete-and-replace-version client id body)
(delete-and-replace-version client id body opts)

Delete and replace version. POST /rest/api/3/version/{id}/removeAndSwap Path params: id — The ID of the version. Body: DeleteAndReplaceVersionBean schema.

Delete and replace version.
POST /rest/api/3/version/{id}/removeAndSwap
Path params: id — The ID of the version.
Body: DeleteAndReplaceVersionBean schema.
sourceraw docstring

delete-componentclj

(delete-component client id)
(delete-component client id opts)

Delete component. DELETE /rest/api/3/component/{id} Path params: id — The ID of the component. Query opts: moveIssuesTo.

Delete component.
DELETE /rest/api/3/component/{id}
Path params: id — The ID of the component.
Query opts: moveIssuesTo.
sourceraw docstring

delete-projectclj

(delete-project client project-id-or-key)
(delete-project client project-id-or-key opts)

Delete project. DELETE /rest/api/3/project/{projectIdOrKey} Path params: projectIdOrKey — The project ID or key (case sensitive). Query opts: enableUndo.

Delete project.
DELETE /rest/api/3/project/{projectIdOrKey}
Path params: projectIdOrKey — The project ID or key (case sensitive).
Query opts: enableUndo.
sourceraw docstring

delete-project-asynchronouslyclj

(delete-project-asynchronously client project-id-or-key)

Delete project asynchronously. POST /rest/api/3/project/{projectIdOrKey}/delete Path params: projectIdOrKey — The project ID or key (case sensitive).

Delete project asynchronously.
POST /rest/api/3/project/{projectIdOrKey}/delete
Path params: projectIdOrKey — The project ID or key (case sensitive).
sourceraw docstring

delete-project-avatarclj

(delete-project-avatar client project-id-or-key id)

Delete project avatar. DELETE /rest/api/3/project/{projectIdOrKey}/avatar/{id} Path params: projectIdOrKey — The project ID or key; id — The ID of the avatar.

Delete project avatar.
DELETE /rest/api/3/project/{projectIdOrKey}/avatar/{id}
Path params: projectIdOrKey — The project ID or key; id — The ID of the avatar.
sourceraw docstring

delete-project-propertyclj

(delete-project-property client project-id-or-key property-key)

Delete project property. DELETE /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey} Path params: projectIdOrKey — The project ID or key; propertyKey — The project property key.

Delete project property.
DELETE /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey}
Path params: projectIdOrKey — The project ID or key; propertyKey — The project property key.
sourceraw docstring

(delete-related-work client version-id related-work-id)

Delete related work. DELETE /rest/api/3/version/{versionId}/relatedwork/{relatedWorkId} Path params: versionId — The ID of the version; relatedWorkId — The ID of the related work to delete.

Delete related work.
DELETE /rest/api/3/version/{versionId}/relatedwork/{relatedWorkId}
Path params: versionId — The ID of the version; relatedWorkId — The ID of the related work to delete.
sourceraw docstring

delete-versionclj

(delete-version client id)
(delete-version client id opts)

DEPRECATED. Delete version. DELETE /rest/api/3/version/{id} Path params: id — The ID of the version. Query opts: moveFixIssuesTo, moveAffectedIssuesTo.

DEPRECATED. Delete version.
DELETE /rest/api/3/version/{id}
Path params: id — The ID of the version.
Query opts: moveFixIssuesTo, moveAffectedIssuesTo.
sourceraw docstring

edit-templateclj

(edit-template client body)
(edit-template client body opts)

Edit a custom project template. PUT /rest/api/3/project-template/edit-template Body: EditTemplateRequest schema.

Edit a custom project template.
PUT /rest/api/3/project-template/edit-template
Body: EditTemplateRequest schema.
sourceraw docstring

find-components-for-projectsclj

(find-components-for-projects client)
(find-components-for-projects client opts)

Find components for projects. GET /rest/api/3/component Query opts: projectIdsOrKeys, startAt, maxResults, orderBy, query.

Find components for projects.
GET /rest/api/3/component
Query opts: projectIdsOrKeys, startAt, maxResults, orderBy, query.
sourceraw docstring

get-accessible-project-type-by-keyclj

(get-accessible-project-type-by-key client project-type-key)

Get accessible project type by key. GET /rest/api/3/project/type/{projectTypeKey}/accessible Path params: projectTypeKey — The key of the project type.

Get accessible project type by key.
GET /rest/api/3/project/type/{projectTypeKey}/accessible
Path params: projectTypeKey — The key of the project type.
sourceraw docstring

get-all-accessible-project-typesclj

(get-all-accessible-project-types client)

Get licensed project types. GET /rest/api/3/project/type/accessible

Get licensed project types.
GET /rest/api/3/project/type/accessible
sourceraw docstring

get-all-project-avatarsclj

(get-all-project-avatars client project-id-or-key)

Get all project avatars. GET /rest/api/3/project/{projectIdOrKey}/avatars Path params: projectIdOrKey — The ID or key of the project.

Get all project avatars.
GET /rest/api/3/project/{projectIdOrKey}/avatars
Path params: projectIdOrKey — The ID or key of the project.
sourceraw docstring

get-all-project-categoriesclj

(get-all-project-categories client)

Get all project categories. GET /rest/api/3/projectCategory

Get all project categories.
GET /rest/api/3/projectCategory
sourceraw docstring

get-all-project-typesclj

(get-all-project-types client)

Get all project types. GET /rest/api/3/project/type

Get all project types.
GET /rest/api/3/project/type
sourceraw docstring

get-all-projectsclj

(get-all-projects client)
(get-all-projects client opts)

DEPRECATED. Get all projects. GET /rest/api/3/project Query opts: expand, recent, properties.

DEPRECATED. Get all projects.
GET /rest/api/3/project
Query opts: expand, recent, properties.
sourceraw docstring

get-all-statusesclj

(get-all-statuses client project-id-or-key)

Get all statuses for project. GET /rest/api/3/project/{projectIdOrKey}/statuses Path params: projectIdOrKey — The project ID or key (case sensitive).

Get all statuses for project.
GET /rest/api/3/project/{projectIdOrKey}/statuses
Path params: projectIdOrKey — The project ID or key (case sensitive).
sourceraw docstring

get-componentclj

(get-component client id)

Get component. GET /rest/api/3/component/{id} Path params: id — The ID of the component.

Get component.
GET /rest/api/3/component/{id}
Path params: id — The ID of the component.
sourceraw docstring

(get-component-related-issues client id)

Get component issues count. GET /rest/api/3/component/{id}/relatedIssueCounts Path params: id — The ID of the component.

Get component issues count.
GET /rest/api/3/component/{id}/relatedIssueCounts
Path params: id — The ID of the component.
sourceraw docstring

get-default-project-classificationclj

(get-default-project-classification client project-id-or-key)

Get the default data classification level of a project. GET /rest/api/3/project/{projectIdOrKey}/classification-level/default Path params: projectIdOrKey — The project ID or key (case-sensitive).

Get the default data classification level of a project.
GET /rest/api/3/project/{projectIdOrKey}/classification-level/default
Path params: projectIdOrKey — The project ID or key (case-sensitive).
sourceraw docstring

get-features-for-projectclj

(get-features-for-project client project-id-or-key)

Get project features. GET /rest/api/3/project/{projectIdOrKey}/features Path params: projectIdOrKey — The ID or key of the project.

Get project features.
GET /rest/api/3/project/{projectIdOrKey}/features
Path params: projectIdOrKey — The ID or key of the project.
sourceraw docstring

get-hierarchyclj

(get-hierarchy client project-id)

Get project issue type hierarchy. GET /rest/api/3/project/{projectId}/hierarchy Path params: projectId — The ID of the project.

Get project issue type hierarchy.
GET /rest/api/3/project/{projectId}/hierarchy
Path params: projectId — The ID of the project.
sourceraw docstring

get-notification-scheme-for-projectclj

(get-notification-scheme-for-project client project-key-or-id)
(get-notification-scheme-for-project client project-key-or-id opts)

Get project notification scheme. GET /rest/api/3/project/{projectKeyOrId}/notificationscheme Path params: projectKeyOrId — The project ID or key (case sensitive). Query opts: expand.

Get project notification scheme.
GET /rest/api/3/project/{projectKeyOrId}/notificationscheme
Path params: projectKeyOrId — The project ID or key (case sensitive).
Query opts: expand.
sourceraw docstring

get-projectclj

(get-project client project-id-or-key)
(get-project client project-id-or-key opts)

Get project. GET /rest/api/3/project/{projectIdOrKey} Path params: projectIdOrKey — The project ID or key (case sensitive). Query opts: expand, properties.

Get project.
GET /rest/api/3/project/{projectIdOrKey}
Path params: projectIdOrKey — The project ID or key (case sensitive).
Query opts: expand, properties.
sourceraw docstring

get-project-category-by-idclj

(get-project-category-by-id client id)

Get project category by ID. GET /rest/api/3/projectCategory/{id} Path params: id — The ID of the project category.

Get project category by ID.
GET /rest/api/3/projectCategory/{id}
Path params: id — The ID of the project category.
sourceraw docstring

get-project-classification-configclj

(get-project-classification-config client project-id-or-key)

Get the classification configuration for a project. GET /rest/api/3/project/{projectIdOrKey}/classification-config Path params: projectIdOrKey — The project ID or key (case-sensitive).

Get the classification configuration for a project.
GET /rest/api/3/project/{projectIdOrKey}/classification-config
Path params: projectIdOrKey — The project ID or key (case-sensitive).
sourceraw docstring

get-project-componentsclj

(get-project-components client project-id-or-key)
(get-project-components client project-id-or-key opts)

Get project components. GET /rest/api/3/project/{projectIdOrKey}/components Path params: projectIdOrKey — The project ID or key (case sensitive). Query opts: componentSource.

Get project components.
GET /rest/api/3/project/{projectIdOrKey}/components
Path params: projectIdOrKey — The project ID or key (case sensitive).
Query opts: componentSource.
sourceraw docstring

get-project-components-paginatedclj

(get-project-components-paginated client project-id-or-key)
(get-project-components-paginated client project-id-or-key opts)

Get project components paginated. GET /rest/api/3/project/{projectIdOrKey}/component Path params: projectIdOrKey — The project ID or key (case sensitive). Query opts: startAt, maxResults, orderBy, componentSource, query.

Get project components paginated.
GET /rest/api/3/project/{projectIdOrKey}/component
Path params: projectIdOrKey — The project ID or key (case sensitive).
Query opts: startAt, maxResults, orderBy, componentSource, query.
sourceraw docstring

get-project-emailclj

(get-project-email client project-id)

Get project's sender email. GET /rest/api/3/project/{projectId}/email Path params: projectId — The project ID.

Get project's sender email.
GET /rest/api/3/project/{projectId}/email
Path params: projectId — The project ID.
sourceraw docstring

get-project-propertyclj

(get-project-property client project-id-or-key property-key)

Get project property. GET /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey} Path params: projectIdOrKey — The project ID or key; propertyKey — The project property key.

Get project property.
GET /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey}
Path params: projectIdOrKey — The project ID or key; propertyKey — The project property key.
sourceraw docstring

get-project-property-keysclj

(get-project-property-keys client project-id-or-key)

Get project property keys. GET /rest/api/3/project/{projectIdOrKey}/properties Path params: projectIdOrKey — The project ID or key (case sensitive).

Get project property keys.
GET /rest/api/3/project/{projectIdOrKey}/properties
Path params: projectIdOrKey — The project ID or key (case sensitive).
sourceraw docstring

get-project-type-by-keyclj

(get-project-type-by-key client project-type-key)

Get project type by key. GET /rest/api/3/project/type/{projectTypeKey} Path params: projectTypeKey — The key of the project type.

Get project type by key.
GET /rest/api/3/project/type/{projectTypeKey}
Path params: projectTypeKey — The key of the project type.
sourceraw docstring

get-project-versionsclj

(get-project-versions client project-id-or-key)
(get-project-versions client project-id-or-key opts)

Get project versions. GET /rest/api/3/project/{projectIdOrKey}/versions Path params: projectIdOrKey — The project ID or key (case sensitive). Query opts: expand.

Get project versions.
GET /rest/api/3/project/{projectIdOrKey}/versions
Path params: projectIdOrKey — The project ID or key (case sensitive).
Query opts: expand.
sourceraw docstring

get-project-versions-paginatedclj

(get-project-versions-paginated client project-id-or-key)
(get-project-versions-paginated client project-id-or-key opts)

Get project versions paginated. GET /rest/api/3/project/{projectIdOrKey}/version Path params: projectIdOrKey — The project ID or key (case sensitive). Query opts: startAt, maxResults, orderBy, query, status, expand.

Get project versions paginated.
GET /rest/api/3/project/{projectIdOrKey}/version
Path params: projectIdOrKey — The project ID or key (case sensitive).
Query opts: startAt, maxResults, orderBy, query, status, expand.
sourceraw docstring

get-recentclj

(get-recent client)
(get-recent client opts)

Get recent projects. GET /rest/api/3/project/recent Query opts: expand, properties.

Get recent projects.
GET /rest/api/3/project/recent
Query opts: expand, properties.
sourceraw docstring

(get-related-work client id)

Get related work. GET /rest/api/3/version/{id}/relatedwork Path params: id — The ID of the version.

Get related work.
GET /rest/api/3/version/{id}/relatedwork
Path params: id — The ID of the version.
sourceraw docstring

get-valid-project-keyclj

(get-valid-project-key client)
(get-valid-project-key client opts)

Get valid project key. GET /rest/api/3/projectvalidate/validProjectKey Query opts: key.

Get valid project key.
GET /rest/api/3/projectvalidate/validProjectKey
Query opts: key.
sourceraw docstring

get-valid-project-nameclj

(get-valid-project-name client opts)

Get valid project name. GET /rest/api/3/projectvalidate/validProjectName Query params: name (required) — The project name.

Get valid project name.
GET /rest/api/3/projectvalidate/validProjectName
Query params: name (required) — The project name.
sourceraw docstring

get-versionclj

(get-version client id)
(get-version client id opts)

Get version. GET /rest/api/3/version/{id} Path params: id — The ID of the version. Query opts: expand.

Get version.
GET /rest/api/3/version/{id}
Path params: id — The ID of the version.
Query opts: expand.
sourceraw docstring

(get-version-related-issues client id)

Get version's related issues count. GET /rest/api/3/version/{id}/relatedIssueCounts Path params: id — The ID of the version.

Get version's related issues count.
GET /rest/api/3/version/{id}/relatedIssueCounts
Path params: id — The ID of the version.
sourceraw docstring

get-version-unresolved-issuesclj

(get-version-unresolved-issues client id)

Get version's unresolved issues count. GET /rest/api/3/version/{id}/unresolvedIssueCount Path params: id — The ID of the version.

Get version's unresolved issues count.
GET /rest/api/3/version/{id}/unresolvedIssueCount
Path params: id — The ID of the version.
sourceraw docstring

live-templateclj

(live-template client)
(live-template client opts)

Gets a custom project template. GET /rest/api/3/project-template/live-template Query opts: projectId, templateKey.

Gets a custom project template.
GET /rest/api/3/project-template/live-template
Query opts: projectId, templateKey.
sourceraw docstring

merge-versionsclj

(merge-versions client id move-issues-to)

Merge versions. PUT /rest/api/3/version/{id}/mergeto/{moveIssuesTo} Path params: id — The ID of the version to delete; moveIssuesTo — The ID of the version to merge into.

Merge versions.
PUT /rest/api/3/version/{id}/mergeto/{moveIssuesTo}
Path params: id — The ID of the version to delete; moveIssuesTo — The ID of the version to merge into.
sourceraw docstring

move-versionclj

(move-version client id body)
(move-version client id body opts)

Move version. POST /rest/api/3/version/{id}/move Path params: id — The ID of the version to be moved. Body: VersionMoveBean schema.

Move version.
POST /rest/api/3/version/{id}/move
Path params: id — The ID of the version to be moved.
Body: VersionMoveBean schema.
sourceraw docstring

remove-default-project-classificationclj

(remove-default-project-classification client project-id-or-key)

Remove the default data classification level from a project. DELETE /rest/api/3/project/{projectIdOrKey}/classification-level/default Path params: projectIdOrKey — The project ID or key (case-sensitive).

Remove the default data classification level from a project.
DELETE /rest/api/3/project/{projectIdOrKey}/classification-level/default
Path params: projectIdOrKey — The project ID or key (case-sensitive).
sourceraw docstring

remove-project-categoryclj

(remove-project-category client id)

Delete project category. DELETE /rest/api/3/projectCategory/{id} Path params: id — ID of the project category to delete.

Delete project category.
DELETE /rest/api/3/projectCategory/{id}
Path params: id — ID of the project category to delete.
sourceraw docstring

remove-templateclj

(remove-template client opts)

Deletes a custom project template. DELETE /rest/api/3/project-template/remove-template Query params: templateKey (required) — The key of the custom template to remove.

Deletes a custom project template.
DELETE /rest/api/3/project-template/remove-template
Query params: templateKey (required) — The key of the custom template to remove.
sourceraw docstring

restoreclj

(restore client project-id-or-key)

Restore deleted or archived project. POST /rest/api/3/project/{projectIdOrKey}/restore Path params: projectIdOrKey — The project ID or key (case sensitive).

Restore deleted or archived project.
POST /rest/api/3/project/{projectIdOrKey}/restore
Path params: projectIdOrKey — The project ID or key (case sensitive).
sourceraw docstring

save-templateclj

(save-template client body)
(save-template client body opts)

Save a custom project template. POST /rest/api/3/project-template/save-template Body: SaveTemplateRequest schema.

Save a custom project template.
POST /rest/api/3/project-template/save-template
Body: SaveTemplateRequest schema.
sourceraw docstring

search-projectsclj

(search-projects client)
(search-projects client opts)

Get projects paginated. GET /rest/api/3/project/search Query opts: startAt, maxResults, orderBy, id, keys, query, typeKey, categoryId, action, expand, status, properties, propertyQuery.

Get projects paginated.
GET /rest/api/3/project/search
Query opts: startAt, maxResults, orderBy, id, keys, query, typeKey,
            categoryId, action, expand, status, properties, propertyQuery.
sourceraw docstring

set-project-propertyclj

(set-project-property client project-id-or-key property-key body)
(set-project-property client project-id-or-key property-key body opts)

Set project property. PUT /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey} Path params: projectIdOrKey — The project ID or key; propertyKey — The property key (max 255 chars). Body: arbitrary value.

Set project property.
PUT /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey}
Path params: projectIdOrKey — The project ID or key; propertyKey — The property key (max 255 chars).
Body: arbitrary value.
sourceraw docstring

toggle-feature-for-projectclj

(toggle-feature-for-project client project-id-or-key feature-key body)
(toggle-feature-for-project client project-id-or-key feature-key body opts)

Set project feature state. PUT /rest/api/3/project/{projectIdOrKey}/features/{featureKey} Path params: projectIdOrKey — The ID or key of the project; featureKey — The key of the feature. Body: ProjectFeatureState schema.

Set project feature state.
PUT /rest/api/3/project/{projectIdOrKey}/features/{featureKey}
Path params: projectIdOrKey — The ID or key of the project; featureKey — The key of the feature.
Body: ProjectFeatureState schema.
sourceraw docstring

update-componentclj

(update-component client id body)
(update-component client id body opts)

Update component. PUT /rest/api/3/component/{id} Path params: id — The ID of the component. Body: ProjectComponent schema.

Update component.
PUT /rest/api/3/component/{id}
Path params: id — The ID of the component.
Body: ProjectComponent schema.
sourceraw docstring

update-default-project-classificationclj

(update-default-project-classification client project-id-or-key body)
(update-default-project-classification client project-id-or-key body opts)

Update the default data classification level of a project. PUT /rest/api/3/project/{projectIdOrKey}/classification-level/default Path params: projectIdOrKey — The project ID or key (case-sensitive). Body: UpdateDefaultProjectClassificationBean schema.

Update the default data classification level of a project.
PUT /rest/api/3/project/{projectIdOrKey}/classification-level/default
Path params: projectIdOrKey — The project ID or key (case-sensitive).
Body: UpdateDefaultProjectClassificationBean schema.
sourceraw docstring

update-projectclj

(update-project client project-id-or-key body)
(update-project client project-id-or-key body opts)

Update project. PUT /rest/api/3/project/{projectIdOrKey} Path params: projectIdOrKey — The project ID or key (case sensitive). Body: UpdateProjectDetails schema. Query opts: expand.

Update project.
PUT /rest/api/3/project/{projectIdOrKey}
Path params: projectIdOrKey — The project ID or key (case sensitive).
Body: UpdateProjectDetails schema.
Query opts: expand.
sourceraw docstring

update-project-avatarclj

(update-project-avatar client project-id-or-key body)
(update-project-avatar client project-id-or-key body opts)

Set project avatar. PUT /rest/api/3/project/{projectIdOrKey}/avatar Path params: projectIdOrKey — The ID or key of the project. Body: Avatar schema.

Set project avatar.
PUT /rest/api/3/project/{projectIdOrKey}/avatar
Path params: projectIdOrKey — The ID or key of the project.
Body: Avatar schema.
sourceraw docstring

update-project-categoryclj

(update-project-category client id body)
(update-project-category client id body opts)

Update project category. PUT /rest/api/3/projectCategory/{id} Path params: id — The project category ID. Body: ProjectCategory schema.

Update project category.
PUT /rest/api/3/projectCategory/{id}
Path params: id — The project category ID.
Body: ProjectCategory schema.
sourceraw docstring

update-project-emailclj

(update-project-email client project-id body)
(update-project-email client project-id body opts)

Set project's sender email. PUT /rest/api/3/project/{projectId}/email Path params: projectId — The project ID. Body: ProjectEmailAddress schema.

Set project's sender email.
PUT /rest/api/3/project/{projectId}/email
Path params: projectId — The project ID.
Body: ProjectEmailAddress schema.
sourceraw docstring

(update-related-work client id body)
(update-related-work client id body opts)

Update related work. PUT /rest/api/3/version/{id}/relatedwork Path params: id — The ID of the version. Body: VersionRelatedWork schema.

Update related work.
PUT /rest/api/3/version/{id}/relatedwork
Path params: id — The ID of the version.
Body: VersionRelatedWork schema.
sourceraw docstring

update-versionclj

(update-version client id body)
(update-version client id body opts)

Update version. PUT /rest/api/3/version/{id} Path params: id — The ID of the version. Body: Version schema.

Update version.
PUT /rest/api/3/version/{id}
Path params: id — The ID of the version.
Body: Version schema.
sourceraw docstring

validate-project-keyclj

(validate-project-key client)
(validate-project-key client opts)

Validate project key. GET /rest/api/3/projectvalidate/key Query opts: key.

Validate project key.
GET /rest/api/3/projectvalidate/key
Query opts: key.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries