Jira Cloud screens, screen tabs, screen tab fields, and screen schemes.
Jira Cloud screens, screen tabs, screen tab fields, and screen schemes.
(add-field-to-default-screen client field-id)Add field to default screen. POST /rest/api/3/screens/addToDefault/{fieldId} Path params: fieldId - The ID of the field.
Add field to default screen.
POST /rest/api/3/screens/addToDefault/{fieldId}
Path params: fieldId - The ID of the field.(add-screen-tab client screen-id body)Create screen tab. POST /rest/api/3/screens/{screenId}/tabs Path params: screenId - The ID of the screen. Body: ScreenableTab — {:name "..."} (:name required, max 255 chars)
Create screen tab.
POST /rest/api/3/screens/{screenId}/tabs
Path params: screenId - The ID of the screen.
Body: ScreenableTab — {:name "..."} (:name required, max 255 chars)(add-screen-tab-field client screen-id tab-id body)(add-screen-tab-field client screen-id tab-id body opts)Add screen tab field. POST /rest/api/3/screens/{screenId}/tabs/{tabId}/fields Path params: screenId - The ID of the screen, tabId - The ID of the screen tab. Body: AddFieldBean — {:fieldId "..."} (:fieldId required) opts: :skipFieldAssociation
Add screen tab field.
POST /rest/api/3/screens/{screenId}/tabs/{tabId}/fields
Path params: screenId - The ID of the screen, tabId - The ID of the screen tab.
Body: AddFieldBean — {:fieldId "..."} (:fieldId required)
opts: :skipFieldAssociation(create-screen client body)(create-screen client body opts)Create screen. POST /rest/api/3/screens Body: ScreenDetails — {:name "..." :description "..."} :name is required, max 255 chars.
Create screen.
POST /rest/api/3/screens
Body: ScreenDetails — {:name "..." :description "..."}
:name is required, max 255 chars.(create-screen-scheme client body)(create-screen-scheme client body opts)Create screen scheme. POST /rest/api/3/screenscheme Body: ScreenSchemeDetails — {:name "..." :screens {...} :description "..."} :name and :screens are required.
Create screen scheme.
POST /rest/api/3/screenscheme
Body: ScreenSchemeDetails — {:name "..." :screens {...} :description "..."}
:name and :screens are required.(delete-screen client screen-id)Delete screen. DELETE /rest/api/3/screens/{screenId} Path params: screenId - The ID of the screen.
Delete screen.
DELETE /rest/api/3/screens/{screenId}
Path params: screenId - The ID of the screen.(delete-screen-scheme client screen-scheme-id)Delete screen scheme. DELETE /rest/api/3/screenscheme/{screenSchemeId} Path params: screenSchemeId - The ID of the screen scheme.
Delete screen scheme.
DELETE /rest/api/3/screenscheme/{screenSchemeId}
Path params: screenSchemeId - The ID of the screen scheme.(delete-screen-tab client screen-id tab-id)Delete screen tab. DELETE /rest/api/3/screens/{screenId}/tabs/{tabId} Path params: screenId - The ID of the screen, tabId - The ID of the screen tab.
Delete screen tab.
DELETE /rest/api/3/screens/{screenId}/tabs/{tabId}
Path params: screenId - The ID of the screen, tabId - The ID of the screen tab.(get-all-screen-tab-fields client screen-id tab-id)(get-all-screen-tab-fields client screen-id tab-id opts)Get all screen tab fields. GET /rest/api/3/screens/{screenId}/tabs/{tabId}/fields Path params: screenId - The ID of the screen, tabId - The ID of the screen tab. opts: :projectKey
Get all screen tab fields.
GET /rest/api/3/screens/{screenId}/tabs/{tabId}/fields
Path params: screenId - The ID of the screen, tabId - The ID of the screen tab.
opts: :projectKey(get-all-screen-tabs client screen-id)(get-all-screen-tabs client screen-id opts)Get all screen tabs. GET /rest/api/3/screens/{screenId}/tabs Path params: screenId - The ID of the screen. opts: :projectKey
Get all screen tabs.
GET /rest/api/3/screens/{screenId}/tabs
Path params: screenId - The ID of the screen.
opts: :projectKey(get-available-screen-fields client screen-id)Get available screen fields. GET /rest/api/3/screens/{screenId}/availableFields Path params: screenId - The ID of the screen.
Get available screen fields.
GET /rest/api/3/screens/{screenId}/availableFields
Path params: screenId - The ID of the screen.(get-bulk-screen-tabs client)(get-bulk-screen-tabs client opts)Get bulk screen tabs. GET /rest/api/3/screens/tabs opts: :screenId, :tabId, :startAt, :maxResult
Get bulk screen tabs. GET /rest/api/3/screens/tabs opts: :screenId, :tabId, :startAt, :maxResult
(get-screen-schemes client)(get-screen-schemes client opts)Get screen schemes. GET /rest/api/3/screenscheme opts: :startAt, :maxResults, :id, :expand, :queryString, :orderBy
Get screen schemes. GET /rest/api/3/screenscheme opts: :startAt, :maxResults, :id, :expand, :queryString, :orderBy
(get-screens client)(get-screens client opts)Get screens. GET /rest/api/3/screens opts: :startAt, :maxResults, :id, :queryString, :scope, :orderBy
Get screens. GET /rest/api/3/screens opts: :startAt, :maxResults, :id, :queryString, :scope, :orderBy
(get-screens-for-field client field-id)(get-screens-for-field client field-id opts)Get screens for a field. GET /rest/api/3/field/{fieldId}/screens Path params: fieldId - The ID of the field. opts: :startAt, :maxResults, :expand
Get screens for a field.
GET /rest/api/3/field/{fieldId}/screens
Path params: fieldId - The ID of the field.
opts: :startAt, :maxResults, :expand(move-screen-tab client screen-id tab-id pos)Move screen tab. POST /rest/api/3/screens/{screenId}/tabs/{tabId}/move/{pos} Path params: screenId - The ID of the screen, tabId - The ID of the tab, pos - The position (0-based index).
Move screen tab.
POST /rest/api/3/screens/{screenId}/tabs/{tabId}/move/{pos}
Path params: screenId - The ID of the screen, tabId - The ID of the tab,
pos - The position (0-based index).(move-screen-tab-field client screen-id tab-id field-id body)Move screen tab field. POST /rest/api/3/screens/{screenId}/tabs/{tabId}/fields/{id}/move Path params: screenId - The ID of the screen, tabId - The ID of the screen tab, id - The ID of the field. Body: MoveFieldBean — {:after "<uri>"} or {:position "Earlier|Later|First|Last"}
Move screen tab field.
POST /rest/api/3/screens/{screenId}/tabs/{tabId}/fields/{id}/move
Path params: screenId - The ID of the screen, tabId - The ID of the screen tab,
id - The ID of the field.
Body: MoveFieldBean — {:after "<uri>"} or {:position "Earlier|Later|First|Last"}(remove-screen-tab-field client screen-id tab-id field-id)Remove screen tab field. DELETE /rest/api/3/screens/{screenId}/tabs/{tabId}/fields/{id} Path params: screenId - The ID of the screen, tabId - The ID of the screen tab, id - The ID of the field.
Remove screen tab field.
DELETE /rest/api/3/screens/{screenId}/tabs/{tabId}/fields/{id}
Path params: screenId - The ID of the screen, tabId - The ID of the screen tab,
id - The ID of the field.(rename-screen-tab client screen-id tab-id body)Update screen tab. PUT /rest/api/3/screens/{screenId}/tabs/{tabId} Path params: screenId - The ID of the screen, tabId - The ID of the screen tab. Body: ScreenableTab — {:name "..."} (:name required, max 255 chars)
Update screen tab.
PUT /rest/api/3/screens/{screenId}/tabs/{tabId}
Path params: screenId - The ID of the screen, tabId - The ID of the screen tab.
Body: ScreenableTab — {:name "..."} (:name required, max 255 chars)(update-screen client screen-id body)(update-screen client screen-id body opts)Update screen. PUT /rest/api/3/screens/{screenId} Path params: screenId - The ID of the screen. Body: UpdateScreenDetails — {:name "..." :description "..."}
Update screen.
PUT /rest/api/3/screens/{screenId}
Path params: screenId - The ID of the screen.
Body: UpdateScreenDetails — {:name "..." :description "..."}(update-screen-scheme client screen-scheme-id body)(update-screen-scheme client screen-scheme-id body opts)Update screen scheme. PUT /rest/api/3/screenscheme/{screenSchemeId} Path params: screenSchemeId - The ID of the screen scheme. Body: UpdateScreenSchemeDetails — {:name "..." :description "..." :screens {...}}
Update screen scheme.
PUT /rest/api/3/screenscheme/{screenSchemeId}
Path params: screenSchemeId - The ID of the screen scheme.
Body: UpdateScreenSchemeDetails — {:name "..." :description "..." :screens {...}}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |