Jira Cloud endpoint functions for issue watchers and votes.
Covers the Issue watchers and Issue votes API surfaces:
Jira Cloud endpoint functions for issue watchers and votes.
Covers the Issue watchers and Issue votes API surfaces:
- bulk-is-watching POST /rest/api/3/issue/watching
- get-votes GET /rest/api/3/issue/{issueIdOrKey}/votes
- add-vote POST /rest/api/3/issue/{issueIdOrKey}/votes
- remove-vote DELETE /rest/api/3/issue/{issueIdOrKey}/votes
- get-issue-watchers GET /rest/api/3/issue/{issueIdOrKey}/watchers
- add-watcher POST /rest/api/3/issue/{issueIdOrKey}/watchers
- remove-watcher DELETE /rest/api/3/issue/{issueIdOrKey}/watchers(add-vote client issue-id-or-key)Add vote — adds the current user's vote to an issue. POST /rest/api/3/issue/{issueIdOrKey}/votes
Path params: issueIdOrKey — The ID or key of the issue.
Add vote — adds the current user's vote to an issue.
POST /rest/api/3/issue/{issueIdOrKey}/votes
Path params:
issueIdOrKey — The ID or key of the issue.(add-watcher client issue-id-or-key body)Add watcher — adds a user as a watcher of an issue by passing the accountId. POST /rest/api/3/issue/{issueIdOrKey}/watchers
Path params: issueIdOrKey — The ID or key of the issue.
Body: a plain string — the accountId of the user to add as a watcher, e.g. "5b10ac8d82e05b22cc7d4ef5".
Add watcher — adds a user as a watcher of an issue by passing the accountId.
POST /rest/api/3/issue/{issueIdOrKey}/watchers
Path params:
issueIdOrKey — The ID or key of the issue.
Body: a plain string — the accountId of the user to add as a watcher,
e.g. "5b10ac8d82e05b22cc7d4ef5".(bulk-is-watching client body)Get is watching issue bulk — returns watching status for multiple issues. POST /rest/api/3/issue/watching
Body: IssueList — {:issueIds ["10001" "10002" ...]}
Get is watching issue bulk — returns watching status for multiple issues.
POST /rest/api/3/issue/watching
Body: IssueList — {:issueIds ["10001" "10002" ...]}(get-issue-watchers client issue-id-or-key)Get issue watchers — returns the watchers for an issue. GET /rest/api/3/issue/{issueIdOrKey}/watchers
Path params: issueIdOrKey — The ID or key of the issue.
Get issue watchers — returns the watchers for an issue.
GET /rest/api/3/issue/{issueIdOrKey}/watchers
Path params:
issueIdOrKey — The ID or key of the issue.(get-votes client issue-id-or-key)Get votes — returns details about votes on an issue, including a list of voters. GET /rest/api/3/issue/{issueIdOrKey}/votes
Path params: issueIdOrKey — The ID or key of the issue.
Get votes — returns details about votes on an issue, including a list of voters.
GET /rest/api/3/issue/{issueIdOrKey}/votes
Path params:
issueIdOrKey — The ID or key of the issue.(remove-vote client issue-id-or-key)Delete vote — deletes a user's vote from an issue. DELETE /rest/api/3/issue/{issueIdOrKey}/votes
Path params: issueIdOrKey — The ID or key of the issue.
Delete vote — deletes a user's vote from an issue.
DELETE /rest/api/3/issue/{issueIdOrKey}/votes
Path params:
issueIdOrKey — The ID or key of the issue.(remove-watcher client issue-id-or-key)(remove-watcher client issue-id-or-key opts)Delete watcher — removes a user from watching an issue. DELETE /rest/api/3/issue/{issueIdOrKey}/watchers
Path params: issueIdOrKey — The ID or key of the issue.
Query params (opts): :accountId — The account ID of the user to remove (required in practice). :username — Deprecated. Use :accountId instead.
Delete watcher — removes a user from watching an issue.
DELETE /rest/api/3/issue/{issueIdOrKey}/watchers
Path params:
issueIdOrKey — The ID or key of the issue.
Query params (opts):
:accountId — The account ID of the user to remove (required in practice).
:username — Deprecated. Use :accountId instead.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |