Bitbucket Cloud pull-requests API endpoint functions.
All functions take a client (from atlassian.bitbucket.client/client) as
their first argument, followed by required path params positionally, then an
optional body (for write ops) and/or an opts map for query params.
Pagination: list endpoints return {:values [...] :next "<full-url>" ...}.
Pass page, pagelen, q, sort, fields in opts; follow :next via
atlassian.bitbucket.client/request-url.
Bitbucket Cloud pull-requests API endpoint functions.
All functions take a `client` (from `atlassian.bitbucket.client/client`) as
their first argument, followed by required path params positionally, then an
optional `body` (for write ops) and/or an `opts` map for query params.
Pagination: list endpoints return `{:values [...] :next "<full-url>" ...}`.
Pass `page`, `pagelen`, `q`, `sort`, `fields` in opts; follow `:next` via
`atlassian.bitbucket.client/request-url`.(create-pullrequests client workspace repo-slug body)(create-pullrequests client workspace repo-slug body opts)Create a pull request. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests Required: workspace, repo-slug Body: pullrequest schema
Create a pull request.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests
Required: workspace, repo-slug
Body: pullrequest schema(create-pullrequests-approve client workspace repo-slug pull-request-id)Approve a pull request. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/approve Required: workspace, repo-slug, pull-request-id
Approve a pull request.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/approve
Required: workspace, repo-slug, pull-request-id(create-pullrequests-comments client workspace repo-slug pull-request-id body)(create-pullrequests-comments client
workspace
repo-slug
pull-request-id
body
opts)Create a comment on a pull request. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments Required: workspace, repo-slug, pull-request-id Body: pullrequest_comment schema
Create a comment on a pull request.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments
Required: workspace, repo-slug, pull-request-id
Body: pullrequest_comment schema(create-pullrequests-comments-resolve client
workspace
repo-slug
pull-request-id
comment-id)Resolve a comment thread. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id}/resolve Required: workspace, repo-slug, pull-request-id, comment-id
Resolve a comment thread.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id}/resolve
Required: workspace, repo-slug, pull-request-id, comment-id(create-pullrequests-decline client workspace repo-slug pull-request-id)Decline a pull request. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/decline Required: workspace, repo-slug, pull-request-id
Decline a pull request.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/decline
Required: workspace, repo-slug, pull-request-id(create-pullrequests-merge client workspace repo-slug pull-request-id body)(create-pullrequests-merge client workspace repo-slug pull-request-id body opts)Merge a pull request. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/merge Required: workspace, repo-slug, pull-request-id Body: pullrequest_merge_parameters schema Query opts: async (boolean, default false; when true runs merge asynchronously)
Merge a pull request.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/merge
Required: workspace, repo-slug, pull-request-id
Body: pullrequest_merge_parameters schema
Query opts: async (boolean, default false; when true runs merge asynchronously)(create-pullrequests-request-changes client workspace repo-slug pull-request-id)Request changes for a pull request. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/request-changes Required: workspace, repo-slug, pull-request-id
Request changes for a pull request.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/request-changes
Required: workspace, repo-slug, pull-request-id(create-pullrequests-tasks client workspace repo-slug pull-request-id body)(create-pullrequests-tasks client workspace repo-slug pull-request-id body opts)Create a task on a pull request. POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks Required: workspace, repo-slug, pull-request-id Body: pullrequest_task_create schema
Create a task on a pull request.
POST /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks
Required: workspace, repo-slug, pull-request-id
Body: pullrequest_task_create schema(delete-default-reviewers client workspace repo-slug target-username)Remove a user from the default reviewers. DELETE /2.0/repositories/{workspace}/{repo_slug}/default-reviewers/{target_username} Required: workspace, repo-slug, target-username
Remove a user from the default reviewers.
DELETE /2.0/repositories/{workspace}/{repo_slug}/default-reviewers/{target_username}
Required: workspace, repo-slug, target-username(delete-pullrequests-approve client workspace repo-slug pull-request-id)Unapprove a pull request. DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/approve Required: workspace, repo-slug, pull-request-id
Unapprove a pull request.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/approve
Required: workspace, repo-slug, pull-request-id(delete-pullrequests-comments client
workspace
repo-slug
pull-request-id
comment-id)Delete a comment on a pull request. DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id} Required: workspace, repo-slug, pull-request-id, comment-id
Delete a comment on a pull request.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id}
Required: workspace, repo-slug, pull-request-id, comment-id(delete-pullrequests-comments-resolve client
workspace
repo-slug
pull-request-id
comment-id)Reopen a comment thread. DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id}/resolve Required: workspace, repo-slug, pull-request-id, comment-id
Reopen a comment thread.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id}/resolve
Required: workspace, repo-slug, pull-request-id, comment-id(delete-pullrequests-request-changes client workspace repo-slug pull-request-id)Remove change request for a pull request. DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/request-changes Required: workspace, repo-slug, pull-request-id
Remove change request for a pull request.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/request-changes
Required: workspace, repo-slug, pull-request-id(delete-pullrequests-tasks client workspace repo-slug pull-request-id task-id)Delete a task on a pull request. DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks/{task_id} Required: workspace, repo-slug, pull-request-id, task-id
Delete a task on a pull request.
DELETE /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks/{task_id}
Required: workspace, repo-slug, pull-request-id, task-id(get-default-reviewers client workspace repo-slug target-username)(get-default-reviewers client workspace repo-slug target-username opts)Get a default reviewer. GET /2.0/repositories/{workspace}/{repo_slug}/default-reviewers/{target_username} Required: workspace, repo-slug, target-username Query opts: passed through as query params (e.g. fields).
Get a default reviewer.
GET /2.0/repositories/{workspace}/{repo_slug}/default-reviewers/{target_username}
Required: workspace, repo-slug, target-username
Query opts: passed through as query params (e.g. fields).(get-pullrequests-by-workspace-repo-slug-pull-request-id client
workspace
repo-slug
pull-request-id)(get-pullrequests-by-workspace-repo-slug-pull-request-id client
workspace
repo-slug
pull-request-id
opts)Get a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id} Required: workspace, repo-slug, pull-request-id Query opts: passed through as query params (e.g. fields).
Get a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}
Required: workspace, repo-slug, pull-request-id
Query opts: passed through as query params (e.g. fields).(get-pullrequests-by-workspace-selected-user client workspace selected-user)(get-pullrequests-by-workspace-selected-user client
workspace
selected-user
opts)List workspace pull requests for a user. GET /2.0/workspaces/{workspace}/pullrequests/{selected_user} Required: workspace, selected-user Query opts: state, page, pagelen
List workspace pull requests for a user.
GET /2.0/workspaces/{workspace}/pullrequests/{selected_user}
Required: workspace, selected-user
Query opts: state, page, pagelen(get-pullrequests-comments client
workspace
repo-slug
pull-request-id
comment-id)(get-pullrequests-comments client
workspace
repo-slug
pull-request-id
comment-id
opts)Get a comment on a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id} Required: workspace, repo-slug, pull-request-id, comment-id Query opts: passed through as query params (e.g. fields).
Get a comment on a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id}
Required: workspace, repo-slug, pull-request-id, comment-id
Query opts: passed through as query params (e.g. fields).(get-pullrequests-merge-task-status client
workspace
repo-slug
pull-request-id
task-id)(get-pullrequests-merge-task-status client
workspace
repo-slug
pull-request-id
task-id
opts)Get the merge task status for a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/merge/task-status/{task_id} Required: workspace, repo-slug, pull-request-id, task-id Query opts: passed through as query params (e.g. fields).
Get the merge task status for a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/merge/task-status/{task_id}
Required: workspace, repo-slug, pull-request-id, task-id
Query opts: passed through as query params (e.g. fields).(get-pullrequests-tasks client workspace repo-slug pull-request-id task-id)(get-pullrequests-tasks client workspace repo-slug pull-request-id task-id opts)Get a task on a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks/{task_id} Required: workspace, repo-slug, pull-request-id, task-id Query opts: passed through as query params (e.g. fields).
Get a task on a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks/{task_id}
Required: workspace, repo-slug, pull-request-id, task-id
Query opts: passed through as query params (e.g. fields).(list-commit-pullrequests client workspace repo-slug commit)(list-commit-pullrequests client workspace repo-slug commit opts)List pull requests that contain a commit. GET /2.0/repositories/{workspace}/{repo_slug}/commit/{commit}/pullrequests Required: workspace, repo-slug, commit Query opts: page, pagelen
List pull requests that contain a commit.
GET /2.0/repositories/{workspace}/{repo_slug}/commit/{commit}/pullrequests
Required: workspace, repo-slug, commit
Query opts: page, pagelen(list-default-reviewers client workspace repo-slug)(list-default-reviewers client workspace repo-slug opts)List default reviewers. GET /2.0/repositories/{workspace}/{repo_slug}/default-reviewers Required: workspace, repo-slug Query opts: page, pagelen
List default reviewers.
GET /2.0/repositories/{workspace}/{repo_slug}/default-reviewers
Required: workspace, repo-slug
Query opts: page, pagelen(list-effective-default-reviewers client workspace repo-slug)(list-effective-default-reviewers client workspace repo-slug opts)List effective default reviewers. GET /2.0/repositories/{workspace}/{repo_slug}/effective-default-reviewers Required: workspace, repo-slug Query opts: page, pagelen
List effective default reviewers.
GET /2.0/repositories/{workspace}/{repo_slug}/effective-default-reviewers
Required: workspace, repo-slug
Query opts: page, pagelen(list-pullrequests client workspace repo-slug)(list-pullrequests client workspace repo-slug opts)List pull requests. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests Required: workspace, repo-slug Query opts: state, page, pagelen, q, sort
List pull requests.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests
Required: workspace, repo-slug
Query opts: state, page, pagelen, q, sort(list-pullrequests-activity-by-workspace-repo-slug client workspace repo-slug)(list-pullrequests-activity-by-workspace-repo-slug client
workspace
repo-slug
opts)List a pull request activity log (repository-level). GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/activity Required: workspace, repo-slug Query opts: page, pagelen
List a pull request activity log (repository-level).
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/activity
Required: workspace, repo-slug
Query opts: page, pagelen(list-pullrequests-activity-by-workspace-repo-slug-pull-request-id
client
workspace
repo-slug
pull-request-id)(list-pullrequests-activity-by-workspace-repo-slug-pull-request-id
client
workspace
repo-slug
pull-request-id
opts)List a pull request activity log (PR-level). GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/activity Required: workspace, repo-slug, pull-request-id Query opts: page, pagelen
List a pull request activity log (PR-level).
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/activity
Required: workspace, repo-slug, pull-request-id
Query opts: page, pagelen(list-pullrequests-comments client workspace repo-slug pull-request-id)(list-pullrequests-comments client workspace repo-slug pull-request-id opts)List comments on a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments Required: workspace, repo-slug, pull-request-id Query opts: page, pagelen, q, sort
List comments on a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments
Required: workspace, repo-slug, pull-request-id
Query opts: page, pagelen, q, sort(list-pullrequests-commits client workspace repo-slug pull-request-id)(list-pullrequests-commits client workspace repo-slug pull-request-id opts)List commits on a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/commits Required: workspace, repo-slug, pull-request-id Query opts: page, pagelen
List commits on a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/commits
Required: workspace, repo-slug, pull-request-id
Query opts: page, pagelen(list-pullrequests-conflicts client workspace repo-slug pull-request-id)(list-pullrequests-conflicts client workspace repo-slug pull-request-id opts)Get file conflicts for a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/conflicts Required: workspace, repo-slug, pull-request-id Query opts: page, pagelen
Get file conflicts for a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/conflicts
Required: workspace, repo-slug, pull-request-id
Query opts: page, pagelen(list-pullrequests-diff client workspace repo-slug pull-request-id)(list-pullrequests-diff client workspace repo-slug pull-request-id opts)List changes in a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/diff Required: workspace, repo-slug, pull-request-id Query opts: passed through as query params (e.g. fields).
List changes in a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/diff
Required: workspace, repo-slug, pull-request-id
Query opts: passed through as query params (e.g. fields).(list-pullrequests-diffstat client workspace repo-slug pull-request-id)(list-pullrequests-diffstat client workspace repo-slug pull-request-id opts)Get the diff stat for a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/diffstat Required: workspace, repo-slug, pull-request-id Query opts: page, pagelen
Get the diff stat for a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/diffstat
Required: workspace, repo-slug, pull-request-id
Query opts: page, pagelen(list-pullrequests-patch client workspace repo-slug pull-request-id)(list-pullrequests-patch client workspace repo-slug pull-request-id opts)Get the patch for a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/patch Required: workspace, repo-slug, pull-request-id Query opts: passed through as query params (e.g. fields).
Get the patch for a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/patch
Required: workspace, repo-slug, pull-request-id
Query opts: passed through as query params (e.g. fields).(list-pullrequests-statuses client workspace repo-slug pull-request-id)(list-pullrequests-statuses client workspace repo-slug pull-request-id opts)List commit statuses for a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/statuses Required: workspace, repo-slug, pull-request-id Query opts: q, sort, page, pagelen
List commit statuses for a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/statuses
Required: workspace, repo-slug, pull-request-id
Query opts: q, sort, page, pagelen(list-pullrequests-tasks client workspace repo-slug pull-request-id)(list-pullrequests-tasks client workspace repo-slug pull-request-id opts)List tasks on a pull request. GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks Required: workspace, repo-slug, pull-request-id Query opts: q, sort, pagelen
List tasks on a pull request.
GET /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks
Required: workspace, repo-slug, pull-request-id
Query opts: q, sort, pagelen(update-default-reviewers client workspace repo-slug target-username)Add a user to the default reviewers. PUT /2.0/repositories/{workspace}/{repo_slug}/default-reviewers/{target_username} Required: workspace, repo-slug, target-username
Add a user to the default reviewers.
PUT /2.0/repositories/{workspace}/{repo_slug}/default-reviewers/{target_username}
Required: workspace, repo-slug, target-username(update-pullrequests client workspace repo-slug pull-request-id body)(update-pullrequests client workspace repo-slug pull-request-id body opts)Update a pull request. PUT /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id} Required: workspace, repo-slug, pull-request-id Body: pullrequest schema
Update a pull request.
PUT /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}
Required: workspace, repo-slug, pull-request-id
Body: pullrequest schema(update-pullrequests-comments client
workspace
repo-slug
pull-request-id
comment-id
body)(update-pullrequests-comments client
workspace
repo-slug
pull-request-id
comment-id
body
opts)Update a comment on a pull request. PUT /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id} Required: workspace, repo-slug, pull-request-id, comment-id Body: pullrequest_comment schema
Update a comment on a pull request.
PUT /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/comments/{comment_id}
Required: workspace, repo-slug, pull-request-id, comment-id
Body: pullrequest_comment schema(update-pullrequests-tasks client
workspace
repo-slug
pull-request-id
task-id
body)(update-pullrequests-tasks client
workspace
repo-slug
pull-request-id
task-id
body
opts)Update a task on a pull request. PUT /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks/{task_id} Required: workspace, repo-slug, pull-request-id, task-id Body: pullrequest_task_update schema
Update a task on a pull request.
PUT /2.0/repositories/{workspace}/{repo_slug}/pullrequests/{pull_request_id}/tasks/{task_id}
Required: workspace, repo-slug, pull-request-id, task-id
Body: pullrequest_task_update schemacljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |