Bitbucket webhooks API — subscription and event-type management.
All functions take a client as their first argument (from
atlassian.bitbucket.client/client). Path params are positional; query
params and optional options go in a trailing opts map (default {}).
Write operations accept a body map before the opts map.
Pagination: list responses return {:values [...] :next "<full-url>" ...}.
Pass :page, :pagelen, :q, :sort, :fields in opts; follow
:next via atlassian.bitbucket.client/request-url.
Bitbucket webhooks API — subscription and event-type management.
All functions take a `client` as their first argument (from
`atlassian.bitbucket.client/client`). Path params are positional; query
params and optional options go in a trailing `opts` map (default `{}`).
Write operations accept a `body` map before the opts map.
Pagination: list responses return `{:values [...] :next "<full-url>" ...}`.
Pass `:page`, `:pagelen`, `:q`, `:sort`, `:fields` in `opts`; follow
`:next` via `atlassian.bitbucket.client/request-url`.(create-hooks-by-workspace client workspace body)(create-hooks-by-workspace client workspace body opts)Create a webhook for a workspace. POST /2.0/workspaces/{workspace}/hooks Path params: workspace
Create a webhook for a workspace.
POST /2.0/workspaces/{workspace}/hooks
Path params: workspace(create-hooks-by-workspace-repo-slug client workspace repo-slug body)(create-hooks-by-workspace-repo-slug client workspace repo-slug body opts)Create a webhook for a repository. POST /2.0/repositories/{workspace}/{repo_slug}/hooks Path params: workspace, repo-slug
Create a webhook for a repository.
POST /2.0/repositories/{workspace}/{repo_slug}/hooks
Path params: workspace, repo-slug(delete-hooks-by-workspace-repo-slug-uid client workspace repo-slug uid)Delete a webhook for a repository. DELETE /2.0/repositories/{workspace}/{repo_slug}/hooks/{uid} Path params: workspace, repo-slug, uid
Delete a webhook for a repository.
DELETE /2.0/repositories/{workspace}/{repo_slug}/hooks/{uid}
Path params: workspace, repo-slug, uid(delete-hooks-by-workspace-uid client workspace uid)Delete a webhook for a workspace. DELETE /2.0/workspaces/{workspace}/hooks/{uid} Path params: workspace, uid
Delete a webhook for a workspace.
DELETE /2.0/workspaces/{workspace}/hooks/{uid}
Path params: workspace, uid(get-hook-events client subject-type)(get-hook-events client subject-type opts)List subscribable webhook types for a given subject-type. GET /2.0/hook_events/{subject_type} Path params: subject-type Query opts: passed through as query params (e.g. fields).
List subscribable webhook types for a given subject-type.
GET /2.0/hook_events/{subject_type}
Path params: subject-type
Query opts: passed through as query params (e.g. fields).(get-hooks-by-workspace-repo-slug-uid client workspace repo-slug uid)(get-hooks-by-workspace-repo-slug-uid client workspace repo-slug uid opts)Get a webhook for a repository. GET /2.0/repositories/{workspace}/{repo_slug}/hooks/{uid} Path params: workspace, repo-slug, uid Query opts: passed through as query params (e.g. fields).
Get a webhook for a repository.
GET /2.0/repositories/{workspace}/{repo_slug}/hooks/{uid}
Path params: workspace, repo-slug, uid
Query opts: passed through as query params (e.g. fields).(get-hooks-by-workspace-uid client workspace uid)(get-hooks-by-workspace-uid client workspace uid opts)Get a webhook for a workspace. GET /2.0/workspaces/{workspace}/hooks/{uid} Path params: workspace, uid Query opts: passed through as query params (e.g. fields).
Get a webhook for a workspace.
GET /2.0/workspaces/{workspace}/hooks/{uid}
Path params: workspace, uid
Query opts: passed through as query params (e.g. fields).(list-hook-events client)(list-hook-events client opts)Get a webhook resource. GET /2.0/hook_events Query opts: passed through as query params (e.g. fields).
Get a webhook resource. GET /2.0/hook_events Query opts: passed through as query params (e.g. fields).
(list-hooks-by-workspace client workspace)(list-hooks-by-workspace client workspace opts)List webhooks for a workspace. GET /2.0/workspaces/{workspace}/hooks Path params: workspace
List webhooks for a workspace.
GET /2.0/workspaces/{workspace}/hooks
Path params: workspace(list-hooks-by-workspace-repo-slug client workspace repo-slug)(list-hooks-by-workspace-repo-slug client workspace repo-slug opts)List webhooks for a repository. GET /2.0/repositories/{workspace}/{repo_slug}/hooks Path params: workspace, repo-slug
List webhooks for a repository.
GET /2.0/repositories/{workspace}/{repo_slug}/hooks
Path params: workspace, repo-slug(update-hooks-by-workspace-repo-slug-uid client workspace repo-slug uid body)(update-hooks-by-workspace-repo-slug-uid client
workspace
repo-slug
uid
body
opts)Update a webhook for a repository. PUT /2.0/repositories/{workspace}/{repo_slug}/hooks/{uid} Path params: workspace, repo-slug, uid
Update a webhook for a repository.
PUT /2.0/repositories/{workspace}/{repo_slug}/hooks/{uid}
Path params: workspace, repo-slug, uid(update-hooks-by-workspace-uid client workspace uid body)(update-hooks-by-workspace-uid client workspace uid body opts)Update a webhook for a workspace. PUT /2.0/workspaces/{workspace}/hooks/{uid} Path params: workspace, uid
Update a webhook for a workspace.
PUT /2.0/workspaces/{workspace}/hooks/{uid}
Path params: workspace, uidcljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |