Confluence v1 admin endpoints: analytics, audit, long-running tasks, relations, settings (look-and-feel, themes), space labels/themes, and templates.
Confluence v1 admin endpoints: analytics, audit, long-running tasks, relations, settings (look-and-feel, themes), space labels/themes, and templates.
(add-labels-to-space client space-key body)(add-labels-to-space client space-key body opts)Add labels to a space. POST /wiki/rest/api/space/{spaceKey}/label Path params: spaceKey Body: array of label objects
Add labels to a space.
POST /wiki/rest/api/space/{spaceKey}/label
Path params: spaceKey
Body: array of label objects(create-audit-record client body)(create-audit-record client body opts)Create audit record. POST /wiki/rest/api/audit Body: AuditRecordCreate
Create audit record. POST /wiki/rest/api/audit Body: AuditRecordCreate
(create-content-template client body)(create-content-template client body opts)Create content template. POST /wiki/rest/api/template Body: ContentTemplateCreate
Create content template. POST /wiki/rest/api/template Body: ContentTemplateCreate
(create-relationship client
relation-name
source-type
source-key
target-type
target-key)(create-relationship client
relation-name
source-type
source-key
target-type
target-key
opts)Create a relationship between two entities. PUT /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey} Path params: relationName, sourceType, sourceKey, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion
Create a relationship between two entities.
PUT /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey}
Path params: relationName, sourceType, sourceKey, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion(delete-label-from-space client space-key opts)Remove label from a space. DELETE /wiki/rest/api/space/{spaceKey}/label Path params: spaceKey Query opts: name (required), prefix
Remove label from a space.
DELETE /wiki/rest/api/space/{spaceKey}/label
Path params: spaceKey
Query opts: name (required), prefix(delete-page-tree client id)Delete page tree rooted at the given content id. DELETE /wiki/rest/api/content/{id}/pageTree Path params: id
Delete page tree rooted at the given content id.
DELETE /wiki/rest/api/content/{id}/pageTree
Path params: id(delete-relationship client
relation-name
source-type
source-key
target-type
target-key)(delete-relationship client
relation-name
source-type
source-key
target-type
target-key
opts)Delete a relationship. DELETE /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey} Path params: relationName, sourceType, sourceKey, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion
Delete a relationship.
DELETE /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey}
Path params: relationName, sourceType, sourceKey, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion(export-audit-records client)(export-audit-records client opts)Export audit records. GET /wiki/rest/api/audit/export Query opts: startDate, endDate, searchString, format
Export audit records. GET /wiki/rest/api/audit/export Query opts: startDate, endDate, searchString, format
(find-sources-for-target client
relation-name
target-type
target-key
source-type)(find-sources-for-target client
relation-name
target-type
target-key
source-type
opts)Find source entities related to a target entity. GET /wiki/rest/api/relation/{relationName}/to/{targetType}/{targetKey}/from/{sourceType} Path params: relationName, sourceType, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit
Find source entities related to a target entity.
GET /wiki/rest/api/relation/{relationName}/to/{targetType}/{targetKey}/from/{sourceType}
Path params: relationName, sourceType, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit(find-target-from-source client
relation-name
source-type
source-key
target-type)(find-target-from-source client
relation-name
source-type
source-key
target-type
opts)Find target entities related to a source entity. GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType} Path params: relationName, sourceType, sourceKey, targetType Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit
Find target entities related to a source entity.
GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}
Path params: relationName, sourceType, sourceKey, targetType
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand, start, limit(get-audit-records client)(get-audit-records client opts)Get audit records. GET /wiki/rest/api/audit Query opts: startDate, endDate, searchString, start, limit
Get audit records. GET /wiki/rest/api/audit Query opts: startDate, endDate, searchString, start, limit
(get-audit-records-for-time-period client)(get-audit-records-for-time-period client opts)Get audit records for a time period. GET /wiki/rest/api/audit/since Query opts: number, units, searchString, start, limit
Get audit records for a time period. GET /wiki/rest/api/audit/since Query opts: number, units, searchString, start, limit
(get-blueprint-templates client)(get-blueprint-templates client opts)Get blueprint templates. GET /wiki/rest/api/template/blueprint Query opts: spaceKey, start, limit
Get blueprint templates. GET /wiki/rest/api/template/blueprint Query opts: spaceKey, start, limit
(get-content-template client content-template-id)Get content template by id. GET /wiki/rest/api/template/{contentTemplateId} Path params: contentTemplateId
Get content template by id.
GET /wiki/rest/api/template/{contentTemplateId}
Path params: contentTemplateId(get-content-templates client)(get-content-templates client opts)Get content templates. GET /wiki/rest/api/template/page Query opts: spaceKey, start, limit
Get content templates. GET /wiki/rest/api/template/page Query opts: spaceKey, start, limit
(get-global-theme client)Get global theme. GET /wiki/rest/api/settings/theme/selected
Get global theme. GET /wiki/rest/api/settings/theme/selected
(get-labels-for-space client space-key)(get-labels-for-space client space-key opts)Get Space Labels. GET /wiki/rest/api/space/{spaceKey}/label Path params: spaceKey Query opts: prefix, start, limit
Get Space Labels.
GET /wiki/rest/api/space/{spaceKey}/label
Path params: spaceKey
Query opts: prefix, start, limit(get-look-and-feel-settings client)(get-look-and-feel-settings client opts)Get look and feel settings. GET /wiki/rest/api/settings/lookandfeel Query opts: spaceKey
Get look and feel settings. GET /wiki/rest/api/settings/lookandfeel Query opts: spaceKey
(get-relationship client
relation-name
source-type
source-key
target-type
target-key)(get-relationship client
relation-name
source-type
source-key
target-type
target-key
opts)Find relationship from source to target. GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey} Path params: relationName, sourceType, sourceKey, targetType, targetKey Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand
Find relationship from source to target.
GET /wiki/rest/api/relation/{relationName}/from/{sourceType}/{sourceKey}/to/{targetType}/{targetKey}
Path params: relationName, sourceType, sourceKey, targetType, targetKey
Query opts: sourceStatus, targetStatus, sourceVersion, targetVersion, expand(get-retention-period client)Get retention period for audit records. GET /wiki/rest/api/audit/retention
Get retention period for audit records. GET /wiki/rest/api/audit/retention
(get-space-theme client space-key)Get space theme. GET /wiki/rest/api/space/{spaceKey}/theme Path params: spaceKey
Get space theme.
GET /wiki/rest/api/space/{spaceKey}/theme
Path params: spaceKey(get-system-info client)Get system info. GET /wiki/rest/api/settings/systemInfo
Get system info. GET /wiki/rest/api/settings/systemInfo
(get-task client id)Get a long-running task by id. GET /wiki/rest/api/longtask/{id} Path params: id
Get a long-running task by id.
GET /wiki/rest/api/longtask/{id}
Path params: id(get-tasks client)(get-tasks client opts)Get long-running tasks. GET /wiki/rest/api/longtask Query opts: key, start, limit
Get long-running tasks. GET /wiki/rest/api/longtask Query opts: key, start, limit
(get-theme client theme-key)Get a theme by key. GET /wiki/rest/api/settings/theme/{themeKey} Path params: themeKey
Get a theme by key.
GET /wiki/rest/api/settings/theme/{themeKey}
Path params: themeKey(get-themes client)(get-themes client opts)Get themes. GET /wiki/rest/api/settings/theme Query opts: start, limit
Get themes. GET /wiki/rest/api/settings/theme Query opts: start, limit
(get-viewers client content-id)(get-viewers client content-id opts)Get viewers for a content item. GET /wiki/rest/api/analytics/content/{contentId}/viewers Path params: contentId Query opts: fromDate
Get viewers for a content item.
GET /wiki/rest/api/analytics/content/{contentId}/viewers
Path params: contentId
Query opts: fromDate(get-views client content-id)(get-views client content-id opts)Get views for a content item. GET /wiki/rest/api/analytics/content/{contentId}/views Path params: contentId Query opts: fromDate
Get views for a content item.
GET /wiki/rest/api/analytics/content/{contentId}/views
Path params: contentId
Query opts: fromDate(remove-template client content-template-id)Remove template by id. DELETE /wiki/rest/api/template/{contentTemplateId} Path params: contentTemplateId
Remove template by id.
DELETE /wiki/rest/api/template/{contentTemplateId}
Path params: contentTemplateId(reset-look-and-feel-settings client)(reset-look-and-feel-settings client opts)Reset look and feel settings. DELETE /wiki/rest/api/settings/lookandfeel/custom Query opts: spaceKey
Reset look and feel settings. DELETE /wiki/rest/api/settings/lookandfeel/custom Query opts: spaceKey
(reset-space-theme client space-key)Reset space theme to default. DELETE /wiki/rest/api/space/{spaceKey}/theme Path params: spaceKey
Reset space theme to default.
DELETE /wiki/rest/api/space/{spaceKey}/theme
Path params: spaceKey(set-retention-period client body)(set-retention-period client body opts)Set retention period for audit records. PUT /wiki/rest/api/audit/retention Body: RetentionPeriod
Set retention period for audit records. PUT /wiki/rest/api/audit/retention Body: RetentionPeriod
(set-space-theme client space-key body)(set-space-theme client space-key body opts)Set space theme. PUT /wiki/rest/api/space/{spaceKey}/theme Path params: spaceKey Body: ThemeUpdate
Set space theme.
PUT /wiki/rest/api/space/{spaceKey}/theme
Path params: spaceKey
Body: ThemeUpdate(update-content-template client body)(update-content-template client body opts)Update content template. PUT /wiki/rest/api/template Body: ContentTemplateUpdate
Update content template. PUT /wiki/rest/api/template Body: ContentTemplateUpdate
(update-look-and-feel client body)(update-look-and-feel client body opts)Select look and feel settings. PUT /wiki/rest/api/settings/lookandfeel Body: LookAndFeelSelection
Select look and feel settings. PUT /wiki/rest/api/settings/lookandfeel Body: LookAndFeelSelection
(update-look-and-feel-settings client body)(update-look-and-feel-settings client body opts)Update look and feel settings. POST /wiki/rest/api/settings/lookandfeel/custom Body: LookAndFeel Query opts: spaceKey
Update look and feel settings. POST /wiki/rest/api/settings/lookandfeel/custom Body: LookAndFeel Query opts: spaceKey
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |