Confluence v1 Content API — archive, blueprint, search, macro, permissions, versions, and body conversion.
Confluence v1 Content API — archive, blueprint, search, macro, permissions, versions, and body conversion.
(archive-pages client body)(archive-pages client body opts)Archive pages. POST /wiki/rest/api/content/archive Body: object (no schema-ref; pass a map of page IDs to archive).
Archive pages. POST /wiki/rest/api/content/archive Body: object (no schema-ref; pass a map of page IDs to archive).
(async-convert-content-body-request client to body)(async-convert-content-body-request client to body opts)Asynchronously convert content body. POST /wiki/rest/api/contentbody/convert/async/{to} Path params: to Body: ContentBodyCreate
Asynchronously convert content body.
POST /wiki/rest/api/contentbody/convert/async/{to}
Path params: to
Body: ContentBodyCreate(async-convert-content-body-response client id)Get asynchronously converted content body from the id or the current status of the task. GET /wiki/rest/api/contentbody/convert/async/{id} Path params: id
Get asynchronously converted content body from the id or the current status of the task.
GET /wiki/rest/api/contentbody/convert/async/{id}
Path params: id(bulk-async-convert-content-body-request client body)Create asynchronous content body conversion tasks in bulk. POST /wiki/rest/api/contentbody/convert/async/bulk/tasks Body: BulkContentBodyConversionInput
Create asynchronous content body conversion tasks in bulk. POST /wiki/rest/api/contentbody/convert/async/bulk/tasks Body: BulkContentBodyConversionInput
(bulk-async-convert-content-body-response client opts)Get asynchronous content body conversion task result in bulk. GET /wiki/rest/api/contentbody/convert/async/bulk/tasks Required query param: :ids (array of asyncIds).
Get asynchronous content body conversion task result in bulk. GET /wiki/rest/api/contentbody/convert/async/bulk/tasks Required query param: :ids (array of asyncIds).
(check-content-permission client id body)Check content permissions. POST /wiki/rest/api/content/{id}/permission/check Path params: id Body: ContentPermissionRequest
Check content permissions.
POST /wiki/rest/api/content/{id}/permission/check
Path params: id
Body: ContentPermissionRequest(delete-content-version client id version-number)Delete content version. DELETE /wiki/rest/api/content/{id}/version/{versionNumber} Path params: id, versionNumber
Delete content version.
DELETE /wiki/rest/api/content/{id}/version/{versionNumber}
Path params: id, versionNumber(get-and-async-convert-macro-body-by-macro-id client id version macro-id to)(get-and-async-convert-macro-body-by-macro-id client
id
version
macro-id
to
opts)Get macro body by macro ID and convert representation asynchronously. GET /wiki/rest/api/content/{id}/history/{version}/macro/id/{macroId}/convert/async/{to} Path params: id, version, macroId, to
Get macro body by macro ID and convert representation asynchronously.
GET /wiki/rest/api/content/{id}/history/{version}/macro/id/{macroId}/convert/async/{to}
Path params: id, version, macroId, to(get-and-convert-macro-body-by-macro-id client id version macro-id to)(get-and-convert-macro-body-by-macro-id client id version macro-id to opts)Get macro body by macro ID and convert the representation synchronously. GET /wiki/rest/api/content/{id}/history/{version}/macro/id/{macroId}/convert/{to} Path params: id, version, macroId, to
Get macro body by macro ID and convert the representation synchronously.
GET /wiki/rest/api/content/{id}/history/{version}/macro/id/{macroId}/convert/{to}
Path params: id, version, macroId, to(get-macro-body-by-macro-id client id version macro-id)Get macro body by macro ID. GET /wiki/rest/api/content/{id}/history/{version}/macro/id/{macroId} Path params: id, version, macroId
Get macro body by macro ID.
GET /wiki/rest/api/content/{id}/history/{version}/macro/id/{macroId}
Path params: id, version, macroId(publish-legacy-draft client draft-id body)(publish-legacy-draft client draft-id body opts)Publish legacy draft. POST /wiki/rest/api/content/blueprint/instance/{draftId} Path params: draftId Body: ContentBlueprintDraft
Publish legacy draft.
POST /wiki/rest/api/content/blueprint/instance/{draftId}
Path params: draftId
Body: ContentBlueprintDraft(publish-shared-draft client draft-id body)(publish-shared-draft client draft-id body opts)Publish shared draft. PUT /wiki/rest/api/content/blueprint/instance/{draftId} Path params: draftId Body: ContentBlueprintDraft
Publish shared draft.
PUT /wiki/rest/api/content/blueprint/instance/{draftId}
Path params: draftId
Body: ContentBlueprintDraft(restore-content-version client id body)(restore-content-version client id body opts)Restore content version. POST /wiki/rest/api/content/{id}/version Path params: id Body: VersionRestore
Restore content version.
POST /wiki/rest/api/content/{id}/version
Path params: id
Body: VersionRestore(search-content-by-cql client opts)Search content by CQL. GET /wiki/rest/api/content/search Required query param: :cql (CQL string).
Search content by CQL. GET /wiki/rest/api/content/search Required query param: :cql (CQL string).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |