Confluence v1 content-children / descendants / attachment operations.
All fns delegate to atlassian.confluence.client/request with :api :v1.
Confluence v1 content-children / descendants / attachment operations. All fns delegate to `atlassian.confluence.client/request` with :api :v1.
(copy-page client id body)(copy-page client id body opts)Copy single page — copy a page to a new location. POST /wiki/rest/api/content/{id}/copy Path params: id — the ID of the page to copy. Body: CopyPageRequest {:destination {:type :value} :copyAttachments :copyPermissions :copyProperties :copyLabels :copyCustomContents :pageTitle :body}
Copy single page — copy a page to a new location.
POST /wiki/rest/api/content/{id}/copy
Path params: id — the ID of the page to copy.
Body: CopyPageRequest {:destination {:type :value} :copyAttachments :copyPermissions :copyProperties :copyLabels :copyCustomContents :pageTitle :body}(copy-page-hierarchy client id body)(copy-page-hierarchy client id body opts)Copy page hierarchy — copy a hierarchy of pages from one location to another. POST /wiki/rest/api/content/{id}/pagehierarchy/copy Path params: id — the ID of the root page of the hierarchy to copy. Body: CopyPageHierarchyRequest {:destinationPageId :copyAttachments :copyPermissions :copyProperties :copyLabels :copyCustomContents :copyDescendants :titleOptions}
Copy page hierarchy — copy a hierarchy of pages from one location to another.
POST /wiki/rest/api/content/{id}/pagehierarchy/copy
Path params: id — the ID of the root page of the hierarchy to copy.
Body: CopyPageHierarchyRequest {:destinationPageId :copyAttachments :copyPermissions :copyProperties :copyLabels :copyCustomContents :copyDescendants :titleOptions}(create-attachment client id body)(create-attachment client id body opts)Create attachment — upload a new attachment to a piece of content. POST /wiki/rest/api/content/{id}/child/attachment Path params: id — The ID of the content to add the attachment to. Body: multipart form data (no JSON schema; submit as multipart).
Create attachment — upload a new attachment to a piece of content.
POST /wiki/rest/api/content/{id}/child/attachment
Path params: id — The ID of the content to add the attachment to.
Body: multipart form data (no JSON schema; submit as multipart).(create-or-update-attachments client id body)(create-or-update-attachments client id body opts)Create or update attachment — add or replace attachments on a piece of content. PUT /wiki/rest/api/content/{id}/child/attachment Path params: id — The ID of the content to add the attachment to. Body: multipart form data (no JSON schema; submit as multipart).
Create or update attachment — add or replace attachments on a piece of content.
PUT /wiki/rest/api/content/{id}/child/attachment
Path params: id — The ID of the content to add the attachment to.
Body: multipart form data (no JSON schema; submit as multipart).(download-attatchment client id attachment-id)(download-attatchment client id attachment-id opts)Get URI to download attachment — returns a redirect to the attachment download URL. GET /wiki/rest/api/content/{id}/child/attachment/{attachmentId}/download Path params: id — content ID; attachmentId — attachment to download. Query opts: version, status.
Get URI to download attachment — returns a redirect to the attachment download URL.
GET /wiki/rest/api/content/{id}/child/attachment/{attachmentId}/download
Path params: id — content ID; attachmentId — attachment to download.
Query opts: version, status.(get-content-descendants client id)(get-content-descendants client id opts)Get content descendants — returns a map of descendant types for a piece of content. DEPRECATED. GET /wiki/rest/api/content/{id}/descendant Path params: id — The ID of the content to be queried for its descendants. Query opts: expand.
Get content descendants — returns a map of descendant types for a piece of content. DEPRECATED.
GET /wiki/rest/api/content/{id}/descendant
Path params: id — The ID of the content to be queried for its descendants.
Query opts: expand.(get-descendants-of-type client id type)(get-descendants-of-type client id type opts)Get content descendants by type — returns descendants of a given type for content. DEPRECATED. GET /wiki/rest/api/content/{id}/descendant/{type} Path params: id — content ID; type — the type of descendants to return. Query opts: depth, start, limit.
Get content descendants by type — returns descendants of a given type for content. DEPRECATED.
GET /wiki/rest/api/content/{id}/descendant/{type}
Path params: id — content ID; type — the type of descendants to return.
Query opts: depth, start, limit.(move-page client page-id position target-id)Move a page to a new location relative to a target page. PUT /wiki/rest/api/content/{pageId}/move/{position}/{targetId} Path params: pageId — page to move; position — before|after|append; targetId — target page.
Move a page to a new location relative to a target page.
PUT /wiki/rest/api/content/{pageId}/move/{position}/{targetId}
Path params: pageId — page to move; position — before|after|append; targetId — target page.(update-attachment-data client id attachment-id body)(update-attachment-data client id attachment-id body opts)Update attachment data — replace the binary data of an existing attachment. POST /wiki/rest/api/content/{id}/child/attachment/{attachmentId}/data Path params: id — content ID; attachmentId — attachment to update. Body: multipart form data (no JSON schema; submit as multipart).
Update attachment data — replace the binary data of an existing attachment.
POST /wiki/rest/api/content/{id}/child/attachment/{attachmentId}/data
Path params: id — content ID; attachmentId — attachment to update.
Body: multipart form data (no JSON schema; submit as multipart).(update-attachment-properties client id attachment-id body)(update-attachment-properties client id attachment-id body opts)Update attachment properties — update the non-binary data of an attachment. PUT /wiki/rest/api/content/{id}/child/attachment/{attachmentId} Path params: id — content ID; attachmentId — attachment to update. Body: AttachmentPropertiesUpdateBody {:id :type :version :status :title :metadata :extensions}
Update attachment properties — update the non-binary data of an attachment.
PUT /wiki/rest/api/content/{id}/child/attachment/{attachmentId}
Path params: id — content ID; attachmentId — attachment to update.
Body: AttachmentPropertiesUpdateBody {:id :type :version :status :title :metadata :extensions}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |