Confluence Cloud v2 Content Properties API.
Cursor-paginated list responses include :results and :_links {:next ...};
page with the cursor query param.
Confluence Cloud v2 Content Properties API.
Cursor-paginated list responses include :results and :_links {:next ...};
page with the `cursor` query param.(create-attachment-property client attachment-id body)(create-attachment-property client attachment-id body opts)Create content property for attachment. POST /wiki/api/v2/attachments/{attachment-id}/properties Path params: attachment-id Body: ContentPropertyCreateRequest
Create content property for attachment.
POST /wiki/api/v2/attachments/{attachment-id}/properties
Path params: attachment-id
Body: ContentPropertyCreateRequest(create-blogpost-property client blogpost-id body)(create-blogpost-property client blogpost-id body opts)Create content property for blog post. POST /wiki/api/v2/blogposts/{blogpost-id}/properties Path params: blogpost-id Body: ContentPropertyCreateRequest
Create content property for blog post.
POST /wiki/api/v2/blogposts/{blogpost-id}/properties
Path params: blogpost-id
Body: ContentPropertyCreateRequest(create-comment-property client comment-id body)(create-comment-property client comment-id body opts)Create content property for comment. POST /wiki/api/v2/comments/{comment-id}/properties Path params: comment-id Body: ContentPropertyCreateRequest
Create content property for comment.
POST /wiki/api/v2/comments/{comment-id}/properties
Path params: comment-id
Body: ContentPropertyCreateRequest(create-custom-content-property client custom-content-id body)(create-custom-content-property client custom-content-id body opts)Create content property for custom content. POST /wiki/api/v2/custom-content/{custom-content-id}/properties Path params: custom-content-id Body: ContentPropertyCreateRequest
Create content property for custom content.
POST /wiki/api/v2/custom-content/{custom-content-id}/properties
Path params: custom-content-id
Body: ContentPropertyCreateRequest(create-database-property client id body)(create-database-property client id body opts)Create content property for database. POST /wiki/api/v2/databases/{id}/properties Path params: id Body: ContentPropertyCreateRequest
Create content property for database.
POST /wiki/api/v2/databases/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest(create-folder-property client id body)(create-folder-property client id body opts)Create content property for folder. POST /wiki/api/v2/folders/{id}/properties Path params: id Body: ContentPropertyCreateRequest
Create content property for folder.
POST /wiki/api/v2/folders/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest(create-page-property client page-id body)(create-page-property client page-id body opts)Create content property for page. POST /wiki/api/v2/pages/{page-id}/properties Path params: page-id Body: ContentPropertyCreateRequest
Create content property for page.
POST /wiki/api/v2/pages/{page-id}/properties
Path params: page-id
Body: ContentPropertyCreateRequest(create-smart-link-property client id body)(create-smart-link-property client id body opts)Create content property for Smart Link in the content tree. POST /wiki/api/v2/embeds/{id}/properties Path params: id Body: ContentPropertyCreateRequest
Create content property for Smart Link in the content tree.
POST /wiki/api/v2/embeds/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest(create-whiteboard-property client id body)(create-whiteboard-property client id body opts)Create content property for whiteboard. POST /wiki/api/v2/whiteboards/{id}/properties Path params: id Body: ContentPropertyCreateRequest
Create content property for whiteboard.
POST /wiki/api/v2/whiteboards/{id}/properties
Path params: id
Body: ContentPropertyCreateRequest(delete-attachment-property-by-id client attachment-id property-id)Delete content property for attachment by id. DELETE /wiki/api/v2/attachments/{attachment-id}/properties/{property-id} Path params: attachment-id, property-id
Delete content property for attachment by id.
DELETE /wiki/api/v2/attachments/{attachment-id}/properties/{property-id}
Path params: attachment-id, property-id(delete-blogpost-property-by-id client blogpost-id property-id)Delete content property for blogpost by id. DELETE /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id} Path params: blogpost-id, property-id
Delete content property for blogpost by id.
DELETE /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id}
Path params: blogpost-id, property-id(delete-comment-property-by-id client comment-id property-id)Delete content property for comment by id. DELETE /wiki/api/v2/comments/{comment-id}/properties/{property-id} Path params: comment-id, property-id
Delete content property for comment by id.
DELETE /wiki/api/v2/comments/{comment-id}/properties/{property-id}
Path params: comment-id, property-id(delete-custom-content-property-by-id client custom-content-id property-id)Delete content property for custom content by id. DELETE /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id} Path params: custom-content-id, property-id
Delete content property for custom content by id.
DELETE /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id}
Path params: custom-content-id, property-id(delete-database-property-by-id client database-id property-id)Delete content property for database by id. DELETE /wiki/api/v2/databases/{database-id}/properties/{property-id} Path params: database-id, property-id
Delete content property for database by id.
DELETE /wiki/api/v2/databases/{database-id}/properties/{property-id}
Path params: database-id, property-id(delete-folder-property-by-id client folder-id property-id)Delete content property for folder by id. DELETE /wiki/api/v2/folders/{folder-id}/properties/{property-id} Path params: folder-id, property-id
Delete content property for folder by id.
DELETE /wiki/api/v2/folders/{folder-id}/properties/{property-id}
Path params: folder-id, property-id(delete-page-property-by-id client page-id property-id)Delete content property for page by id. DELETE /wiki/api/v2/pages/{page-id}/properties/{property-id} Path params: page-id, property-id
Delete content property for page by id.
DELETE /wiki/api/v2/pages/{page-id}/properties/{property-id}
Path params: page-id, property-id(delete-smart-link-property-by-id client embed-id property-id)Delete content property for Smart Link in the content tree by id. DELETE /wiki/api/v2/embeds/{embed-id}/properties/{property-id} Path params: embed-id, property-id
Delete content property for Smart Link in the content tree by id.
DELETE /wiki/api/v2/embeds/{embed-id}/properties/{property-id}
Path params: embed-id, property-id(delete-whiteboard-property-by-id client whiteboard-id property-id)Delete content property for whiteboard by id. DELETE /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id} Path params: whiteboard-id, property-id
Delete content property for whiteboard by id.
DELETE /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id}
Path params: whiteboard-id, property-id(get-attachment-content-properties client attachment-id)(get-attachment-content-properties client attachment-id opts)Get content properties for attachment. GET /wiki/api/v2/attachments/{attachment-id}/properties Path params: attachment-id Query opts: key, sort, cursor, limit
Get content properties for attachment.
GET /wiki/api/v2/attachments/{attachment-id}/properties
Path params: attachment-id
Query opts: key, sort, cursor, limit(get-attachment-content-properties-by-id client attachment-id property-id)Get content property for attachment by id. GET /wiki/api/v2/attachments/{attachment-id}/properties/{property-id} Path params: attachment-id, property-id
Get content property for attachment by id.
GET /wiki/api/v2/attachments/{attachment-id}/properties/{property-id}
Path params: attachment-id, property-id(get-blogpost-content-properties client blogpost-id)(get-blogpost-content-properties client blogpost-id opts)Get content properties for blog post. GET /wiki/api/v2/blogposts/{blogpost-id}/properties Path params: blogpost-id Query opts: key, sort, cursor, limit
Get content properties for blog post.
GET /wiki/api/v2/blogposts/{blogpost-id}/properties
Path params: blogpost-id
Query opts: key, sort, cursor, limit(get-blogpost-content-properties-by-id client blogpost-id property-id)Get content property for blog post by id. GET /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id} Path params: blogpost-id, property-id
Get content property for blog post by id.
GET /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id}
Path params: blogpost-id, property-id(get-comment-content-properties client comment-id)(get-comment-content-properties client comment-id opts)Get content properties for comment. GET /wiki/api/v2/comments/{comment-id}/properties Path params: comment-id Query opts: key, sort, cursor, limit
Get content properties for comment.
GET /wiki/api/v2/comments/{comment-id}/properties
Path params: comment-id
Query opts: key, sort, cursor, limit(get-comment-content-properties-by-id client comment-id property-id)Get content property for comment by id. GET /wiki/api/v2/comments/{comment-id}/properties/{property-id} Path params: comment-id, property-id
Get content property for comment by id.
GET /wiki/api/v2/comments/{comment-id}/properties/{property-id}
Path params: comment-id, property-id(get-custom-content-content-properties client custom-content-id)(get-custom-content-content-properties client custom-content-id opts)Get content properties for custom content. GET /wiki/api/v2/custom-content/{custom-content-id}/properties Path params: custom-content-id Query opts: key, sort, cursor, limit
Get content properties for custom content.
GET /wiki/api/v2/custom-content/{custom-content-id}/properties
Path params: custom-content-id
Query opts: key, sort, cursor, limit(get-custom-content-content-properties-by-id client
custom-content-id
property-id)Get content property for custom content by id. GET /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id} Path params: custom-content-id, property-id
Get content property for custom content by id.
GET /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id}
Path params: custom-content-id, property-id(get-database-content-properties client id)(get-database-content-properties client id opts)Get content properties for database. GET /wiki/api/v2/databases/{id}/properties Path params: id Query opts: key, sort, cursor, limit
Get content properties for database.
GET /wiki/api/v2/databases/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit(get-database-content-properties-by-id client database-id property-id)Get content property for database by id. GET /wiki/api/v2/databases/{database-id}/properties/{property-id} Path params: database-id, property-id
Get content property for database by id.
GET /wiki/api/v2/databases/{database-id}/properties/{property-id}
Path params: database-id, property-id(get-folder-content-properties client id)(get-folder-content-properties client id opts)Get content properties for folder. GET /wiki/api/v2/folders/{id}/properties Path params: id Query opts: key, sort, cursor, limit
Get content properties for folder.
GET /wiki/api/v2/folders/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit(get-folder-content-properties-by-id client folder-id property-id)Get content property for folder by id. GET /wiki/api/v2/folders/{folder-id}/properties/{property-id} Path params: folder-id, property-id
Get content property for folder by id.
GET /wiki/api/v2/folders/{folder-id}/properties/{property-id}
Path params: folder-id, property-id(get-page-content-properties client page-id)(get-page-content-properties client page-id opts)Get content properties for page. GET /wiki/api/v2/pages/{page-id}/properties Path params: page-id Query opts: key, sort, cursor, limit
Get content properties for page.
GET /wiki/api/v2/pages/{page-id}/properties
Path params: page-id
Query opts: key, sort, cursor, limit(get-page-content-properties-by-id client page-id property-id)Get content property for page by id. GET /wiki/api/v2/pages/{page-id}/properties/{property-id} Path params: page-id, property-id
Get content property for page by id.
GET /wiki/api/v2/pages/{page-id}/properties/{property-id}
Path params: page-id, property-id(get-smart-link-content-properties client id)(get-smart-link-content-properties client id opts)Get content properties for Smart Link in the content tree. GET /wiki/api/v2/embeds/{id}/properties Path params: id Query opts: key, sort, cursor, limit
Get content properties for Smart Link in the content tree.
GET /wiki/api/v2/embeds/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit(get-smart-link-content-properties-by-id client embed-id property-id)Get content property for Smart Link in the content tree by id. GET /wiki/api/v2/embeds/{embed-id}/properties/{property-id} Path params: embed-id, property-id
Get content property for Smart Link in the content tree by id.
GET /wiki/api/v2/embeds/{embed-id}/properties/{property-id}
Path params: embed-id, property-id(get-whiteboard-content-properties client id)(get-whiteboard-content-properties client id opts)Get content properties for whiteboard. GET /wiki/api/v2/whiteboards/{id}/properties Path params: id Query opts: key, sort, cursor, limit
Get content properties for whiteboard.
GET /wiki/api/v2/whiteboards/{id}/properties
Path params: id
Query opts: key, sort, cursor, limit(get-whiteboard-content-properties-by-id client whiteboard-id property-id)Get content property for whiteboard by id. GET /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id} Path params: whiteboard-id, property-id
Get content property for whiteboard by id.
GET /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id}
Path params: whiteboard-id, property-id(update-attachment-property-by-id client attachment-id property-id body)(update-attachment-property-by-id client attachment-id property-id body opts)Update content property for attachment by id. PUT /wiki/api/v2/attachments/{attachment-id}/properties/{property-id} Path params: attachment-id, property-id Body: ContentPropertyUpdateRequest
Update content property for attachment by id.
PUT /wiki/api/v2/attachments/{attachment-id}/properties/{property-id}
Path params: attachment-id, property-id
Body: ContentPropertyUpdateRequest(update-blogpost-property-by-id client blogpost-id property-id body)(update-blogpost-property-by-id client blogpost-id property-id body opts)Update content property for blog post by id. PUT /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id} Path params: blogpost-id, property-id Body: ContentPropertyUpdateRequest
Update content property for blog post by id.
PUT /wiki/api/v2/blogposts/{blogpost-id}/properties/{property-id}
Path params: blogpost-id, property-id
Body: ContentPropertyUpdateRequest(update-comment-property-by-id client comment-id property-id body)(update-comment-property-by-id client comment-id property-id body opts)Update content property for comment by id. PUT /wiki/api/v2/comments/{comment-id}/properties/{property-id} Path params: comment-id, property-id Body: ContentPropertyUpdateRequest
Update content property for comment by id.
PUT /wiki/api/v2/comments/{comment-id}/properties/{property-id}
Path params: comment-id, property-id
Body: ContentPropertyUpdateRequest(update-custom-content-property-by-id client custom-content-id property-id body)(update-custom-content-property-by-id client
custom-content-id
property-id
body
opts)Update content property for custom content by id. PUT /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id} Path params: custom-content-id, property-id Body: ContentPropertyUpdateRequest
Update content property for custom content by id.
PUT /wiki/api/v2/custom-content/{custom-content-id}/properties/{property-id}
Path params: custom-content-id, property-id
Body: ContentPropertyUpdateRequest(update-database-property-by-id client database-id property-id body)(update-database-property-by-id client database-id property-id body opts)Update content property for database by id. PUT /wiki/api/v2/databases/{database-id}/properties/{property-id} Path params: database-id, property-id Body: ContentPropertyUpdateRequest
Update content property for database by id.
PUT /wiki/api/v2/databases/{database-id}/properties/{property-id}
Path params: database-id, property-id
Body: ContentPropertyUpdateRequest(update-folder-property-by-id client folder-id property-id body)(update-folder-property-by-id client folder-id property-id body opts)Update content property for folder by id. PUT /wiki/api/v2/folders/{folder-id}/properties/{property-id} Path params: folder-id, property-id Body: ContentPropertyUpdateRequest
Update content property for folder by id.
PUT /wiki/api/v2/folders/{folder-id}/properties/{property-id}
Path params: folder-id, property-id
Body: ContentPropertyUpdateRequest(update-page-property-by-id client page-id property-id body)(update-page-property-by-id client page-id property-id body opts)Update content property for page by id. PUT /wiki/api/v2/pages/{page-id}/properties/{property-id} Path params: page-id, property-id Body: ContentPropertyUpdateRequest
Update content property for page by id.
PUT /wiki/api/v2/pages/{page-id}/properties/{property-id}
Path params: page-id, property-id
Body: ContentPropertyUpdateRequest(update-smart-link-property-by-id client embed-id property-id body)(update-smart-link-property-by-id client embed-id property-id body opts)Update content property for Smart Link in the content tree by id. PUT /wiki/api/v2/embeds/{embed-id}/properties/{property-id} Path params: embed-id, property-id Body: ContentPropertyUpdateRequest
Update content property for Smart Link in the content tree by id.
PUT /wiki/api/v2/embeds/{embed-id}/properties/{property-id}
Path params: embed-id, property-id
Body: ContentPropertyUpdateRequest(update-whiteboard-property-by-id client whiteboard-id property-id body)(update-whiteboard-property-by-id client whiteboard-id property-id body opts)Update content property for whiteboard by id. PUT /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id} Path params: whiteboard-id, property-id Body: ContentPropertyUpdateRequest
Update content property for whiteboard by id.
PUT /wiki/api/v2/whiteboards/{whiteboard-id}/properties/{property-id}
Path params: whiteboard-id, property-id
Body: ContentPropertyUpdateRequestcljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |