Miscellaneous Confluence v2 endpoints: admin key, likes, operations, redactions, tasks, user access, and bulk user lookup.
Miscellaneous Confluence v2 endpoints: admin key, likes, operations, redactions, tasks, user access, and bulk user lookup.
(check-access-by-email client)(check-access-by-email client body)(check-access-by-email client body opts)Check site access for a list of emails. POST /wiki/api/v2/user/access/check-access-by-email
Check site access for a list of emails. POST /wiki/api/v2/user/access/check-access-by-email
(convert-content-ids-to-content-types client)(convert-content-ids-to-content-types client body)(convert-content-ids-to-content-types client body opts)Convert content ids to content types. POST /wiki/api/v2/content/convert-ids-to-types
Convert content ids to content types. POST /wiki/api/v2/content/convert-ids-to-types
(create-bulk-user-lookup client)(create-bulk-user-lookup client body)(create-bulk-user-lookup client body opts)Create bulk user lookup using ids. POST /wiki/api/v2/users-bulk
Create bulk user lookup using ids. POST /wiki/api/v2/users-bulk
(disable-admin-key client)Disable Admin Key. DELETE /wiki/api/v2/admin-key
Disable Admin Key. DELETE /wiki/api/v2/admin-key
(enable-admin-key client)(enable-admin-key client body)(enable-admin-key client body opts)Enable Admin Key. POST /wiki/api/v2/admin-key
Enable Admin Key. POST /wiki/api/v2/admin-key
(get-admin-key client)Get Admin Key. GET /wiki/api/v2/admin-key
Get Admin Key. GET /wiki/api/v2/admin-key
(get-attachment-operations client id)Get permitted operations for attachment. GET /wiki/api/v2/attachments/{id}/operations Path param: id — The ID of the attachment.
Get permitted operations for attachment.
GET /wiki/api/v2/attachments/{id}/operations
Path param: id — The ID of the attachment.(get-blog-post-like-count client id)Get like count for blog post. GET /wiki/api/v2/blogposts/{id}/likes/count Path param: id — The ID of the blog post.
Get like count for blog post.
GET /wiki/api/v2/blogposts/{id}/likes/count
Path param: id — The ID of the blog post.(get-blog-post-like-users client id)(get-blog-post-like-users client id opts)Get account IDs of likes for blog post. GET /wiki/api/v2/blogposts/{id}/likes/users Path param: id — The ID of the blog post. opts: cursor, limit
Get account IDs of likes for blog post.
GET /wiki/api/v2/blogposts/{id}/likes/users
Path param: id — The ID of the blog post.
opts: cursor, limit(get-blog-post-operations client id)Get permitted operations for blog post. GET /wiki/api/v2/blogposts/{id}/operations Path param: id — The ID of the blog post.
Get permitted operations for blog post.
GET /wiki/api/v2/blogposts/{id}/operations
Path param: id — The ID of the blog post.(get-custom-content-operations client id)Get permitted operations for custom content. GET /wiki/api/v2/custom-content/{id}/operations Path param: id — The ID of the custom content.
Get permitted operations for custom content.
GET /wiki/api/v2/custom-content/{id}/operations
Path param: id — The ID of the custom content.(get-database-operations client id)Get permitted operations for a database. GET /wiki/api/v2/databases/{id}/operations Path param: id — The ID of the database.
Get permitted operations for a database.
GET /wiki/api/v2/databases/{id}/operations
Path param: id — The ID of the database.(get-folder-operations client id)Get permitted operations for a folder. GET /wiki/api/v2/folders/{id}/operations Path param: id — The ID of the folder.
Get permitted operations for a folder.
GET /wiki/api/v2/folders/{id}/operations
Path param: id — The ID of the folder.(get-footer-comment-operations client id)Get permitted operations for footer comment. GET /wiki/api/v2/footer-comments/{id}/operations Path param: id — The ID of the footer comment.
Get permitted operations for footer comment.
GET /wiki/api/v2/footer-comments/{id}/operations
Path param: id — The ID of the footer comment.(get-footer-like-count client id)Get like count for footer comment. GET /wiki/api/v2/footer-comments/{id}/likes/count Path param: id — The ID of the footer comment.
Get like count for footer comment.
GET /wiki/api/v2/footer-comments/{id}/likes/count
Path param: id — The ID of the footer comment.(get-footer-like-users client id)(get-footer-like-users client id opts)Get account IDs of likes for footer comment. GET /wiki/api/v2/footer-comments/{id}/likes/users Path param: id — The ID of the footer comment. opts: cursor, limit
Get account IDs of likes for footer comment.
GET /wiki/api/v2/footer-comments/{id}/likes/users
Path param: id — The ID of the footer comment.
opts: cursor, limit(get-inline-comment-operations client id)Get permitted operations for inline comment. GET /wiki/api/v2/inline-comments/{id}/operations Path param: id — The ID of the inline comment.
Get permitted operations for inline comment.
GET /wiki/api/v2/inline-comments/{id}/operations
Path param: id — The ID of the inline comment.(get-inline-like-count client id)Get like count for inline comment. GET /wiki/api/v2/inline-comments/{id}/likes/count Path param: id — The ID of the inline comment.
Get like count for inline comment.
GET /wiki/api/v2/inline-comments/{id}/likes/count
Path param: id — The ID of the inline comment.(get-inline-like-users client id)(get-inline-like-users client id opts)Get account IDs of likes for inline comment. GET /wiki/api/v2/inline-comments/{id}/likes/users Path param: id — The ID of the inline comment. opts: cursor, limit
Get account IDs of likes for inline comment.
GET /wiki/api/v2/inline-comments/{id}/likes/users
Path param: id — The ID of the inline comment.
opts: cursor, limit(get-page-like-count client id)Get like count for page. GET /wiki/api/v2/pages/{id}/likes/count Path param: id — The ID of the page.
Get like count for page.
GET /wiki/api/v2/pages/{id}/likes/count
Path param: id — The ID of the page.(get-page-like-users client id)(get-page-like-users client id opts)Get account IDs of likes for page. GET /wiki/api/v2/pages/{id}/likes/users Path param: id — The ID of the page. opts: cursor, limit
Get account IDs of likes for page.
GET /wiki/api/v2/pages/{id}/likes/users
Path param: id — The ID of the page.
opts: cursor, limit(get-page-operations client id)Get permitted operations for page. GET /wiki/api/v2/pages/{id}/operations Path param: id — The ID of the page.
Get permitted operations for page.
GET /wiki/api/v2/pages/{id}/operations
Path param: id — The ID of the page.(get-smart-link-operations client id)Get permitted operations for a Smart Link in the content tree. GET /wiki/api/v2/embeds/{id}/operations Path param: id — The ID of the Smart Link in the content tree.
Get permitted operations for a Smart Link in the content tree.
GET /wiki/api/v2/embeds/{id}/operations
Path param: id — The ID of the Smart Link in the content tree.(get-space-operations client id)Get permitted operations for space. GET /wiki/api/v2/spaces/{id}/operations Path param: id — The ID of the space.
Get permitted operations for space.
GET /wiki/api/v2/spaces/{id}/operations
Path param: id — The ID of the space.(get-task-by-id client id)(get-task-by-id client id opts)Get task by id. GET /wiki/api/v2/tasks/{id} Path param: id — The ID of the task. opts: body-format
Get task by id.
GET /wiki/api/v2/tasks/{id}
Path param: id — The ID of the task.
opts: body-format(get-tasks client)(get-tasks client opts)Get tasks. GET /wiki/api/v2/tasks opts: body-format, include-blank-tasks, status, task-id, space-id, page-id, blogpost-id, created-by, assigned-to, completed-by, created-at-from, created-at-to, due-at-from, due-at-to, completed-at-from, completed-at-to, cursor, limit
Get tasks.
GET /wiki/api/v2/tasks
opts: body-format, include-blank-tasks, status, task-id, space-id,
page-id, blogpost-id, created-by, assigned-to, completed-by,
created-at-from, created-at-to, due-at-from, due-at-to,
completed-at-from, completed-at-to, cursor, limit(get-whiteboard-operations client id)Get permitted operations for a whiteboard. GET /wiki/api/v2/whiteboards/{id}/operations Path param: id — The ID of the whiteboard.
Get permitted operations for a whiteboard.
GET /wiki/api/v2/whiteboards/{id}/operations
Path param: id — The ID of the whiteboard.(invite-by-email client)(invite-by-email client body)(invite-by-email client body opts)Invite a list of emails to the site. POST /wiki/api/v2/user/access/invite-by-email
Invite a list of emails to the site. POST /wiki/api/v2/user/access/invite-by-email
(post-redact-blog client id)(post-redact-blog client id body)(post-redact-blog client id body opts)Redact Content in a Confluence Blog Post. POST /wiki/api/v2/blogposts/{id}/redact Path param: id — The ID of the blog post to redact content from.
Redact Content in a Confluence Blog Post.
POST /wiki/api/v2/blogposts/{id}/redact
Path param: id — The ID of the blog post to redact content from.(post-redact-page client id)(post-redact-page client id body)(post-redact-page client id body opts)Redact Content in a Confluence Page. POST /wiki/api/v2/pages/{id}/redact Path param: id — The ID of the page to redact content from.
Redact Content in a Confluence Page.
POST /wiki/api/v2/pages/{id}/redact
Path param: id — The ID of the page to redact content from.(update-task client id body)(update-task client id body opts)Update task. PUT /wiki/api/v2/tasks/{id} Path param: id — The ID of the task to be updated. opts: body-format
Update task.
PUT /wiki/api/v2/tasks/{id}
Path param: id — The ID of the task to be updated.
opts: body-formatcljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |