Jira field configuration and field scheme endpoints.
Covers two API surface areas:
All issue-field-configuration ops are marked DEPRECATED by Atlassian; they still work and are included in full.
Jira field configuration and field scheme endpoints.
Covers two API surface areas:
- Field schemes (/rest/api/3/config/fieldschemes/*)
- Issue field configs (/rest/api/3/fieldconfiguration* and
/rest/api/3/fieldconfigurationscheme*)
All issue-field-configuration ops are marked DEPRECATED by Atlassian; they
still work and are included in full.(assign-field-configuration-scheme-to-project client body)(assign-field-configuration-scheme-to-project client body opts)DEPRECATED. Assign field configuration scheme to project. PUT /rest/api/3/fieldconfigurationscheme/project Body: FieldConfigurationSchemeProjectAssociation
DEPRECATED. Assign field configuration scheme to project. PUT /rest/api/3/fieldconfigurationscheme/project Body: FieldConfigurationSchemeProjectAssociation
(associate-projects-to-field-association-schemes client body)(associate-projects-to-field-association-schemes client body opts)Associate projects to field schemes. PUT /rest/api/3/config/fieldschemes/projects Body: object mapping project IDs to field association scheme IDs.
Associate projects to field schemes. PUT /rest/api/3/config/fieldschemes/projects Body: object mapping project IDs to field association scheme IDs.
(clone-field-association-scheme client id body)(clone-field-association-scheme client id body opts)Clone field scheme — create a new scheme from an existing one. POST /rest/api/3/config/fieldschemes/{id}/clone Path params: id - integer, the ID of the source field association scheme to clone from. Body: CreateFieldAssociationSchemeRequest
Clone field scheme — create a new scheme from an existing one.
POST /rest/api/3/config/fieldschemes/{id}/clone
Path params:
id - integer, the ID of the source field association scheme to clone from.
Body: CreateFieldAssociationSchemeRequest(create-field-association-scheme client body)(create-field-association-scheme client body opts)Create field scheme. POST /rest/api/3/config/fieldschemes Body: CreateFieldAssociationSchemeRequest
Create field scheme. POST /rest/api/3/config/fieldschemes Body: CreateFieldAssociationSchemeRequest
(create-field-configuration client body)(create-field-configuration client body opts)DEPRECATED. Create field configuration. POST /rest/api/3/fieldconfiguration Body: FieldConfigurationDetails
DEPRECATED. Create field configuration. POST /rest/api/3/fieldconfiguration Body: FieldConfigurationDetails
(create-field-configuration-scheme client body)(create-field-configuration-scheme client body opts)DEPRECATED. Create field configuration scheme. POST /rest/api/3/fieldconfigurationscheme Body: UpdateFieldConfigurationSchemeDetails
DEPRECATED. Create field configuration scheme. POST /rest/api/3/fieldconfigurationscheme Body: UpdateFieldConfigurationSchemeDetails
(delete-field-association-scheme client id)Delete a field scheme by ID. DELETE /rest/api/3/config/fieldschemes/{id} Path params: id - integer, the ID of the field association scheme to delete.
Delete a field scheme by ID.
DELETE /rest/api/3/config/fieldschemes/{id}
Path params:
id - integer, the ID of the field association scheme to delete.(delete-field-configuration client id)DEPRECATED. Delete field configuration by ID. DELETE /rest/api/3/fieldconfiguration/{id} Path params: id - integer, the ID of the field configuration.
DEPRECATED. Delete field configuration by ID.
DELETE /rest/api/3/fieldconfiguration/{id}
Path params:
id - integer, the ID of the field configuration.(delete-field-configuration-scheme client id)DEPRECATED. Delete field configuration scheme by ID. DELETE /rest/api/3/fieldconfigurationscheme/{id} Path params: id - integer, the ID of the field configuration scheme.
DEPRECATED. Delete field configuration scheme by ID.
DELETE /rest/api/3/fieldconfigurationscheme/{id}
Path params:
id - integer, the ID of the field configuration scheme.(get-all-field-configuration-schemes client)(get-all-field-configuration-schemes client opts)DEPRECATED. Get all field configuration schemes — paginated list. GET /rest/api/3/fieldconfigurationscheme opts (all optional): :id - array of scheme IDs to filter by :startAt - page offset (default 0) :maxResults - max items per page
DEPRECATED. Get all field configuration schemes — paginated list. GET /rest/api/3/fieldconfigurationscheme opts (all optional): :id - array of scheme IDs to filter by :startAt - page offset (default 0) :maxResults - max items per page
(get-all-field-configurations client)(get-all-field-configurations client opts)DEPRECATED. Get all field configurations — paginated list. GET /rest/api/3/fieldconfiguration opts (all optional): :id - array of field configuration IDs to filter by :isDefault - if true, return only default configurations :query - text filter against name/description :startAt - page offset (default 0) :maxResults - max items per page
DEPRECATED. Get all field configurations — paginated list. GET /rest/api/3/fieldconfiguration opts (all optional): :id - array of field configuration IDs to filter by :isDefault - if true, return only default configurations :query - text filter against name/description :startAt - page offset (default 0) :maxResults - max items per page
(get-field-association-scheme-by-id client id)Get field scheme by ID. GET /rest/api/3/config/fieldschemes/{id} Path params: id - integer, the scheme ID to fetch.
Get field scheme by ID.
GET /rest/api/3/config/fieldschemes/{id}
Path params:
id - integer, the scheme ID to fetch.(get-field-association-scheme-item-parameters client id field-id)Get field parameters for a specific field in a scheme. GET /rest/api/3/config/fieldschemes/{id}/fields/{fieldId}/parameters Path params: id - integer, the field association scheme ID. field-id - string, the ID of the field.
Get field parameters for a specific field in a scheme.
GET /rest/api/3/config/fieldschemes/{id}/fields/{fieldId}/parameters
Path params:
id - integer, the field association scheme ID.
field-id - string, the ID of the field.(get-field-association-schemes client)(get-field-association-schemes client opts)Get field schemes — paginated list of all field association schemes. GET /rest/api/3/config/fieldschemes opts (all query params, all optional): :projectId - array of project IDs to filter by :query - text filter for scheme name/description (case-insensitive) :startAt - zero-based page offset (default 0) :maxResults - max items per page (default 50, max 100)
Get field schemes — paginated list of all field association schemes. GET /rest/api/3/config/fieldschemes opts (all query params, all optional): :projectId - array of project IDs to filter by :query - text filter for scheme name/description (case-insensitive) :startAt - zero-based page offset (default 0) :maxResults - max items per page (default 50, max 100)
(get-field-configuration-items client id)(get-field-configuration-items client id opts)DEPRECATED. Get field configuration items — paginated list of fields in a configuration. GET /rest/api/3/fieldconfiguration/{id}/fields Path params: id - integer, the ID of the field configuration. opts (all optional): :startAt - page offset (default 0) :maxResults - max items per page
DEPRECATED. Get field configuration items — paginated list of fields in a configuration.
GET /rest/api/3/fieldconfiguration/{id}/fields
Path params:
id - integer, the ID of the field configuration.
opts (all optional):
:startAt - page offset (default 0)
:maxResults - max items per page(get-field-configuration-scheme-mappings client)(get-field-configuration-scheme-mappings client opts)DEPRECATED. Get field configuration issue type items — mappings for schemes. GET /rest/api/3/fieldconfigurationscheme/mapping opts (all optional): :fieldConfigurationSchemeId - array of scheme IDs to filter by :startAt - page offset (default 0) :maxResults - max items per page
DEPRECATED. Get field configuration issue type items — mappings for schemes. GET /rest/api/3/fieldconfigurationscheme/mapping opts (all optional): :fieldConfigurationSchemeId - array of scheme IDs to filter by :startAt - page offset (default 0) :maxResults - max items per page
(get-field-configuration-scheme-project-mapping client opts)DEPRECATED. Get field configuration schemes for projects. GET /rest/api/3/fieldconfigurationscheme/project opts (query params): :projectId - REQUIRED array of project IDs :startAt - page offset (default 0) :maxResults - max items per page
DEPRECATED. Get field configuration schemes for projects. GET /rest/api/3/fieldconfigurationscheme/project opts (query params): :projectId - REQUIRED array of project IDs :startAt - page offset (default 0) :maxResults - max items per page
(get-projects-with-field-schemes client opts)Get projects with field schemes — paginated list filtered by project IDs. GET /rest/api/3/config/fieldschemes/projects Path params: none opts (query params): :projectId - REQUIRED array of project IDs to filter by :startAt - zero-based page offset (default 0) :maxResults - max items per page (max 100)
Get projects with field schemes — paginated list filtered by project IDs. GET /rest/api/3/config/fieldschemes/projects Path params: none opts (query params): :projectId - REQUIRED array of project IDs to filter by :startAt - zero-based page offset (default 0) :maxResults - max items per page (max 100)
(remove-field-association-scheme-item-parameters client body)(remove-field-association-scheme-item-parameters client body opts)Remove field parameters. DELETE /rest/api/3/config/fieldschemes/fields/parameters Body: object identifying the scheme item parameters to remove.
Remove field parameters. DELETE /rest/api/3/config/fieldschemes/fields/parameters Body: object identifying the scheme item parameters to remove.
(remove-fields-associated-with-schemes client body)(remove-fields-associated-with-schemes client body opts)Remove fields associated with field schemes. DELETE /rest/api/3/config/fieldschemes/fields Body: object specifying the fields and schemes to disassociate.
Remove fields associated with field schemes. DELETE /rest/api/3/config/fieldschemes/fields Body: object specifying the fields and schemes to disassociate.
(remove-issue-types-from-global-field-configuration-scheme client id body)(remove-issue-types-from-global-field-configuration-scheme client id body opts)DEPRECATED. Remove issue types from field configuration scheme. POST /rest/api/3/fieldconfigurationscheme/{id}/mapping/delete Path params: id - integer, the ID of the field configuration scheme. Body: IssueTypeIdsToRemove
DEPRECATED. Remove issue types from field configuration scheme.
POST /rest/api/3/fieldconfigurationscheme/{id}/mapping/delete
Path params:
id - integer, the ID of the field configuration scheme.
Body: IssueTypeIdsToRemove(search-field-association-scheme-fields client id)(search-field-association-scheme-fields client id opts)Search field scheme fields — paginated list of fields in a scheme. GET /rest/api/3/config/fieldschemes/{id}/fields Path params: id - integer, the scheme ID to search for child fields. opts (all optional): :fieldId - array of field IDs to filter by :startAt - zero-based page offset (default 0) :maxResults - max items per page (max 100)
Search field scheme fields — paginated list of fields in a scheme.
GET /rest/api/3/config/fieldschemes/{id}/fields
Path params:
id - integer, the scheme ID to search for child fields.
opts (all optional):
:fieldId - array of field IDs to filter by
:startAt - zero-based page offset (default 0)
:maxResults - max items per page (max 100)(search-field-association-scheme-projects client id)(search-field-association-scheme-projects client id opts)Search field scheme projects — paginated list of projects in a scheme. GET /rest/api/3/config/fieldschemes/{id}/projects Path params: id - integer, the scheme ID to search for associated projects. opts (all optional): :projectId - array of project IDs to filter by :startAt - zero-based page offset (default 0) :maxResults - max items per page (max 100)
Search field scheme projects — paginated list of projects in a scheme.
GET /rest/api/3/config/fieldschemes/{id}/projects
Path params:
id - integer, the scheme ID to search for associated projects.
opts (all optional):
:projectId - array of project IDs to filter by
:startAt - zero-based page offset (default 0)
:maxResults - max items per page (max 100)(set-field-configuration-scheme-mapping client id body)(set-field-configuration-scheme-mapping client id body opts)DEPRECATED. Assign issue types to field configurations within a scheme. PUT /rest/api/3/fieldconfigurationscheme/{id}/mapping Path params: id - integer, the ID of the field configuration scheme. Body: AssociateFieldConfigurationsWithIssueTypesRequest
DEPRECATED. Assign issue types to field configurations within a scheme.
PUT /rest/api/3/fieldconfigurationscheme/{id}/mapping
Path params:
id - integer, the ID of the field configuration scheme.
Body: AssociateFieldConfigurationsWithIssueTypesRequest(update-field-association-scheme client id body)(update-field-association-scheme client id body opts)Update field scheme. PUT /rest/api/3/config/fieldschemes/{id} Path params: id - integer, the scheme ID to update. Body: UpdateFieldAssociationSchemeRequest
Update field scheme.
PUT /rest/api/3/config/fieldschemes/{id}
Path params:
id - integer, the scheme ID to update.
Body: UpdateFieldAssociationSchemeRequest(update-field-association-scheme-item-parameters client body)(update-field-association-scheme-item-parameters client body opts)Update field parameters. PUT /rest/api/3/config/fieldschemes/fields/parameters Body: object with updated field parameter values for scheme items.
Update field parameters. PUT /rest/api/3/config/fieldschemes/fields/parameters Body: object with updated field parameter values for scheme items.
(update-field-configuration client id body)(update-field-configuration client id body opts)DEPRECATED. Update field configuration. PUT /rest/api/3/fieldconfiguration/{id} Path params: id - integer, the ID of the field configuration. Body: FieldConfigurationDetails
DEPRECATED. Update field configuration.
PUT /rest/api/3/fieldconfiguration/{id}
Path params:
id - integer, the ID of the field configuration.
Body: FieldConfigurationDetails(update-field-configuration-items client id body)(update-field-configuration-items client id body opts)DEPRECATED. Update field configuration items. PUT /rest/api/3/fieldconfiguration/{id}/fields Path params: id - integer, the ID of the field configuration. Body: FieldConfigurationItemsDetails
DEPRECATED. Update field configuration items.
PUT /rest/api/3/fieldconfiguration/{id}/fields
Path params:
id - integer, the ID of the field configuration.
Body: FieldConfigurationItemsDetails(update-field-configuration-scheme client id body)(update-field-configuration-scheme client id body opts)DEPRECATED. Update field configuration scheme. PUT /rest/api/3/fieldconfigurationscheme/{id} Path params: id - integer, the ID of the field configuration scheme. Body: UpdateFieldConfigurationSchemeDetails
DEPRECATED. Update field configuration scheme.
PUT /rest/api/3/fieldconfigurationscheme/{id}
Path params:
id - integer, the ID of the field configuration scheme.
Body: UpdateFieldConfigurationSchemeDetails(update-fields-associated-with-schemes client body)(update-fields-associated-with-schemes client body opts)Update fields associated with field schemes. PUT /rest/api/3/config/fieldschemes/fields Body: object specifying the updated field-scheme associations.
Update fields associated with field schemes. PUT /rest/api/3/config/fieldschemes/fields Body: object specifying the updated field-scheme associations.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |