atlassian.jira.issue-properties

Jira Cloud Issue Properties and Issue Type Properties endpoints.

Covers both issue-level and issue-type-level entity property CRUD, plus bulk set/delete operations. All fns delegate to atlassian.jira.client/request.

Jira Cloud Issue Properties and Issue Type Properties endpoints.

Covers both issue-level and issue-type-level entity property CRUD, plus bulk
set/delete operations. All fns delegate to `atlassian.jira.client/request`.
raw docstring

bulk-delete-issue-propertyclj

(bulk-delete-issue-property client property-key body)

Bulk delete issue property. DELETE /rest/api/3/issue/properties/{propertyKey}

Path params: propertyKey — the key of the property to delete.

Body: IssueFilterForBulkPropertyDelete {:entityIds [<long> ...] ; issue IDs to target (optional) :currentValue <any>} ; only delete where the property has this value (optional)

Bulk delete issue property.
DELETE /rest/api/3/issue/properties/{propertyKey}

Path params: propertyKey — the key of the property to delete.

Body: IssueFilterForBulkPropertyDelete
  {:entityIds    [<long> ...]   ; issue IDs to target (optional)
   :currentValue <any>}         ; only delete where the property has this value (optional)
sourceraw docstring

bulk-set-issue-properties-by-issueclj

(bulk-set-issue-properties-by-issue client body)

Bulk set issue properties by issue. POST /rest/api/3/issue/properties/multi

Sets properties on multiple issues; each issue can receive different values.

Body: MultiIssueEntityProperties {:issues [{:issueID <long> :properties {"key" <value>}} ...]}

Bulk set issue properties by issue.
POST /rest/api/3/issue/properties/multi

Sets properties on multiple issues; each issue can receive different values.

Body: MultiIssueEntityProperties
  {:issues [{:issueID <long> :properties {"key" <value>}} ...]}
sourceraw docstring

bulk-set-issue-propertyclj

(bulk-set-issue-property client property-key body)

Bulk set issue property. PUT /rest/api/3/issue/properties/{propertyKey}

Path params: propertyKey — the key of the property (max 255 chars).

Body: BulkIssuePropertyUpdateRequest {:value <any> ; the new property value (max 32 768 chars JSON) :expression "..." ; EXPERIMENTAL — Jira expression for computed value :filter {...}} ; IssueFilterForBulkPropertySet

Bulk set issue property.
PUT /rest/api/3/issue/properties/{propertyKey}

Path params: propertyKey — the key of the property (max 255 chars).

Body: BulkIssuePropertyUpdateRequest
  {:value      <any>    ; the new property value (max 32 768 chars JSON)
   :expression "..."  ; EXPERIMENTAL — Jira expression for computed value
   :filter     {...}}   ; IssueFilterForBulkPropertySet
sourceraw docstring

bulk-set-issues-properties-listclj

(bulk-set-issues-properties-list client body)

Bulk set issues properties by list. POST /rest/api/3/issue/properties

Sets a property on a list of issues identified by entity IDs.

Body: IssueEntityProperties {:entitiesIds [<long> ...] ; 1–10 000 issue IDs :properties {"key" <value>}} ; 1–10 property key/value pairs

Bulk set issues properties by list.
POST /rest/api/3/issue/properties

Sets a property on a list of issues identified by entity IDs.

Body: IssueEntityProperties
  {:entitiesIds [<long> ...]   ; 1–10 000 issue IDs
   :properties  {"key" <value>}}  ; 1–10 property key/value pairs
sourceraw docstring

delete-issue-propertyclj

(delete-issue-property client issue-id-or-key property-key)

Delete issue property. DELETE /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}

Path params: issue-id-or-key — the key or ID of the issue. property-key — the key of the property to delete.

Delete issue property.
DELETE /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}

Path params:
  issue-id-or-key — the key or ID of the issue.
  property-key    — the key of the property to delete.
sourceraw docstring

delete-issue-type-propertyclj

(delete-issue-type-property client issue-type-id property-key)

Delete issue type property. DELETE /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}

Path params: issue-type-id — the ID of the issue type. property-key — the key of the property to delete.

Delete issue type property.
DELETE /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}

Path params:
  issue-type-id — the ID of the issue type.
  property-key  — the key of the property to delete.
sourceraw docstring

get-issue-propertyclj

(get-issue-property client issue-id-or-key property-key)

Get issue property. GET /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}

Path params: issue-id-or-key — the key or ID of the issue. property-key — the key of the property.

Get issue property.
GET /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}

Path params:
  issue-id-or-key — the key or ID of the issue.
  property-key    — the key of the property.
sourceraw docstring

get-issue-property-keysclj

(get-issue-property-keys client issue-id-or-key)

Get issue property keys. GET /rest/api/3/issue/{issueIdOrKey}/properties

Path params: issue-id-or-key — the key or ID of the issue.

Get issue property keys.
GET /rest/api/3/issue/{issueIdOrKey}/properties

Path params: issue-id-or-key — the key or ID of the issue.
sourceraw docstring

get-issue-type-propertyclj

(get-issue-type-property client issue-type-id property-key)

Get issue type property. GET /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}

Path params: issue-type-id — the ID of the issue type. property-key — the key of the property.

Get issue type property.
GET /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}

Path params:
  issue-type-id — the ID of the issue type.
  property-key  — the key of the property.
sourceraw docstring

get-issue-type-property-keysclj

(get-issue-type-property-keys client issue-type-id)

Get issue type property keys. GET /rest/api/3/issuetype/{issueTypeId}/properties

Path params: issue-type-id — the ID of the issue type.

Get issue type property keys.
GET /rest/api/3/issuetype/{issueTypeId}/properties

Path params: issue-type-id — the ID of the issue type.
sourceraw docstring

set-issue-propertyclj

(set-issue-property client issue-id-or-key property-key body)

Set issue property. PUT /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}

Path params: issue-id-or-key — the ID or key of the issue. property-key — the key of the issue property (max 255 chars).

Body: any valid JSON-serialisable value (string, number, map, vector, etc.).

Set issue property.
PUT /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}

Path params:
  issue-id-or-key — the ID or key of the issue.
  property-key    — the key of the issue property (max 255 chars).

Body: any valid JSON-serialisable value (string, number, map, vector, etc.).
sourceraw docstring

set-issue-type-propertyclj

(set-issue-type-property client issue-type-id property-key body)

Set issue type property. PUT /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}

Path params: issue-type-id — the ID of the issue type. property-key — the key of the issue type property (max 255 chars).

Body: any valid JSON-serialisable value (string, number, map, vector, etc.).

Set issue type property.
PUT /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}

Path params:
  issue-type-id — the ID of the issue type.
  property-key  — the key of the issue type property (max 255 chars).

Body: any valid JSON-serialisable value (string, number, map, vector, etc.).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries