atlassian.jira.users

Jira Cloud Users, User Search, User Properties, and Groups endpoints.

One public fn per operation in resources/openapi/groups/users.edn. All fns delegate to atlassian.jira.client/request.

Jira Cloud Users, User Search, User Properties, and Groups endpoints.

One public fn per operation in resources/openapi/groups/users.edn. All fns
delegate to `atlassian.jira.client/request`.
raw docstring

add-user-to-groupclj

(add-user-to-group client body)
(add-user-to-group client body opts)

Add user to group. POST /rest/api/3/group/user

Body: UpdateUserToGroupBean {:accountId "<account-id>"}

Opts (query): groupname, groupId.

Add user to group.
POST /rest/api/3/group/user

Body: UpdateUserToGroupBean
  {:accountId "<account-id>"}

Opts (query): groupname, groupId.
sourceraw docstring

bulk-get-groupsclj

(bulk-get-groups client)
(bulk-get-groups client opts)

Bulk get groups. GET /rest/api/3/group/bulk

Opts (query): startAt, maxResults, groupId (repeatable), groupName (repeatable), accessType, applicationKey.

Bulk get groups.
GET /rest/api/3/group/bulk

Opts (query): startAt, maxResults, groupId (repeatable), groupName (repeatable),
              accessType, applicationKey.
sourceraw docstring

bulk-get-usersclj

(bulk-get-users client opts)

Bulk get users. GET /rest/api/3/user/bulk

Required query param: accountId (repeatable). Other opts: startAt, maxResults, username, key.

Bulk get users.
GET /rest/api/3/user/bulk

Required query param: accountId (repeatable). Other opts: startAt, maxResults,
username, key.
sourceraw docstring

bulk-get-users-migrationclj

(bulk-get-users-migration client)
(bulk-get-users-migration client opts)

Get account IDs for users. GET /rest/api/3/user/bulk/migration

Opts (query): startAt, maxResults, username (repeatable), key (repeatable).

Get account IDs for users.
GET /rest/api/3/user/bulk/migration

Opts (query): startAt, maxResults, username (repeatable), key (repeatable).
sourceraw docstring

create-groupclj

(create-group client body)

Create group. POST /rest/api/3/group

Body: AddGroupBean {:name "<group-name>"}

Create group.
POST /rest/api/3/group

Body: AddGroupBean
  {:name "<group-name>"}
sourceraw docstring

create-userclj

(create-user client body)

Create user. POST /rest/api/3/user

Body: NewUserDetails {:emailAddress "user@example.com" ; required :products ["jira-software"] ; required — pass [] for no product access :displayName "..." ; optional (deprecated field)}

Create user.
POST /rest/api/3/user

Body: NewUserDetails
  {:emailAddress "user@example.com"   ; required
   :products     ["jira-software"]    ; required — pass [] for no product access
   :displayName  "..."               ; optional (deprecated field)}
sourceraw docstring

delete-user-propertyclj

(delete-user-property client property-key)
(delete-user-property client property-key opts)

Delete user property. DELETE /rest/api/3/user/properties/{propertyKey}

Path params: property-key — the key of the user's property. Opts (query): accountId, userKey, username.

Delete user property.
DELETE /rest/api/3/user/properties/{propertyKey}

Path params: property-key — the key of the user's property.
Opts (query): accountId, userKey, username.
sourceraw docstring

find-assignable-usersclj

(find-assignable-users client)
(find-assignable-users client opts)

Find users assignable to issues. GET /rest/api/3/user/assignable/search

Opts (query): query, sessionId, username, accountId, project, issueKey, issueId, startAt, maxResults, actionDescriptorId, recommend, accountType, appType.

Find users assignable to issues.
GET /rest/api/3/user/assignable/search

Opts (query): query, sessionId, username, accountId, project, issueKey,
issueId, startAt, maxResults, actionDescriptorId, recommend, accountType,
appType.
sourceraw docstring

find-bulk-assignable-usersclj

(find-bulk-assignable-users client project-keys)
(find-bulk-assignable-users client project-keys opts)

Find users assignable to projects. GET /rest/api/3/user/assignable/multiProjectSearch

Required query param: projectKeys (comma-separated). Other opts: query, username, accountId, startAt, maxResults.

Find users assignable to projects.
GET /rest/api/3/user/assignable/multiProjectSearch

Required query param: projectKeys (comma-separated). Other opts: query,
username, accountId, startAt, maxResults.
sourceraw docstring

find-groupsclj

(find-groups client)
(find-groups client opts)

Find groups. GET /rest/api/3/groups/picker

Opts (query): accountId, query, exclude (repeatable), excludeId (repeatable), maxResults, caseInsensitive, userName.

Find groups.
GET /rest/api/3/groups/picker

Opts (query): accountId, query, exclude (repeatable), excludeId (repeatable),
              maxResults, caseInsensitive, userName.
sourceraw docstring

find-user-keys-by-queryclj

(find-user-keys-by-query client query)
(find-user-keys-by-query client query opts)

Find user keys by query. GET /rest/api/3/user/search/query/key

Required query param: query. Other opts: startAt, maxResult.

Find user keys by query.
GET /rest/api/3/user/search/query/key

Required query param: query. Other opts: startAt, maxResult.
sourceraw docstring

find-usersclj

(find-users client)
(find-users client opts)

Find users. GET /rest/api/3/user/search

Opts (query): query, username, accountId, startAt, maxResults, property.

Find users.
GET /rest/api/3/user/search

Opts (query): query, username, accountId, startAt, maxResults, property.
sourceraw docstring

find-users-and-groupsclj

(find-users-and-groups client query)
(find-users-and-groups client query opts)

Find users and groups. GET /rest/api/3/groupuserpicker

Required query param: query. Other opts: maxResults, showAvatar, fieldId, projectId (repeatable), issueTypeId (repeatable), avatarSize, caseInsensitive, excludeConnectAddons.

Find users and groups.
GET /rest/api/3/groupuserpicker

Required query param: query. Other opts: maxResults, showAvatar, fieldId,
projectId (repeatable), issueTypeId (repeatable), avatarSize, caseInsensitive,
excludeConnectAddons.
sourceraw docstring

find-users-by-queryclj

(find-users-by-query client query)
(find-users-by-query client query opts)

Find users by query. GET /rest/api/3/user/search/query

Required query param: query. Other opts: startAt, maxResults.

Find users by query.
GET /rest/api/3/user/search/query

Required query param: query. Other opts: startAt, maxResults.
sourceraw docstring

find-users-for-pickerclj

(find-users-for-picker client query)
(find-users-for-picker client query opts)

Find users for picker. GET /rest/api/3/user/picker

Required query param: query. Other opts: maxResults, showAvatar, exclude, excludeAccountIds, avatarSize, excludeConnectUsers.

Find users for picker.
GET /rest/api/3/user/picker

Required query param: query. Other opts: maxResults, showAvatar, exclude,
excludeAccountIds, avatarSize, excludeConnectUsers.
sourceraw docstring

find-users-with-all-permissionsclj

(find-users-with-all-permissions client permissions)
(find-users-with-all-permissions client permissions opts)

Find users with permissions. GET /rest/api/3/user/permission/search

Required query param: permissions (comma-separated). Other opts: query, username, accountId, issueKey, projectKey, startAt, maxResults.

Find users with permissions.
GET /rest/api/3/user/permission/search

Required query param: permissions (comma-separated). Other opts: query,
username, accountId, issueKey, projectKey, startAt, maxResults.
sourceraw docstring

find-users-with-browse-permissionclj

(find-users-with-browse-permission client)
(find-users-with-browse-permission client opts)

Find users with browse permission. GET /rest/api/3/user/viewissue/search

Opts (query): query, username, accountId, issueKey, projectKey, startAt, maxResults.

Find users with browse permission.
GET /rest/api/3/user/viewissue/search

Opts (query): query, username, accountId, issueKey, projectKey, startAt,
maxResults.
sourceraw docstring

get-all-usersclj

(get-all-users client)
(get-all-users client opts)

Get all users. GET /rest/api/3/users/search

Opts (query): startAt, maxResults, expand.

Get all users.
GET /rest/api/3/users/search

Opts (query): startAt, maxResults, expand.
sourceraw docstring

get-all-users-defaultclj

(get-all-users-default client)
(get-all-users-default client opts)

Get all users default. GET /rest/api/3/users

Opts (query): startAt, maxResults, expand.

Get all users default.
GET /rest/api/3/users

Opts (query): startAt, maxResults, expand.
sourceraw docstring

get-groupclj

(get-group client)
(get-group client opts)

DEPRECATED Get group. GET /rest/api/3/group

Opts (query): groupname, groupId, expand.

DEPRECATED Get group.
GET /rest/api/3/group

Opts (query): groupname, groupId, expand.
sourceraw docstring

get-userclj

(get-user client)
(get-user client opts)

Get user. GET /rest/api/3/user

Opts (query): accountId (required per Jira docs), username, key, expand.

Get user.
GET /rest/api/3/user

Opts (query): accountId (required per Jira docs), username, key, expand.
sourceraw docstring

get-user-default-columnsclj

(get-user-default-columns client)
(get-user-default-columns client opts)

Get user default columns. GET /rest/api/3/user/columns

Opts (query): accountId, username.

Get user default columns.
GET /rest/api/3/user/columns

Opts (query): accountId, username.
sourceraw docstring

get-user-emailclj

(get-user-email client account-id)

Get user email. GET /rest/api/3/user/email

Required query param: accountId.

Get user email.
GET /rest/api/3/user/email

Required query param: accountId.
sourceraw docstring

get-user-email-bulkclj

(get-user-email-bulk client opts)

Get user email bulk. GET /rest/api/3/user/email/bulk

Required query param: accountId (repeatable array).

Get user email bulk.
GET /rest/api/3/user/email/bulk

Required query param: accountId (repeatable array).
sourceraw docstring

get-user-groupsclj

(get-user-groups client account-id)
(get-user-groups client account-id opts)

Get user groups. GET /rest/api/3/user/groups

Required query param: accountId. Other opts: username, key.

Get user groups.
GET /rest/api/3/user/groups

Required query param: accountId. Other opts: username, key.
sourceraw docstring

get-user-propertyclj

(get-user-property client property-key)
(get-user-property client property-key opts)

Get user property. GET /rest/api/3/user/properties/{propertyKey}

Path params: property-key — the key of the user's property. Opts (query): accountId, userKey, username.

Get user property.
GET /rest/api/3/user/properties/{propertyKey}

Path params: property-key — the key of the user's property.
Opts (query): accountId, userKey, username.
sourceraw docstring

get-user-property-keysclj

(get-user-property-keys client)
(get-user-property-keys client opts)

Get user property keys. GET /rest/api/3/user/properties

Opts (query): accountId, userKey, username.

Get user property keys.
GET /rest/api/3/user/properties

Opts (query): accountId, userKey, username.
sourceraw docstring

get-users-from-groupclj

(get-users-from-group client)
(get-users-from-group client opts)

Get users from group. GET /rest/api/3/group/member

Opts (query): groupname, groupId, includeInactiveUsers, startAt, maxResults.

Get users from group.
GET /rest/api/3/group/member

Opts (query): groupname, groupId, includeInactiveUsers, startAt, maxResults.
sourceraw docstring

remove-groupclj

(remove-group client)
(remove-group client opts)

Remove group. DELETE /rest/api/3/group

Opts (query): groupname, groupId, swapGroup, swapGroupId.

Remove group.
DELETE /rest/api/3/group

Opts (query): groupname, groupId, swapGroup, swapGroupId.
sourceraw docstring

remove-userclj

(remove-user client opts)

Delete user. DELETE /rest/api/3/user

Required query param: accountId. Other opts: username, key.

Delete user.
DELETE /rest/api/3/user

Required query param: accountId. Other opts: username, key.
sourceraw docstring

remove-user-from-groupclj

(remove-user-from-group client opts)

Remove user from group. DELETE /rest/api/3/group/user

Required query param: accountId. Other opts: groupname, groupId, username.

Remove user from group.
DELETE /rest/api/3/group/user

Required query param: accountId. Other opts: groupname, groupId, username.
sourceraw docstring

reset-user-columnsclj

(reset-user-columns client)
(reset-user-columns client opts)

Reset user default columns. DELETE /rest/api/3/user/columns

Opts (query): accountId, username.

Reset user default columns.
DELETE /rest/api/3/user/columns

Opts (query): accountId, username.
sourceraw docstring

set-user-columnsclj

(set-user-columns client body)
(set-user-columns client body opts)

Set user default columns. PUT /rest/api/3/user/columns

Opts (query): accountId.

Body: array of column keys (schema-ref not named in spec — pass a vector of column identifier strings, e.g. ["issuekey" "summary"]).

Set user default columns.
PUT /rest/api/3/user/columns

Opts (query): accountId.

Body: array of column keys (schema-ref not named in spec — pass a vector of
column identifier strings, e.g. ["issuekey" "summary"]).
sourceraw docstring

set-user-propertyclj

(set-user-property client property-key body)
(set-user-property client property-key body opts)

Set user property. PUT /rest/api/3/user/properties/{propertyKey}

Path params: property-key — the key of the user's property (max 255 chars). Opts (query): accountId, userKey, username.

Body: any valid JSON-serialisable value (string, number, map, vector, etc.).

Set user property.
PUT /rest/api/3/user/properties/{propertyKey}

Path params: property-key — the key of the user's property (max 255 chars).
Opts (query): accountId, userKey, username.

Body: any valid JSON-serialisable value (string, number, map, vector, etc.).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries