Jira Cloud workflow, workflow-scheme, status, and status-category endpoints.
All functions take a client (from atlassian.jira.client/client) as their
first argument. Optional query params are passed via the trailing opts map.
Jira Cloud workflow, workflow-scheme, status, and status-category endpoints. All functions take a `client` (from `atlassian.jira.client/client`) as their first argument. Optional query params are passed via the trailing `opts` map.
(assign-scheme-to-project client body)(assign-scheme-to-project client body opts)Assign workflow scheme to project. PUT /rest/api/3/workflowscheme/project Body: WorkflowSchemeProjectAssociation — {:workflowSchemeId string, :projectId string}
Assign workflow scheme to project.
PUT /rest/api/3/workflowscheme/project
Body: WorkflowSchemeProjectAssociation — {:workflowSchemeId string, :projectId string}(create-workflow-scheme client body)(create-workflow-scheme client body opts)Create workflow scheme. POST /rest/api/3/workflowscheme Body: WorkflowScheme — {:name string, :description string, :defaultWorkflow string, :issueTypeMappings {issueTypeId workflowName}}
Create workflow scheme.
POST /rest/api/3/workflowscheme
Body: WorkflowScheme — {:name string, :description string, :defaultWorkflow string, :issueTypeMappings {issueTypeId workflowName}}(create-workflow-scheme-draft-from-parent client id)Create draft workflow scheme from an active workflow scheme. POST /rest/api/3/workflowscheme/{id}/createdraft Path params: id — the ID of the active workflow scheme.
Create draft workflow scheme from an active workflow scheme.
POST /rest/api/3/workflowscheme/{id}/createdraft
Path params: id — the ID of the active workflow scheme.(create-workflow-transition-property client transition-id body opts)DEPRECATED: Create workflow transition property. POST /rest/api/3/workflow/transitions/{transitionId}/properties Path params: transition-id Body: WorkflowTransitionProperty — {:key string, :value string} opts: :key (required), :workflowName (required), :workflowMode
DEPRECATED: Create workflow transition property.
POST /rest/api/3/workflow/transitions/{transitionId}/properties
Path params: transition-id
Body: WorkflowTransitionProperty — {:key string, :value string}
opts: :key (required), :workflowName (required), :workflowMode(create-workflows client body)(create-workflows client body opts)Bulk create workflows. POST /rest/api/3/workflows/create Body: WorkflowCreateRequest — {:scope {:type string}, :workflows [{:name string, :statuses [...], :transitions [...]}]}
Bulk create workflows.
POST /rest/api/3/workflows/create
Body: WorkflowCreateRequest — {:scope {:type string}, :workflows [{:name string, :statuses [...], :transitions [...]}]}(delete-default-workflow client id)(delete-default-workflow client id opts)Delete default workflow from workflow scheme. DELETE /rest/api/3/workflowscheme/{id}/default Path params: id — the workflow scheme ID. opts: :updateDraftIfNeeded
Delete default workflow from workflow scheme.
DELETE /rest/api/3/workflowscheme/{id}/default
Path params: id — the workflow scheme ID.
opts: :updateDraftIfNeeded(delete-draft-default-workflow client id)Delete draft default workflow. DELETE /rest/api/3/workflowscheme/{id}/draft/default Path params: id — the ID of the workflow scheme the draft belongs to.
Delete draft default workflow.
DELETE /rest/api/3/workflowscheme/{id}/draft/default
Path params: id — the ID of the workflow scheme the draft belongs to.(delete-draft-workflow-mapping client id opts)Delete issue types for workflow in draft workflow scheme. DELETE /rest/api/3/workflowscheme/{id}/draft/workflow Path params: id — the workflow scheme ID. opts: :workflowName (required)
Delete issue types for workflow in draft workflow scheme.
DELETE /rest/api/3/workflowscheme/{id}/draft/workflow
Path params: id — the workflow scheme ID.
opts: :workflowName (required)(delete-inactive-workflow client entity-id)Delete inactive workflow. DELETE /rest/api/3/workflow/{entityId} Path params: entity-id — the entity ID of the workflow.
Delete inactive workflow.
DELETE /rest/api/3/workflow/{entityId}
Path params: entity-id — the entity ID of the workflow.(delete-workflow-mapping client id opts)Delete issue types for workflow in workflow scheme. DELETE /rest/api/3/workflowscheme/{id}/workflow Path params: id — the workflow scheme ID. opts: :workflowName (required), :updateDraftIfNeeded
Delete issue types for workflow in workflow scheme.
DELETE /rest/api/3/workflowscheme/{id}/workflow
Path params: id — the workflow scheme ID.
opts: :workflowName (required), :updateDraftIfNeeded(delete-workflow-scheme client id)Delete workflow scheme. DELETE /rest/api/3/workflowscheme/{id} Path params: id — the workflow scheme ID.
Delete workflow scheme.
DELETE /rest/api/3/workflowscheme/{id}
Path params: id — the workflow scheme ID.(delete-workflow-scheme-draft client id)Delete draft workflow scheme. DELETE /rest/api/3/workflowscheme/{id}/draft Path params: id — the ID of the active workflow scheme the draft was created from.
Delete draft workflow scheme.
DELETE /rest/api/3/workflowscheme/{id}/draft
Path params: id — the ID of the active workflow scheme the draft was created from.(delete-workflow-scheme-draft-issue-type client id issue-type)Delete workflow for issue type in draft workflow scheme. DELETE /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType} Path params: id — the workflow scheme ID, issue-type — the issue type ID.
Delete workflow for issue type in draft workflow scheme.
DELETE /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType}
Path params: id — the workflow scheme ID, issue-type — the issue type ID.(delete-workflow-scheme-issue-type client id issue-type)(delete-workflow-scheme-issue-type client id issue-type opts)Delete workflow for issue type in workflow scheme. DELETE /rest/api/3/workflowscheme/{id}/issuetype/{issueType} Path params: id — the workflow scheme ID, issue-type — the issue type ID. opts: :updateDraftIfNeeded
Delete workflow for issue type in workflow scheme.
DELETE /rest/api/3/workflowscheme/{id}/issuetype/{issueType}
Path params: id — the workflow scheme ID, issue-type — the issue type ID.
opts: :updateDraftIfNeeded(delete-workflow-transition-property client transition-id opts)DEPRECATED: Delete workflow transition property. DELETE /rest/api/3/workflow/transitions/{transitionId}/properties Path params: transition-id opts: :key (required), :workflowName (required), :workflowMode
DEPRECATED: Delete workflow transition property.
DELETE /rest/api/3/workflow/transitions/{transitionId}/properties
Path params: transition-id
opts: :key (required), :workflowName (required), :workflowMode(delete-workflow-transition-rule-configurations client body)(delete-workflow-transition-rule-configurations client body opts)Delete workflow transition rule configurations. PUT /rest/api/3/workflow/rule/config/delete Body: WorkflowsWithTransitionRulesDetails — {:workflows [{:workflowId string, ...}]}
Delete workflow transition rule configurations.
PUT /rest/api/3/workflow/rule/config/delete
Body: WorkflowsWithTransitionRulesDetails — {:workflows [{:workflowId string, ...}]}(get-all-workflow-schemes client)(get-all-workflow-schemes client opts)Get all workflow schemes. GET /rest/api/3/workflowscheme opts: :startAt, :maxResults
Get all workflow schemes. GET /rest/api/3/workflowscheme opts: :startAt, :maxResults
(get-default-editor client)Get the user's default workflow editor. GET /rest/api/3/workflows/defaultEditor
Get the user's default workflow editor. GET /rest/api/3/workflows/defaultEditor
(get-default-workflow client id)(get-default-workflow client id opts)Get default workflow for workflow scheme. GET /rest/api/3/workflowscheme/{id}/default Path params: id — the workflow scheme ID. opts: :returnDraftIfExists
Get default workflow for workflow scheme.
GET /rest/api/3/workflowscheme/{id}/default
Path params: id — the workflow scheme ID.
opts: :returnDraftIfExists(get-draft-default-workflow client id)Get draft default workflow. GET /rest/api/3/workflowscheme/{id}/draft/default Path params: id — the ID of the workflow scheme the draft belongs to.
Get draft default workflow.
GET /rest/api/3/workflowscheme/{id}/draft/default
Path params: id — the ID of the workflow scheme the draft belongs to.(get-draft-workflow client id)(get-draft-workflow client id opts)Get issue types for workflows in draft workflow scheme. GET /rest/api/3/workflowscheme/{id}/draft/workflow Path params: id — the workflow scheme ID. opts: :workflowName
Get issue types for workflows in draft workflow scheme.
GET /rest/api/3/workflowscheme/{id}/draft/workflow
Path params: id — the workflow scheme ID.
opts: :workflowName(get-project-usages-for-workflow client workflow-id)(get-project-usages-for-workflow client workflow-id opts)Get projects using a given workflow. GET /rest/api/3/workflow/{workflowId}/projectUsages Path params: workflow-id opts: :nextPageToken, :maxResults
Get projects using a given workflow.
GET /rest/api/3/workflow/{workflowId}/projectUsages
Path params: workflow-id
opts: :nextPageToken, :maxResults(get-project-usages-for-workflow-scheme client workflow-scheme-id)(get-project-usages-for-workflow-scheme client workflow-scheme-id opts)Get projects which are using a given workflow scheme. GET /rest/api/3/workflowscheme/{workflowSchemeId}/projectUsages Path params: workflow-scheme-id opts: :nextPageToken, :maxResults
Get projects which are using a given workflow scheme.
GET /rest/api/3/workflowscheme/{workflowSchemeId}/projectUsages
Path params: workflow-scheme-id
opts: :nextPageToken, :maxResults(get-required-workflow-scheme-mappings client body)(get-required-workflow-scheme-mappings client body opts)Get required status mappings for workflow scheme update. POST /rest/api/3/workflowscheme/update/mappings Body: WorkflowSchemeUpdateRequiredMappingsRequest
Get required status mappings for workflow scheme update. POST /rest/api/3/workflowscheme/update/mappings Body: WorkflowSchemeUpdateRequiredMappingsRequest
(get-status client id-or-name)Get status by ID or name. GET /rest/api/3/status/{idOrName} Path params: idOrName — the ID or name of the status.
Get status by ID or name.
GET /rest/api/3/status/{idOrName}
Path params: idOrName — the ID or name of the status.(get-status-categories client)Get all status categories. GET /rest/api/3/statuscategory
Get all status categories. GET /rest/api/3/statuscategory
(get-status-category client id-or-key)Get status category by ID or key. GET /rest/api/3/statuscategory/{idOrKey} Path params: id-or-key — the ID or key of the status category.
Get status category by ID or key.
GET /rest/api/3/statuscategory/{idOrKey}
Path params: id-or-key — the ID or key of the status category.(get-statuses client)Get all statuses. GET /rest/api/3/status
Get all statuses. GET /rest/api/3/status
(get-workflow client id)(get-workflow client id opts)Get issue types for workflows in workflow scheme. GET /rest/api/3/workflowscheme/{id}/workflow Path params: id — the workflow scheme ID. opts: :workflowName, :returnDraftIfExists
Get issue types for workflows in workflow scheme.
GET /rest/api/3/workflowscheme/{id}/workflow
Path params: id — the workflow scheme ID.
opts: :workflowName, :returnDraftIfExists(get-workflow-project-issue-type-usages client workflow-id project-id)(get-workflow-project-issue-type-usages client workflow-id project-id opts)Get issue types in a project that are using a given workflow. GET /rest/api/3/workflow/{workflowId}/project/{projectId}/issueTypeUsages Path params: workflow-id, project-id opts: :nextPageToken, :maxResults
Get issue types in a project that are using a given workflow.
GET /rest/api/3/workflow/{workflowId}/project/{projectId}/issueTypeUsages
Path params: workflow-id, project-id
opts: :nextPageToken, :maxResults(get-workflow-scheme client id)(get-workflow-scheme client id opts)Get workflow scheme. GET /rest/api/3/workflowscheme/{id} Path params: id — the workflow scheme ID. opts: :returnDraftIfExists
Get workflow scheme.
GET /rest/api/3/workflowscheme/{id}
Path params: id — the workflow scheme ID.
opts: :returnDraftIfExists(get-workflow-scheme-draft client id)Get draft workflow scheme. GET /rest/api/3/workflowscheme/{id}/draft Path params: id — the ID of the active workflow scheme the draft was created from.
Get draft workflow scheme.
GET /rest/api/3/workflowscheme/{id}/draft
Path params: id — the ID of the active workflow scheme the draft was created from.(get-workflow-scheme-draft-issue-type client id issue-type)Get workflow for issue type in draft workflow scheme. GET /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType} Path params: id — the workflow scheme ID, issue-type — the issue type ID.
Get workflow for issue type in draft workflow scheme.
GET /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType}
Path params: id — the workflow scheme ID, issue-type — the issue type ID.(get-workflow-scheme-issue-type client id issue-type)(get-workflow-scheme-issue-type client id issue-type opts)Get workflow for issue type in workflow scheme. GET /rest/api/3/workflowscheme/{id}/issuetype/{issueType} Path params: id — the workflow scheme ID, issue-type — the issue type ID. opts: :returnDraftIfExists
Get workflow for issue type in workflow scheme.
GET /rest/api/3/workflowscheme/{id}/issuetype/{issueType}
Path params: id — the workflow scheme ID, issue-type — the issue type ID.
opts: :returnDraftIfExists(get-workflow-scheme-project-associations client opts)Get workflow scheme project associations. GET /rest/api/3/workflowscheme/project opts: :projectId (required, array)
Get workflow scheme project associations. GET /rest/api/3/workflowscheme/project opts: :projectId (required, array)
(get-workflow-scheme-usages-for-workflow client workflow-id)(get-workflow-scheme-usages-for-workflow client workflow-id opts)Get workflow schemes which are using a given workflow. GET /rest/api/3/workflow/{workflowId}/workflowSchemes Path params: workflow-id opts: :nextPageToken, :maxResults
Get workflow schemes which are using a given workflow.
GET /rest/api/3/workflow/{workflowId}/workflowSchemes
Path params: workflow-id
opts: :nextPageToken, :maxResults(get-workflow-transition-properties client transition-id opts)DEPRECATED: Get workflow transition properties. GET /rest/api/3/workflow/transitions/{transitionId}/properties Path params: transition-id opts: :workflowName (required), :includeReservedKeys, :key, :workflowMode
DEPRECATED: Get workflow transition properties.
GET /rest/api/3/workflow/transitions/{transitionId}/properties
Path params: transition-id
opts: :workflowName (required), :includeReservedKeys, :key, :workflowMode(get-workflow-transition-rule-configurations client opts)Get workflow transition rule configurations. GET /rest/api/3/workflow/rule/config opts: :types (required array), :startAt, :maxResults, :keys, :workflowNames, :withTags, :draft, :expand
Get workflow transition rule configurations. GET /rest/api/3/workflow/rule/config opts: :types (required array), :startAt, :maxResults, :keys, :workflowNames, :withTags, :draft, :expand
(get-workflows-paginated client)(get-workflows-paginated client opts)DEPRECATED: Get workflows paginated. GET /rest/api/3/workflow/search opts: :startAt, :maxResults, :workflowName, :expand, :queryString, :orderBy, :isActive
DEPRECATED: Get workflows paginated. GET /rest/api/3/workflow/search opts: :startAt, :maxResults, :workflowName, :expand, :queryString, :orderBy, :isActive
(list-workflow-history client body)(list-workflow-history client body opts)List workflow history entries. POST /rest/api/3/workflow/history/list Body: WorkflowHistoryListRequest opts: :expand — comma-separated expansion options (e.g. "includeIntermediateVersions")
List workflow history entries. POST /rest/api/3/workflow/history/list Body: WorkflowHistoryListRequest opts: :expand — comma-separated expansion options (e.g. "includeIntermediateVersions")
(publish-draft-workflow-scheme client id body)(publish-draft-workflow-scheme client id body opts)Publish draft workflow scheme. POST /rest/api/3/workflowscheme/{id}/draft/publish Path params: id — the ID of the workflow scheme the draft belongs to. Body: PublishDraftWorkflowScheme — {:statusMappingsByWorkflows [...], :statusMappingsByIssueTypeOverride [...]} opts: :validateOnly
Publish draft workflow scheme.
POST /rest/api/3/workflowscheme/{id}/draft/publish
Path params: id — the ID of the workflow scheme the draft belongs to.
Body: PublishDraftWorkflowScheme — {:statusMappingsByWorkflows [...], :statusMappingsByIssueTypeOverride [...]}
opts: :validateOnly(read-workflow-from-history client body)(read-workflow-from-history client body opts)Read workflow version from history. POST /rest/api/3/workflow/history Body: WorkflowHistoryReadRequest — {:workflowId string, :versionId string}
Read workflow version from history.
POST /rest/api/3/workflow/history
Body: WorkflowHistoryReadRequest — {:workflowId string, :versionId string}(read-workflow-previews client body)(read-workflow-previews client body opts)Preview workflow. POST /rest/api/3/workflows/preview Body: WorkflowPreviewRequest
Preview workflow. POST /rest/api/3/workflows/preview Body: WorkflowPreviewRequest
(read-workflow-schemes client body)(read-workflow-schemes client body opts)Bulk get workflow schemes. POST /rest/api/3/workflowscheme/read Body: WorkflowSchemeReadRequest — {:workflowSchemeIds [string], :expand [string]}
Bulk get workflow schemes.
POST /rest/api/3/workflowscheme/read
Body: WorkflowSchemeReadRequest — {:workflowSchemeIds [string], :expand [string]}(read-workflows client body)(read-workflows client body opts)Bulk get workflows. POST /rest/api/3/workflows Body: WorkflowReadRequest — {:workflowIds [string], :expand [string]}
Bulk get workflows.
POST /rest/api/3/workflows
Body: WorkflowReadRequest — {:workflowIds [string], :expand [string]}(search-workflows client)(search-workflows client opts)Search workflows. GET /rest/api/3/workflows/search opts: :startAt, :maxResults, :expand, :queryString, :orderBy, :scope, :isActive
Search workflows. GET /rest/api/3/workflows/search opts: :startAt, :maxResults, :expand, :queryString, :orderBy, :scope, :isActive
(set-workflow-scheme-draft-issue-type client id issue-type body)(set-workflow-scheme-draft-issue-type client id issue-type body opts)Set workflow for issue type in draft workflow scheme. PUT /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType} Path params: id — the workflow scheme ID, issue-type — the issue type ID. Body: IssueTypeWorkflowMapping — {:issueType string, :workflow string, :updateDraftIfNeeded boolean}
Set workflow for issue type in draft workflow scheme.
PUT /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType}
Path params: id — the workflow scheme ID, issue-type — the issue type ID.
Body: IssueTypeWorkflowMapping — {:issueType string, :workflow string, :updateDraftIfNeeded boolean}(set-workflow-scheme-issue-type client id issue-type body)(set-workflow-scheme-issue-type client id issue-type body opts)Set workflow for issue type in workflow scheme. PUT /rest/api/3/workflowscheme/{id}/issuetype/{issueType} Path params: id — the workflow scheme ID, issue-type — the issue type ID. Body: IssueTypeWorkflowMapping — {:issueType string, :workflow string, :updateDraftIfNeeded boolean}
Set workflow for issue type in workflow scheme.
PUT /rest/api/3/workflowscheme/{id}/issuetype/{issueType}
Path params: id — the workflow scheme ID, issue-type — the issue type ID.
Body: IssueTypeWorkflowMapping — {:issueType string, :workflow string, :updateDraftIfNeeded boolean}(switch-workflow-scheme-for-project client body)(switch-workflow-scheme-for-project client body opts)Switch workflow scheme for project. POST /rest/api/3/workflowscheme/project/switch Body: WorkflowSchemeProjectSwitchBean — {:workflowSchemeId string, :projectId string, :statusMappingsByWorkflows [...], :statusMappingsByIssueTypeOverride [...]}
Switch workflow scheme for project.
POST /rest/api/3/workflowscheme/project/switch
Body: WorkflowSchemeProjectSwitchBean — {:workflowSchemeId string, :projectId string, :statusMappingsByWorkflows [...], :statusMappingsByIssueTypeOverride [...]}(update-default-workflow client id body)(update-default-workflow client id body opts)Update default workflow for workflow scheme. PUT /rest/api/3/workflowscheme/{id}/default Path params: id — the workflow scheme ID. Body: DefaultWorkflow — {:workflow string, :updateDraftIfNeeded boolean}
Update default workflow for workflow scheme.
PUT /rest/api/3/workflowscheme/{id}/default
Path params: id — the workflow scheme ID.
Body: DefaultWorkflow — {:workflow string, :updateDraftIfNeeded boolean}(update-draft-default-workflow client id body)(update-draft-default-workflow client id body opts)Update draft default workflow. PUT /rest/api/3/workflowscheme/{id}/draft/default Path params: id — the ID of the workflow scheme the draft belongs to. Body: DefaultWorkflow — {:workflow string, :updateDraftIfNeeded boolean}
Update draft default workflow.
PUT /rest/api/3/workflowscheme/{id}/draft/default
Path params: id — the ID of the workflow scheme the draft belongs to.
Body: DefaultWorkflow — {:workflow string, :updateDraftIfNeeded boolean}(update-draft-workflow-mapping client id body opts)Set issue types for workflow in workflow scheme (draft). PUT /rest/api/3/workflowscheme/{id}/draft/workflow Path params: id — the workflow scheme ID. Body: IssueTypesWorkflowMapping — {:workflow string, :issueTypes [string], :defaultMapping boolean, :updateDraftIfNeeded boolean} opts: :workflowName (required)
Set issue types for workflow in workflow scheme (draft).
PUT /rest/api/3/workflowscheme/{id}/draft/workflow
Path params: id — the workflow scheme ID.
Body: IssueTypesWorkflowMapping — {:workflow string, :issueTypes [string], :defaultMapping boolean, :updateDraftIfNeeded boolean}
opts: :workflowName (required)(update-schemes client body)(update-schemes client body opts)Update workflow scheme. POST /rest/api/3/workflowscheme/update Body: WorkflowSchemeUpdateRequest — {:id string, :version {:id string, :versionNumber integer}, :defaultWorkflowId string, :workflowsForIssueTypes [...]}
Update workflow scheme.
POST /rest/api/3/workflowscheme/update
Body: WorkflowSchemeUpdateRequest — {:id string, :version {:id string, :versionNumber integer}, :defaultWorkflowId string, :workflowsForIssueTypes [...]}(update-workflow-mapping client id body opts)Set issue types for workflow in workflow scheme. PUT /rest/api/3/workflowscheme/{id}/workflow Path params: id — the workflow scheme ID. Body: IssueTypesWorkflowMapping — {:workflow string, :issueTypes [string], :defaultMapping boolean, :updateDraftIfNeeded boolean} opts: :workflowName (required)
Set issue types for workflow in workflow scheme.
PUT /rest/api/3/workflowscheme/{id}/workflow
Path params: id — the workflow scheme ID.
Body: IssueTypesWorkflowMapping — {:workflow string, :issueTypes [string], :defaultMapping boolean, :updateDraftIfNeeded boolean}
opts: :workflowName (required)(update-workflow-scheme client id body)(update-workflow-scheme client id body opts)Classic update workflow scheme. PUT /rest/api/3/workflowscheme/{id} Path params: id — the workflow scheme ID. Body: WorkflowScheme — {:name string, :description string, :defaultWorkflow string, :issueTypeMappings {issueTypeId workflowName}}
Classic update workflow scheme.
PUT /rest/api/3/workflowscheme/{id}
Path params: id — the workflow scheme ID.
Body: WorkflowScheme — {:name string, :description string, :defaultWorkflow string, :issueTypeMappings {issueTypeId workflowName}}(update-workflow-scheme-draft client id body)(update-workflow-scheme-draft client id body opts)Update draft workflow scheme. PUT /rest/api/3/workflowscheme/{id}/draft Path params: id — the ID of the active workflow scheme the draft was created from. Body: WorkflowScheme — {:name string, :description string, :defaultWorkflow string, :issueTypeMappings {issueTypeId workflowName}}
Update draft workflow scheme.
PUT /rest/api/3/workflowscheme/{id}/draft
Path params: id — the ID of the active workflow scheme the draft was created from.
Body: WorkflowScheme — {:name string, :description string, :defaultWorkflow string, :issueTypeMappings {issueTypeId workflowName}}(update-workflow-transition-property client transition-id body opts)DEPRECATED: Update workflow transition property. PUT /rest/api/3/workflow/transitions/{transitionId}/properties Path params: transition-id Body: WorkflowTransitionProperty — {:key string, :value string} opts: :key (required), :workflowName (required), :workflowMode
DEPRECATED: Update workflow transition property.
PUT /rest/api/3/workflow/transitions/{transitionId}/properties
Path params: transition-id
Body: WorkflowTransitionProperty — {:key string, :value string}
opts: :key (required), :workflowName (required), :workflowMode(update-workflow-transition-rule-configurations client body)(update-workflow-transition-rule-configurations client body opts)Update workflow transition rule configurations. PUT /rest/api/3/workflow/rule/config Body: WorkflowTransitionRulesUpdate
Update workflow transition rule configurations. PUT /rest/api/3/workflow/rule/config Body: WorkflowTransitionRulesUpdate
(update-workflows client body)(update-workflows client body opts)Bulk update workflows. POST /rest/api/3/workflows/update Body: WorkflowUpdateRequest — {:workflows [{:id string, :version {...}, :statuses [...], :transitions [...]}]}
Bulk update workflows.
POST /rest/api/3/workflows/update
Body: WorkflowUpdateRequest — {:workflows [{:id string, :version {...}, :statuses [...], :transitions [...]}]}(validate-create-workflows client body)(validate-create-workflows client body opts)Validate create workflows. POST /rest/api/3/workflows/create/validation Body: WorkflowCreateValidateRequest — {:payload WorkflowCreateRequest, :validationOptions {...}}
Validate create workflows.
POST /rest/api/3/workflows/create/validation
Body: WorkflowCreateValidateRequest — {:payload WorkflowCreateRequest, :validationOptions {...}}(validate-update-workflows client body)(validate-update-workflows client body opts)Validate update workflows. POST /rest/api/3/workflows/update/validation Body: WorkflowUpdateValidateRequestBean — {:payload WorkflowUpdateRequest, :validationOptions {...}}
Validate update workflows.
POST /rest/api/3/workflows/update/validation
Body: WorkflowUpdateValidateRequestBean — {:payload WorkflowUpdateRequest, :validationOptions {...}}(workflow-capabilities client)(workflow-capabilities client opts)Get available workflow capabilities. GET /rest/api/3/workflows/capabilities opts: :workflowId, :projectId, :issueTypeId
Get available workflow capabilities. GET /rest/api/3/workflows/capabilities opts: :workflowId, :projectId, :issueTypeId
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |